@@ -20,9 +20,9 @@ data = np.random.random((50, 50, 50))
 
 fig, ax = plt.subplots()
 
-for i in range(len(data)):
-    ax.cla()
-    ax.imshow(data[i])
-    ax.set_title("frame {}".format(i))
+for i, img in enumerate(data):
+    ax.clear()
+    ax.imshow(img)
+    ax.set_title(f"frame {i}")
     # Note that using time.sleep does *not* work here!
     plt.pause(0.1)
