@@ -7,6 +7,14 @@ This example showcases:
 
 - using the Animation.pause() method to pause an animation.
 - using the Animation.resume() method to resume an animation.
+
+.. note::
+    This example exercises the interactive capabilities of Matplotlib, and this
+    will not appear in the static documentation. Please run this code on your
+    machine to see the interactivity.
+
+    You can copy and paste individual parts, or download the entire example
+    using the link at the bottom of the page.
 """
 
 import matplotlib.pyplot as plt
