@@ -6,7 +6,7 @@ Parasite Simple2
 """
 import matplotlib.transforms as mtransforms
 import matplotlib.pyplot as plt
-from mpl_toolkits.axes_grid1.parasite_axes import SubplotHost
+from mpl_toolkits.axes_grid1.parasite_axes import HostAxes
 
 obs = [["01_S1", 3.88, 0.14, 1970, 63],
        ["01_S4", 5.6, 0.82, 1622, 150],
@@ -16,16 +16,13 @@ obs = [["01_S1", 3.88, 0.14, 1970, 63],
 
 fig = plt.figure()
 
-ax_kms = SubplotHost(fig, 1, 1, 1, aspect=1.)
+ax_kms = fig.add_subplot(axes_class=HostAxes, aspect=1)
 
 # angular proper motion("/yr) to linear velocity(km/s) at distance=2.3kpc
 pm_to_kms = 1./206265.*2300*3.085e18/3.15e7/1.e5
 
 aux_trans = mtransforms.Affine2D().scale(pm_to_kms, 1.)
 ax_pm = ax_kms.twin(aux_trans)
-ax_pm.set_viewlim_mode("transform")
-
-fig.add_subplot(ax_kms)
 
 for n, ds, dse, w, we in obs:
     time = ((2007 + (10. + 4/30.)/12) - 1988.5)
