@@ -1,18 +1,18 @@
 """
-===========================================
-Blend transparency with color in 2-D images
-===========================================
+==========================================
+Blend transparency with color in 2D images
+==========================================
 
 Blend transparency with color to highlight parts of data with imshow.
 
-A common use for `matplotlib.pyplot.imshow` is to plot a 2-D statistical
-map. The function makes it easy to visualize a 2-D matrix as an image and add
+A common use for `matplotlib.pyplot.imshow` is to plot a 2D statistical
+map. The function makes it easy to visualize a 2D matrix as an image and add
 transparency to the output. For example, one can plot a statistic (such as a
 t-statistic) and color the transparency of each pixel according to its p-value.
 This example demonstrates how you can achieve this effect.
 
-First we will generate some data, in this case, we'll create two 2-D "blobs"
-in a 2-D grid. One blob will be positive, and the other negative.
+First we will generate some data, in this case, we'll create two 2D "blobs"
+in a 2D grid. One blob will be positive, and the other negative.
 """
 
 # sphinx_gallery_thumbnail_number = 3
@@ -113,18 +113,12 @@ plt.show()
 
 #############################################################################
 #
-# ------------
+# .. admonition:: References
 #
-# References
-# """"""""""
+#    The use of the following functions, methods, classes and modules is shown
+#    in this example:
 #
-# The use of the following functions, methods and classes is shown
-# in this example:
-
-import matplotlib
-matplotlib.axes.Axes.imshow
-matplotlib.pyplot.imshow
-matplotlib.axes.Axes.contour
-matplotlib.pyplot.contour
-matplotlib.colors.Normalize
-matplotlib.axes.Axes.set_axis_off
+#    - `matplotlib.axes.Axes.imshow` / `matplotlib.pyplot.imshow`
+#    - `matplotlib.axes.Axes.contour` / `matplotlib.pyplot.contour`
+#    - `matplotlib.colors.Normalize`
+#    - `matplotlib.axes.Axes.set_axis_off`
