@@ -19,7 +19,7 @@ np.random.seed(19680801)
 X = 10*np.random.rand(5, 3)
 
 fig, ax = plt.subplots()
-ax.imshow(X, interpolation='nearest')
+ax.imshow(X)
 
 numrows, numcols = X.shape
 
@@ -27,7 +27,7 @@ numrows, numcols = X.shape
 def format_coord(x, y):
     col = int(x + 0.5)
     row = int(y + 0.5)
-    if col >= 0 and col < numcols and row >= 0 and row < numrows:
+    if 0 <= col < numcols and 0 <= row < numrows:
         z = X[row, col]
         return 'x=%1.4f, y=%1.4f, z=%1.4f' % (x, y, z)
     else:
@@ -38,14 +38,10 @@ plt.show()
 
 #############################################################################
 #
-# ------------
+# .. admonition:: References
 #
-# References
-# """"""""""
+#    The use of the following functions, methods, classes and modules is shown
+#    in this example:
 #
-# The use of the following functions, methods, classes and modules is shown
-# in this example:
-
-import matplotlib
-matplotlib.axes.Axes.format_coord
-matplotlib.axes.Axes.imshow
+#    - `matplotlib.axes.Axes.format_coord`
+#    - `matplotlib.axes.Axes.imshow`
