@@ -33,14 +33,9 @@ plt.show()
 
 #############################################################################
 #
-# ------------
+# .. admonition:: References
 #
-# References
-# """"""""""
+#    The use of the following functions, methods, classes and modules is shown
+#    in this example:
 #
-# The use of the following functions, methods and classes is shown
-# in this example:
-
-import matplotlib
-matplotlib.axes.Axes.spy
-matplotlib.pyplot.spy
+#    - `matplotlib.axes.Axes.spy` / `matplotlib.pyplot.spy`
