@@ -9,76 +9,43 @@ of the figure is similar to the one found in
 :doc:`/gallery/axes_grid1/simple_anchored_artists`, but it is
 implemented using only the matplotlib namespace, without the help
 of additional toolkits.
+
+.. redirect-from:: /gallery/userdemo/anchored_box01
+.. redirect-from:: /gallery/userdemo/anchored_box02
+.. redirect-from:: /gallery/userdemo/anchored_box03
 """
 
 from matplotlib import pyplot as plt
 from matplotlib.lines import Line2D
-from matplotlib.patches import Ellipse
+from matplotlib.patches import Circle, Ellipse
 from matplotlib.offsetbox import (
     AnchoredOffsetbox, AuxTransformBox, DrawingArea, TextArea, VPacker)
 
 
-class AnchoredText(AnchoredOffsetbox):
-    def __init__(self, s, loc, pad=0.4, borderpad=0.5,
-                 prop=None, frameon=True):
-        self.txt = TextArea(s, minimumdescent=False)
-        super().__init__(loc, pad=pad, borderpad=borderpad,
-                         child=self.txt, prop=prop, frameon=frameon)
-
-
 def draw_text(ax):
-    """
-    Draw a text-box anchored to the upper-left corner of the figure.
-    """
-    at = AnchoredText("Figure 1a", loc='upper left', frameon=True)
-    at.patch.set_boxstyle("round,pad=0.,rounding_size=0.2")
-    ax.add_artist(at)
+    """Draw a text-box anchored to the upper-left corner of the figure."""
+    box = AnchoredOffsetbox(child=TextArea("Figure 1a"),
+                            loc="upper left", frameon=True)
+    box.patch.set_boxstyle("round,pad=0.,rounding_size=0.2")
+    ax.add_artist(box)
 
 
-class AnchoredDrawingArea(AnchoredOffsetbox):
-    def __init__(self, width, height, xdescent, ydescent,
-                 loc, pad=0.4, borderpad=0.5, prop=None, frameon=True):
-        self.da = DrawingArea(width, height, xdescent, ydescent)
-        super().__init__(loc, pad=pad, borderpad=borderpad,
-                         child=self.da, prop=None, frameon=frameon)
-
-
-def draw_circle(ax):
-    """
-    Draw a circle in axis coordinates
-    """
-    from matplotlib.patches import Circle
-    ada = AnchoredDrawingArea(20, 20, 0, 0,
-                              loc='upper right', pad=0., frameon=False)
-    p = Circle((10, 10), 10)
-    ada.da.add_artist(p)
-    ax.add_artist(ada)
-
-
-class AnchoredEllipse(AnchoredOffsetbox):
-    def __init__(self, transform, width, height, angle, loc,
-                 pad=0.1, borderpad=0.1, prop=None, frameon=True):
-        """
-        Draw an ellipse the size in data coordinate of the give axes.
-
-        pad, borderpad in fraction of the legend font size (or prop)
-        """
-        self._box = AuxTransformBox(transform)
-        self.ellipse = Ellipse((0, 0), width, height, angle)
-        self._box.add_artist(self.ellipse)
-        super().__init__(loc, pad=pad, borderpad=borderpad,
-                         child=self._box, prop=prop, frameon=frameon)
+def draw_circles(ax):
+    """Draw circles in axes coordinates."""
+    area = DrawingArea(40, 20, 0, 0)
+    area.add_artist(Circle((10, 10), 10, fc="tab:blue"))
+    area.add_artist(Circle((30, 10), 5, fc="tab:red"))
+    box = AnchoredOffsetbox(
+        child=area, loc="upper right", pad=0, frameon=False)
+    ax.add_artist(box)
 
 
 def draw_ellipse(ax):
-    """
-    Draw an ellipse of width=0.1, height=0.15 in data coordinates
-    """
-    ae = AnchoredEllipse(ax.transData, width=0.1, height=0.15, angle=0.,
-                         loc='lower left', pad=0.5, borderpad=0.4,
-                         frameon=True)
-
-    ax.add_artist(ae)
+    """Draw an ellipse of width=0.1, height=0.15 in data coordinates."""
+    aux_tr_box = AuxTransformBox(ax.transData)
+    aux_tr_box.add_artist(Ellipse((0, 0), width=0.1, height=0.15))
+    box = AnchoredOffsetbox(child=aux_tr_box, loc="lower left", frameon=True)
+    ax.add_artist(box)
 
 
 class AnchoredSizeBar(AnchoredOffsetbox):
@@ -93,13 +60,10 @@ class AnchoredSizeBar(AnchoredOffsetbox):
         """
         self.size_bar = AuxTransformBox(transform)
         self.size_bar.add_artist(Line2D([0, size], [0, 0], color="black"))
-
-        self.txt_label = TextArea(label, minimumdescent=False)
-
+        self.txt_label = TextArea(label)
         self._box = VPacker(children=[self.size_bar, self.txt_label],
                             align="center",
                             pad=0, sep=sep)
-
         super().__init__(loc, pad=pad, borderpad=borderpad,
                          child=self._box, prop=prop, frameon=frameon)
 
@@ -118,11 +82,11 @@ def draw_sizebar(ax):
     ax.add_artist(asb)
 
 
-ax = plt.gca()
-ax.set_aspect(1.)
+fig, ax = plt.subplots()
+ax.set_aspect(1)
 
 draw_text(ax)
-draw_circle(ax)
+draw_circles(ax)
 draw_ellipse(ax)
 draw_sizebar(ax)
 
