@@ -52,8 +52,9 @@ class GeoAxes(Axes):
         # self.spines['geo'].register_axis(self.yaxis)
         self._update_transScale()
 
-    def cla(self):
-        super().cla()
+    def clear(self):
+        # docstring inherited
+        super().clear()
 
         self.set_longitude_grid(30)
         self.set_latitude_grid(15)
@@ -270,14 +271,8 @@ class GeoAxes(Axes):
         In this case, we want them to be displayed in degrees N/S/E/W.
         """
         lon, lat = np.rad2deg([lon, lat])
-        if lat >= 0.0:
-            ns = 'N'
-        else:
-            ns = 'S'
-        if lon >= 0.0:
-            ew = 'E'
-        else:
-            ew = 'W'
+        ns = 'N' if lat >= 0.0 else 'S'
+        ew = 'E' if lon >= 0.0 else 'W'
         return ('%f\N{DEGREE SIGN}%s, %f\N{DEGREE SIGN}%s'
                 % (abs(lat), ns, abs(lon), ew))
 
@@ -430,7 +425,7 @@ class HammerAxes(GeoAxes):
         self._longitude_cap = np.pi / 2.0
         super().__init__(*args, **kwargs)
         self.set_aspect(0.5, adjustable='box', anchor='C')
-        self.cla()
+        self.clear()
 
     def _get_core_transform(self, resolution):
         return self.HammerTransform(resolution)
