@@ -20,7 +20,7 @@ parser = ArgumentParser(
     description="Build thumbnails of all images in a directory.")
 parser.add_argument("imagedir", type=Path)
 args = parser.parse_args()
-if not args.imagedir.isdir():
+if not args.imagedir.is_dir():
     sys.exit(f"Could not find input directory {args.imagedir}")
 
 outdir = Path("thumbs")
