@@ -41,10 +41,9 @@ for l in [l1, l2]:
     shadow.set_zorder(l.get_zorder() - 0.5)
 
     # offset transform
-    ot = mtransforms.offset_copy(l.get_transform(), fig1,
-                                 x=4.0, y=-6.0, units='points')
-
-    shadow.set_transform(ot)
+    transform = mtransforms.offset_copy(l.get_transform(), fig1,
+                                        x=4.0, y=-6.0, units='points')
+    shadow.set_transform(transform)
 
     # set the id for a later use
     shadow.set_gid(l.get_label() + "_shadow")
