@@ -3,11 +3,11 @@
 Filled contours
 ===============
 
-contourf differs from contour in that it creates filled contours, ie.
-a discrete number of colours are used to shade the domain.
+`.Axes3D.contourf` differs from `.Axes3D.contour` in that it creates filled
+contours, i.e. a discrete number of colours are used to shade the domain.
 
-This is like a contourf plot in 2D except that the shaded region corresponding
-to the level c is graphed on the plane z=c.
+This is like a `.Axes.contourf` plot in 2D except that the shaded region
+corresponding to the level c is graphed on the plane ``z=c``.
 """
 
 from mpl_toolkits.mplot3d import axes3d
