@@ -1,7 +1,7 @@
 """
-=================================
-2D and 3D *Axes* in same *Figure*
-=================================
+=============================
+2D and 3D axes in same figure
+=============================
 
 This example shows a how to plot a 2D and 3D plot on the same figure.
 """
