@@ -10,8 +10,8 @@ of 'jagged stained glass' effect.
 
 from matplotlib.collections import PolyCollection
 import matplotlib.pyplot as plt
+import math
 import numpy as np
-from scipy.stats import poisson
 
 # Fixing random state for reproducibility
 np.random.seed(19680801)
@@ -31,7 +31,9 @@ x = np.linspace(0., 10., 31)
 lambdas = range(1, 9)
 
 # verts[i] is a list of (x, y) pairs defining polygon i.
-verts = [polygon_under_graph(x, poisson.pmf(l, x)) for l in lambdas]
+gamma = np.vectorize(math.gamma)
+verts = [polygon_under_graph(x, l**x * np.exp(-l) / gamma(x + 1))
+         for l in lambdas]
 facecolors = plt.colormaps['viridis_r'](np.linspace(0, 1, len(verts)))
 
 poly = PolyCollection(verts, facecolors=facecolors, alpha=.7)
