@@ -6,7 +6,7 @@ More triangular 3D surfaces
 Two additional examples of plotting surfaces with triangular mesh.
 
 The first demonstrates use of plot_trisurf's triangles argument, and the
-second sets a Triangulation object's mask and passes the object directly
+second sets a `.Triangulation` object's mask and passes the object directly
 to plot_trisurf.
 """
 
