@@ -20,17 +20,16 @@ cube2 = (x >= 5) & (y >= 5) & (z >= 5)
 link = abs(x - y) + abs(y - z) + abs(z - x) <= 2
 
 # combine the objects into a single boolean array
-voxels = cube1 | cube2 | link
+voxelarray = cube1 | cube2 | link
 
 # set the colors of each object
-colors = np.empty(voxels.shape, dtype=object)
+colors = np.empty(voxelarray.shape, dtype=object)
 colors[link] = 'red'
 colors[cube1] = 'blue'
 colors[cube2] = 'green'
 
 # and plot everything
-fig = plt.figure()
-ax = fig.gca(projection='3d')
-ax.voxels(voxels, facecolors=colors, edgecolor='k')
+ax = plt.figure().add_subplot(projection='3d')
+ax.voxels(voxelarray, facecolors=colors, edgecolor='k')
 
 plt.show()
