@@ -1,6 +1,6 @@
 """
 ==========================================
-3D voxel / volumetric plot with rgb colors
+3D voxel / volumetric plot with RGB colors
 ==========================================
 
 Demonstrates using `.Axes3D.voxels` to visualize parts of a color space.
@@ -39,5 +39,6 @@ ax.voxels(r, g, b, sphere,
           edgecolors=np.clip(2*colors - 0.5, 0, 1),  # brighter
           linewidth=0.5)
 ax.set(xlabel='r', ylabel='g', zlabel='b')
+ax.set_aspect('equal')
 
 plt.show()
