@@ -3,7 +3,7 @@
 3D wireframe plots in one direction
 ===================================
 
-Demonstrates that setting rstride or cstride to 0 causes wires to not be
+Demonstrates that setting *rstride* or *cstride* to 0 causes wires to not be
 generated in the corresponding direction.
 """
 
