@@ -27,14 +27,10 @@ plt.show()
 
 #############################################################################
 #
-# ------------
+# .. admonition:: References
 #
-# References
-# """"""""""
+#    The use of the following functions, methods, classes and modules is shown
+#    in this example:
 #
-# The use of the following functions, methods, classes and modules is shown
-# in this example:
-
-import matplotlib
-matplotlib.pyplot.figure
-matplotlib.pyplot.subplot
+#    - `matplotlib.pyplot.figure`
+#    - `matplotlib.pyplot.subplot`
