@@ -7,6 +7,7 @@ Drawing a collection of ellipses. While this would equally be possible using
 a `~.collections.EllipseCollection` or `~.collections.PathCollection`, the use
 of an `~.collections.EllipseCollection` allows for much shorter code.
 """
+
 import matplotlib.pyplot as plt
 import numpy as np
 from matplotlib.collections import EllipseCollection
@@ -25,7 +26,7 @@ aa = X * 9
 fig, ax = plt.subplots()
 
 ec = EllipseCollection(ww, hh, aa, units='x', offsets=XY,
-                       transOffset=ax.transData)
+                       offset_transform=ax.transData)
 ec.set_array((X + Y).ravel())
 ax.add_collection(ec)
 ax.autoscale_view()
