@@ -16,8 +16,7 @@ with plt.xkcd():
 
     fig = plt.figure()
     ax = fig.add_axes((0.1, 0.2, 0.8, 0.7))
-    ax.spines.right.set_color('none')
-    ax.spines.top.set_color('none')
+    ax.spines[['top', 'right']].set_visible(False)
     ax.set_xticks([])
     ax.set_yticks([])
     ax.set_ylim([-30, 10])
@@ -47,8 +46,7 @@ with plt.xkcd():
     fig = plt.figure()
     ax = fig.add_axes((0.1, 0.2, 0.8, 0.7))
     ax.bar([0, 1], [0, 100], 0.25)
-    ax.spines.right.set_color('none')
-    ax.spines.top.set_color('none')
+    ax.spines[['top', 'right']].set_visible(False)
     ax.xaxis.set_ticks_position('bottom')
     ax.set_xticks([0, 1])
     ax.set_xticklabels(['CONFIRMED BY\nEXPERIMENT', 'REFUTED BY\nEXPERIMENT'])
