@@ -10,10 +10,11 @@ no figure with the number exists, a new one is created.
 
 .. note::
 
-    We discourage working with multiple figures in pyplot because managing
-    the *current figure* is cumbersome and error-prone. Instead, we recommend
-    to use the object-oriented approach and call methods on Figure and Axes
-    instances.
+    We discourage working with multiple figures through the implicit pyplot
+    interface because managing the *current figure* is cumbersome and
+    error-prone. Instead, we recommend using the explicit approach and call
+    methods on Figure and Axes instances. See :ref:`api_interfaces` for an
+    explanation of the trade-offs between the implicit and explicit interfaces.
 
 """
 import matplotlib.pyplot as plt
