@@ -33,23 +33,20 @@ axins.imshow(Z2, extent=extent, origin="lower")
 x1, x2, y1, y2 = -1.5, -0.9, -2.5, -1.9
 axins.set_xlim(x1, x2)
 axins.set_ylim(y1, y2)
-axins.set_xticklabels('')
-axins.set_yticklabels('')
+axins.set_xticklabels([])
+axins.set_yticklabels([])
 
-ax.indicate_inset_zoom(axins)
+ax.indicate_inset_zoom(axins, edgecolor="black")
 
 plt.show()
 
 #############################################################################
 #
-# ------------
+# .. admonition:: References
 #
-# References
-# """"""""""
+#    The use of the following functions, methods, classes and modules is shown
+#    in this example:
 #
-# The use of the following functions and methods is shown in this example:
-
-import matplotlib
-matplotlib.axes.Axes.inset_axes
-matplotlib.axes.Axes.indicate_inset_zoom
-matplotlib.axes.Axes.imshow
+#    - `matplotlib.axes.Axes.inset_axes`
+#    - `matplotlib.axes.Axes.indicate_inset_zoom`
+#    - `matplotlib.axes.Axes.imshow`
