@@ -19,7 +19,8 @@ want a legend item to show up for each one. If you simply plot the lines
 and call ``ax.legend()``, you will get the following:
 """
 # sphinx_gallery_thumbnail_number = 2
-from matplotlib import rcParams, cycler
+import matplotlib as mpl
+from matplotlib import cycler
 import matplotlib.pyplot as plt
 import numpy as np
 
@@ -29,7 +30,7 @@ np.random.seed(19680801)
 N = 10
 data = (np.geomspace(1, 10, 100) + np.random.randn(N, 100)).T
 cmap = plt.cm.coolwarm
-rcParams['axes.prop_cycle'] = cycler(color=cmap(np.linspace(0, 1, N)))
+mpl.rcParams['axes.prop_cycle'] = cycler(color=cmap(np.linspace(0, 1, N)))
 
 fig, ax = plt.subplots()
 lines = ax.plot(data)
