@@ -1,8 +1,7 @@
 """
 =======================
-Matplotlib With Glade 3
+Matplotlib with Glade 3
 =======================
-
 """
 
 from pathlib import Path
@@ -32,7 +31,7 @@ def main():
 
     # Start of Matplotlib specific code
     figure = Figure(figsize=(8, 6), dpi=71)
-    axis = figure.add_subplot(111)
+    axis = figure.add_subplot()
     t = np.arange(0.0, 3.0, 0.01)
     s = np.sin(2*np.pi*t)
     axis.plot(t, s)
