@@ -3,9 +3,9 @@
 subplot2grid demo
 =================
 
-This example demonstrates the use of `plt.subplot2grid` to generate subplots.
-Using `GridSpec`, as demonstrated in :doc:`/gallery/userdemo/demo_gridspec03`
-is generally preferred.
+This example demonstrates the use of `.pyplot.subplot2grid` to generate
+subplots.  Using `.GridSpec`, as demonstrated in
+:doc:`/gallery/userdemo/demo_gridspec03` is generally preferred.
 """
 
 import matplotlib.pyplot as plt
