@@ -29,9 +29,10 @@ for a in range(4):
 
 # show only the outside spines
 for ax in fig.get_axes():
-    ax.spines['top'].set_visible(ax.is_first_row())
-    ax.spines['bottom'].set_visible(ax.is_last_row())
-    ax.spines['left'].set_visible(ax.is_first_col())
-    ax.spines['right'].set_visible(ax.is_last_col())
+    ss = ax.get_subplotspec()
+    ax.spines.top.set_visible(ss.is_first_row())
+    ax.spines.bottom.set_visible(ss.is_last_row())
+    ax.spines.left.set_visible(ss.is_first_col())
+    ax.spines.right.set_visible(ss.is_last_col())
 
 plt.show()
