@@ -12,6 +12,7 @@ the ``Slider`` snap to discrete values.
 See :doc:`/gallery/widgets/range_slider` for an example of using
 a ``RangeSlider`` to define a range of values.
 """
+
 import numpy as np
 import matplotlib.pyplot as plt
 from matplotlib.widgets import Slider, Button
@@ -29,14 +30,14 @@ init_frequency = 3
 
 # Create the figure and the line that we will manipulate
 fig, ax = plt.subplots()
-line, = plt.plot(t, f(t, init_amplitude, init_frequency), lw=2)
+line, = ax.plot(t, f(t, init_amplitude, init_frequency), lw=2)
 ax.set_xlabel('Time [s]')
 
 # adjust the main plot to make room for the sliders
-plt.subplots_adjust(left=0.25, bottom=0.25)
+fig.subplots_adjust(left=0.25, bottom=0.25)
 
 # Make a horizontal slider to control the frequency.
-axfreq = plt.axes([0.25, 0.1, 0.65, 0.03])
+axfreq = fig.add_axes([0.25, 0.1, 0.65, 0.03])
 freq_slider = Slider(
     ax=axfreq,
     label='Frequency [Hz]',
@@ -46,7 +47,7 @@ freq_slider = Slider(
 )
 
 # Make a vertically oriented slider to control the amplitude
-axamp = plt.axes([0.1, 0.25, 0.0225, 0.63])
+axamp = fig.add_axes([0.1, 0.25, 0.0225, 0.63])
 amp_slider = Slider(
     ax=axamp,
     label="Amplitude",
@@ -68,7 +69,7 @@ freq_slider.on_changed(update)
 amp_slider.on_changed(update)
 
 # Create a `matplotlib.widgets.Button` to reset the sliders to initial values.
-resetax = plt.axes([0.8, 0.025, 0.1, 0.04])
+resetax = fig.add_axes([0.8, 0.025, 0.1, 0.04])
 button = Button(resetax, 'Reset', hovercolor='0.975')
 
 
