@@ -11,20 +11,7 @@ using `~matplotlib.gridspec.GridSpecFromSubplotSpec`).  Axes placed using
 layout.  Axes manually placed via ``figure.add_axes()`` will not.
 
 See Tutorial: :doc:`/tutorials/intermediate/constrainedlayout_guide`
-"""
 
-import logging
-
-import numpy as np
-
-from matplotlib import _api
-import matplotlib.transforms as mtransforms
-import matplotlib._layoutgrid as mlayoutgrid
-
-
-_log = logging.getLogger(__name__)
-
-"""
 General idea:
 -------------
 
@@ -33,8 +20,8 @@ with heights and widths set by ``height_ratios`` and ``width_ratios``,
 often just set to 1 for an equal grid.
 
 Subplotspecs that are derived from this gridspec can contain either a
-``SubPanel``, a ``GridSpecFromSubplotSpec``, or an axes.  The ``SubPanel`` and
-``GridSpecFromSubplotSpec`` are dealt with recursively and each contain an
+``SubPanel``, a ``GridSpecFromSubplotSpec``, or an ``Axes``.  The ``SubPanel``
+and ``GridSpecFromSubplotSpec`` are dealt with recursively and each contain an
 analogous layout.
 
 Each ``GridSpec`` has a ``_layoutgrid`` attached to it.  The ``_layoutgrid``
@@ -60,10 +47,22 @@ See the tutorial doc:`/tutorials/intermediate/constrainedlayout_guide`
 for more discussion of the algorithm with examples.
 """
 
+import logging
+
+import numpy as np
+
+from matplotlib import _api, artist as martist
+import matplotlib.transforms as mtransforms
+import matplotlib._layoutgrid as mlayoutgrid
+
+
+_log = logging.getLogger(__name__)
+
 
 ######################################################
-def do_constrained_layout(fig, renderer, h_pad, w_pad,
-                          hspace=None, wspace=None):
+def do_constrained_layout(fig, h_pad, w_pad,
+                          hspace=None, wspace=None, rect=(0, 0, 1, 1),
+                          compress=False):
     """
     Do the constrained_layout.  Called at draw time in
      ``figure.constrained_layout()``
@@ -86,13 +85,23 @@ def do_constrained_layout(fig, renderer, h_pad, w_pad,
        of 0.1 of the figure width between each column.
        If h/wspace < h/w_pad, then the pads are used instead.
 
+    rect : tuple of 4 floats
+        Rectangle in figure coordinates to perform constrained layout in
+        [left, bottom, width, height], each from 0-1.
+
+    compress : bool
+        Whether to shift Axes so that white space in between them is
+        removed. This is useful for simple grids of fixed-aspect Axes (e.g.
+        a grid of images).
+
     Returns
     -------
     layoutgrid : private debugging structure
     """
 
+    renderer = fig._get_renderer()
     # make layoutgrid tree...
-    layoutgrids = make_layoutgrids(fig, None)
+    layoutgrids = make_layoutgrids(fig, None, rect=rect)
     if not layoutgrids['hasgrids']:
         _api.warn_external('There are no gridspecs with layoutgrids. '
                            'Possibly did not call parent GridSpec with the'
@@ -120,18 +129,27 @@ def do_constrained_layout(fig, renderer, h_pad, w_pad,
         # update all the variables in the layout.
         layoutgrids[fig].update_variables()
 
+        warn_collapsed = ('constrained_layout not applied because '
+                          'axes sizes collapsed to zero.  Try making '
+                          'figure larger or axes decorations smaller.')
         if check_no_collapsed_axes(layoutgrids, fig):
             reposition_axes(layoutgrids, fig, renderer, h_pad=h_pad,
                             w_pad=w_pad, hspace=hspace, wspace=wspace)
+            if compress:
+                layoutgrids = compress_fixed_aspect(layoutgrids, fig)
+                layoutgrids[fig].update_variables()
+                if check_no_collapsed_axes(layoutgrids, fig):
+                    reposition_axes(layoutgrids, fig, renderer, h_pad=h_pad,
+                                    w_pad=w_pad, hspace=hspace, wspace=wspace)
+                else:
+                    _api.warn_external(warn_collapsed)
         else:
-            _api.warn_external('constrained_layout not applied because '
-                               'axes sizes collapsed to zero.  Try making '
-                               'figure larger or axes decorations smaller.')
+            _api.warn_external(warn_collapsed)
         reset_margins(layoutgrids, fig)
     return layoutgrids
 
 
-def make_layoutgrids(fig, layoutgrids):
+def make_layoutgrids(fig, layoutgrids, rect=(0, 0, 1, 1)):
     """
     Make the layoutgrid tree.
 
@@ -145,8 +163,9 @@ def make_layoutgrids(fig, layoutgrids):
         layoutgrids = dict()
         layoutgrids['hasgrids'] = False
     if not hasattr(fig, '_parent'):
-        # top figure
-        layoutgrids[fig] = mlayoutgrid.LayoutGrid(parent=None, name='figlb')
+        # top figure;  pass rect as parent to allow user-specified
+        # margins
+        layoutgrids[fig] = mlayoutgrid.LayoutGrid(parent=rect, name='figlb')
     else:
         # subfigure
         gs = fig._subplotspec.get_gridspec()
@@ -167,7 +186,7 @@ def make_layoutgrids(fig, layoutgrids):
         layoutgrids = make_layoutgrids(sfig, layoutgrids)
 
     # for each axes at the local level add its gridspec:
-    for ax in fig._localaxes.as_list():
+    for ax in fig._localaxes:
         if hasattr(ax, 'get_subplotspec'):
             gs = ax.get_subplotspec().get_gridspec()
             layoutgrids = make_layoutgrids_gs(layoutgrids, gs)
@@ -204,14 +223,16 @@ def make_layoutgrids_gs(layoutgrids, gs):
             layoutgrids = make_layoutgrids_gs(layoutgrids, parentgs)
         subspeclb = layoutgrids[parentgs]
         # gridspecfromsubplotspec need an outer container:
-        if f'{gs}top' not in layoutgrids:
-            layoutgrids[f'{gs}top'] = mlayoutgrid.LayoutGrid(
+        # get a unique representation:
+        rep = (gs, 'top')
+        if rep not in layoutgrids:
+            layoutgrids[rep] = mlayoutgrid.LayoutGrid(
                 parent=subspeclb,
                 name='top',
                 nrows=1, ncols=1,
                 parent_pos=(subplot_spec.rowspan, subplot_spec.colspan))
         layoutgrids[gs] = mlayoutgrid.LayoutGrid(
-                parent=layoutgrids[f'{gs}top'],
+                parent=layoutgrids[rep],
                 name='gridspec',
                 nrows=gs._nrows, ncols=gs._ncols,
                 width_ratios=gs.get_width_ratios(),
@@ -241,6 +262,43 @@ def check_no_collapsed_axes(layoutgrids, fig):
     return True
 
 
+def compress_fixed_aspect(layoutgrids, fig):
+    gs = None
+    for ax in fig.axes:
+        if not hasattr(ax, 'get_subplotspec'):
+            continue
+        ax.apply_aspect()
+        sub = ax.get_subplotspec()
+        _gs = sub.get_gridspec()
+        if gs is None:
+            gs = _gs
+            extraw = np.zeros(gs.ncols)
+            extrah = np.zeros(gs.nrows)
+        elif _gs != gs:
+            raise ValueError('Cannot do compressed layout if axes are not'
+                                'all from the same gridspec')
+        orig = ax.get_position(original=True)
+        actual = ax.get_position(original=False)
+        dw = orig.width - actual.width
+        if dw > 0:
+            extraw[sub.colspan] = np.maximum(extraw[sub.colspan], dw)
+        dh = orig.height - actual.height
+        if dh > 0:
+            extrah[sub.rowspan] = np.maximum(extrah[sub.rowspan], dh)
+
+    if gs is None:
+        raise ValueError('Cannot do compressed layout if no axes '
+                         'are part of a gridspec.')
+    w = np.sum(extraw) / 2
+    layoutgrids[fig].edit_margin_min('left', w)
+    layoutgrids[fig].edit_margin_min('right', w)
+
+    h = np.sum(extrah) / 2
+    layoutgrids[fig].edit_margin_min('top', h)
+    layoutgrids[fig].edit_margin_min('bottom', h)
+    return layoutgrids
+
+
 def get_margin_from_padding(obj, *, w_pad=0, h_pad=0,
                             hspace=0, wspace=0):
 
@@ -298,7 +356,7 @@ def make_layout_margins(layoutgrids, fig, renderer, *, w_pad=0, h_pad=0,
                                           hspace=hspace, wspace=wspace)
         layoutgrids[sfig].parent.edit_outer_margin_mins(margins, ss)
 
-    for ax in fig._localaxes.as_list():
+    for ax in fig._localaxes:
         if not hasattr(ax, 'get_subplotspec') or not ax.get_in_layout():
             continue
 
@@ -534,17 +592,12 @@ def get_pos_and_bbox(ax, renderer):
         Position in figure coordinates.
     bbox : Bbox
         Tight bounding box in figure coordinates.
-
     """
     fig = ax.figure
     pos = ax.get_position(original=True)
     # pos is in panel co-ords, but we need in figure for the layout
     pos = pos.transformed(fig.transSubfigure - fig.transFigure)
-    try:
-        tightbbox = ax.get_tightbbox(renderer=renderer, for_layout_only=True)
-    except TypeError:
-        tightbbox = ax.get_tightbbox(renderer=renderer)
-
+    tightbbox = martist._get_tightbbox_for_layout_only(ax, renderer)
     if tightbbox is None:
         bbox = pos
     else:
@@ -566,7 +619,7 @@ def reposition_axes(layoutgrids, fig, renderer, *,
                         w_pad=w_pad, h_pad=h_pad,
                         wspace=wspace, hspace=hspace)
 
-    for ax in fig._localaxes.as_list():
+    for ax in fig._localaxes:
         if not hasattr(ax, 'get_subplotspec') or not ax.get_in_layout():
             continue
 
@@ -574,7 +627,6 @@ def reposition_axes(layoutgrids, fig, renderer, *,
         # coordinates...
         ss = ax.get_subplotspec()
         gs = ss.get_gridspec()
-        nrows, ncols = gs.get_geometry()
         if gs not in layoutgrids:
             return
 
