@@ -132,7 +132,7 @@ latex_to_bakoma = {
     ']'                          : ('cmr10', 0x5d),
 
     '*'                          : ('cmsy10', 0xa4),
-    '-'                          : ('cmsy10', 0xa1),
+    '\N{MINUS SIGN}'             : ('cmsy10', 0xa1),
     '\\Downarrow'                : ('cmsy10', 0x2b),
     '\\Im'                       : ('cmsy10', 0x3d),
     '\\Leftarrow'                : ('cmsy10', 0x28),
@@ -236,173 +236,6 @@ latex_to_bakoma = {
     '\\_'                        : ('cmtt10', 0x5f)
 }
 
-latex_to_cmex = {  # Unused; delete once mathtext becomes private.
-    r'\__sqrt__'   : 112,
-    r'\bigcap'     : 92,
-    r'\bigcup'     : 91,
-    r'\bigodot'    : 75,
-    r'\bigoplus'   : 77,
-    r'\bigotimes'  : 79,
-    r'\biguplus'   : 93,
-    r'\bigvee'     : 95,
-    r'\bigwedge'   : 94,
-    r'\coprod'     : 97,
-    r'\int'        : 90,
-    r'\leftangle'  : 173,
-    r'\leftbrace'  : 169,
-    r'\oint'       : 73,
-    r'\prod'       : 89,
-    r'\rightangle' : 174,
-    r'\rightbrace' : 170,
-    r'\sum'        : 88,
-    r'\widehat'    : 98,
-    r'\widetilde'  : 101,
-}
-
-latex_to_standard = {
-    r'\cong'                     : ('psyr', 64),
-    r'\Delta'                    : ('psyr', 68),
-    r'\Phi'                      : ('psyr', 70),
-    r'\Gamma'                    : ('psyr', 89),
-    r'\alpha'                    : ('psyr', 97),
-    r'\beta'                     : ('psyr', 98),
-    r'\chi'                      : ('psyr', 99),
-    r'\delta'                    : ('psyr', 100),
-    r'\varepsilon'               : ('psyr', 101),
-    r'\phi'                      : ('psyr', 102),
-    r'\gamma'                    : ('psyr', 103),
-    r'\eta'                      : ('psyr', 104),
-    r'\iota'                     : ('psyr', 105),
-    r'\varphi'                   : ('psyr', 106),
-    r'\kappa'                    : ('psyr', 108),
-    r'\nu'                       : ('psyr', 110),
-    r'\pi'                       : ('psyr', 112),
-    r'\theta'                    : ('psyr', 113),
-    r'\rho'                      : ('psyr', 114),
-    r'\sigma'                    : ('psyr', 115),
-    r'\tau'                      : ('psyr', 116),
-    r'\upsilon'                  : ('psyr', 117),
-    r'\varpi'                    : ('psyr', 118),
-    r'\omega'                    : ('psyr', 119),
-    r'\xi'                       : ('psyr', 120),
-    r'\psi'                      : ('psyr', 121),
-    r'\zeta'                     : ('psyr', 122),
-    r'\sim'                      : ('psyr', 126),
-    r'\leq'                      : ('psyr', 163),
-    r'\infty'                    : ('psyr', 165),
-    r'\clubsuit'                 : ('psyr', 167),
-    r'\diamondsuit'              : ('psyr', 168),
-    r'\heartsuit'                : ('psyr', 169),
-    r'\spadesuit'                : ('psyr', 170),
-    r'\leftrightarrow'           : ('psyr', 171),
-    r'\leftarrow'                : ('psyr', 172),
-    r'\uparrow'                  : ('psyr', 173),
-    r'\rightarrow'               : ('psyr', 174),
-    r'\downarrow'                : ('psyr', 175),
-    r'\pm'                       : ('psyr', 176),
-    r'\geq'                      : ('psyr', 179),
-    r'\times'                    : ('psyr', 180),
-    r'\propto'                   : ('psyr', 181),
-    r'\partial'                  : ('psyr', 182),
-    r'\bullet'                   : ('psyr', 183),
-    r'\div'                      : ('psyr', 184),
-    r'\neq'                      : ('psyr', 185),
-    r'\equiv'                    : ('psyr', 186),
-    r'\approx'                   : ('psyr', 187),
-    r'\ldots'                    : ('psyr', 188),
-    r'\aleph'                    : ('psyr', 192),
-    r'\Im'                       : ('psyr', 193),
-    r'\Re'                       : ('psyr', 194),
-    r'\wp'                       : ('psyr', 195),
-    r'\otimes'                   : ('psyr', 196),
-    r'\oplus'                    : ('psyr', 197),
-    r'\oslash'                   : ('psyr', 198),
-    r'\cap'                      : ('psyr', 199),
-    r'\cup'                      : ('psyr', 200),
-    r'\supset'                   : ('psyr', 201),
-    r'\supseteq'                 : ('psyr', 202),
-    r'\subset'                   : ('psyr', 204),
-    r'\subseteq'                 : ('psyr', 205),
-    r'\in'                       : ('psyr', 206),
-    r'\notin'                    : ('psyr', 207),
-    r'\angle'                    : ('psyr', 208),
-    r'\nabla'                    : ('psyr', 209),
-    r'\textregistered'           : ('psyr', 210),
-    r'\copyright'                : ('psyr', 211),
-    r'\texttrademark'            : ('psyr', 212),
-    r'\Pi'                       : ('psyr', 213),
-    r'\prod'                     : ('psyr', 213),
-    r'\surd'                     : ('psyr', 214),
-    r'\__sqrt__'                 : ('psyr', 214),
-    r'\cdot'                     : ('psyr', 215),
-    r'\urcorner'                 : ('psyr', 216),
-    r'\vee'                      : ('psyr', 217),
-    r'\wedge'                    : ('psyr', 218),
-    r'\Leftrightarrow'           : ('psyr', 219),
-    r'\Leftarrow'                : ('psyr', 220),
-    r'\Uparrow'                  : ('psyr', 221),
-    r'\Rightarrow'               : ('psyr', 222),
-    r'\Downarrow'                : ('psyr', 223),
-    r'\Diamond'                  : ('psyr', 224),
-    r'\Sigma'                    : ('psyr', 229),
-    r'\sum'                      : ('psyr', 229),
-    r'\forall'                   : ('psyr',  34),
-    r'\exists'                   : ('psyr',  36),
-    r'\lceil'                    : ('psyr', 233),
-    r'\lbrace'                   : ('psyr', 123),
-    r'\Psi'                      : ('psyr',  89),
-    r'\bot'                      : ('psyr', 0o136),
-    r'\Omega'                    : ('psyr', 0o127),
-    r'\leftbracket'              : ('psyr', 0o133),
-    r'\rightbracket'             : ('psyr', 0o135),
-    r'\leftbrace'                : ('psyr', 123),
-    r'\leftparen'                : ('psyr', 0o50),
-    r'\prime'                    : ('psyr', 0o242),
-    r'\sharp'                    : ('psyr', 0o43),
-    r'\slash'                    : ('psyr', 0o57),
-    r'\Lambda'                   : ('psyr', 0o114),
-    r'\neg'                      : ('psyr', 0o330),
-    r'\Upsilon'                  : ('psyr', 0o241),
-    r'\rightbrace'               : ('psyr', 0o175),
-    r'\rfloor'                   : ('psyr', 0o373),
-    r'\lambda'                   : ('psyr', 0o154),
-    r'\to'                       : ('psyr', 0o256),
-    r'\Xi'                       : ('psyr', 0o130),
-    r'\emptyset'                 : ('psyr', 0o306),
-    r'\lfloor'                   : ('psyr', 0o353),
-    r'\rightparen'               : ('psyr', 0o51),
-    r'\rceil'                    : ('psyr', 0o371),
-    r'\ni'                       : ('psyr', 0o47),
-    r'\epsilon'                  : ('psyr', 0o145),
-    r'\Theta'                    : ('psyr', 0o121),
-    r'\langle'                   : ('psyr', 0o341),
-    r'\leftangle'                : ('psyr', 0o341),
-    r'\rangle'                   : ('psyr', 0o361),
-    r'\rightangle'               : ('psyr', 0o361),
-    r'\rbrace'                   : ('psyr', 0o175),
-    r'\circ'                     : ('psyr', 0o260),
-    r'\diamond'                  : ('psyr', 0o340),
-    r'\mu'                       : ('psyr', 0o155),
-    r'\mid'                      : ('psyr', 0o352),
-    r'\imath'                    : ('pncri8a', 105),
-    r'\%'                        : ('pncr8a',  37),
-    r'\$'                        : ('pncr8a',  36),
-    r'\{'                        : ('pncr8a', 123),
-    r'\}'                        : ('pncr8a', 125),
-    r'\backslash'                : ('pncr8a',  92),
-    r'\ast'                      : ('pncr8a',  42),
-    r'\#'                        : ('pncr8a',  35),
-
-    r'\circumflexaccent'         : ('pncri8a',   124), # for \hat
-    r'\combiningbreve'           : ('pncri8a',   81),  # for \breve
-    r'\combininggraveaccent'     : ('pncri8a', 114), # for \grave
-    r'\combiningacuteaccent'     : ('pncri8a', 63), # for \accute
-    r'\combiningdiaeresis'       : ('pncri8a', 91), # for \ddot
-    r'\combiningtilde'           : ('pncri8a', 75), # for \tilde
-    r'\combiningrightarrowabove' : ('pncri8a', 110), # for \vec
-    r'\combiningdotabove'        : ('pncri8a', 26), # for \dot
-}
-
 # Automatically generated.
 
 type12uni = {
@@ -1116,6 +949,7 @@ tex2uni = {
     'cwopencirclearrow'        : 8635,
     'geqq'                     : 8807,
     'rightleftarrows'          : 8644,
+    'aa'                       : 229,
     'ac'                       : 8766,
     'ae'                       : 230,
     'int'                      : 8747,
