@@ -6,6 +6,19 @@ var comm_websocket_adapter = function (comm) {
     // socket, so there is still some room for performance tuning.
     var ws = {};
 
+    ws.binaryType = comm.kernel.ws.binaryType;
+    ws.readyState = comm.kernel.ws.readyState;
+    function updateReadyState(_event) {
+        if (comm.kernel.ws) {
+            ws.readyState = comm.kernel.ws.readyState;
+        } else {
+            ws.readyState = 3; // Closed state.
+        }
+    }
+    comm.kernel.ws.addEventListener('open', updateReadyState);
+    comm.kernel.ws.addEventListener('close', updateReadyState);
+    comm.kernel.ws.addEventListener('error', updateReadyState);
+
     ws.close = function () {
         comm.close();
     };
@@ -16,8 +29,14 @@ var comm_websocket_adapter = function (comm) {
     // Register the callback with on_msg.
     comm.on_msg(function (msg) {
         //console.log('receiving', msg['content']['data'], msg);
+        var data = msg['content']['data'];
+        if (data['blob'] !== undefined) {
+            data = {
+                data: new Blob(msg['buffers'], { type: data['blob'] }),
+            };
+        }
         // Pass the mpl event to the overridden (by mpl) onmessage function.
-        ws.onmessage(msg['content']['data']);
+        ws.onmessage(data);
     });
     return ws;
 };
@@ -48,11 +67,20 @@ mpl.mpl_figure_comm = function (comm, msg) {
         console.error('Failed to find cell for figure', id, fig);
         return;
     }
+    fig.cell_info[0].output_area.element.on(
+        'cleared',
+        { fig: fig },
+        fig._remove_fig_handler
+    );
 };
 
 mpl.figure.prototype.handle_close = function (fig, msg) {
-    var width = fig.canvas.width / mpl.ratio;
-    fig.root.removeEventListener('remove', this._remove_fig_handler);
+    var width = fig.canvas.width / fig.ratio;
+    fig.cell_info[0].output_area.element.off(
+        'cleared',
+        fig._remove_fig_handler
+    );
+    fig.resizeObserverInstance.unobserve(fig.canvas_div);
 
     // Update the output cell to use the data from the current canvas.
     fig.push_to_output();
@@ -72,7 +100,7 @@ mpl.figure.prototype.close_ws = function (fig, msg) {
 
 mpl.figure.prototype.push_to_output = function (_remove_interactive) {
     // Turn the data on the canvas into data in the output cell.
-    var width = this.canvas.width / mpl.ratio;
+    var width = this.canvas.width / this.ratio;
     var dataURL = this.canvas.toDataURL();
     this.cell_info[1]['text/html'] =
         '<img src="' + dataURL + '" width="' + width + '">';
@@ -171,13 +199,17 @@ mpl.figure.prototype._init_toolbar = function () {
     titlebar.insertBefore(buttongrp, titlebar.firstChild);
 };
 
-mpl.figure.prototype._remove_fig_handler = function () {
-    this.close_ws(this, {});
+mpl.figure.prototype._remove_fig_handler = function (event) {
+    var fig = event.data.fig;
+    if (event.target !== this) {
+        // Ignore bubbled events from children.
+        return;
+    }
+    fig.close_ws(fig, {});
 };
 
 mpl.figure.prototype._root_extra_style = function (el) {
     el.style.boxSizing = 'content-box'; // override notebook setting of border-box.
-    el.addEventListener('remove', this._remove_fig_handler);
 };
 
 mpl.figure.prototype._canvas_extra_style = function (el) {
@@ -196,11 +228,6 @@ mpl.figure.prototype._canvas_extra_style = function (el) {
 };
 
 mpl.figure.prototype._key_event_extra = function (event, _name) {
-    var manager = IPython.notebook.keyboard_manager;
-    if (!manager) {
-        manager = IPython.keyboard_manager;
-    }
-
     // Check for shift+enter
     if (event.shiftKey && event.which === 13) {
         this.canvas_div.blur();
