@@ -22,25 +22,25 @@ import sys
 import time
 import traceback
 import types
-import warnings
 import weakref
 
 import numpy as np
 
 import matplotlib
 from matplotlib import _api, _c_internal_utils
-from matplotlib._api.deprecation import (
-    MatplotlibDeprecationWarning, mplDeprecation)
 
 
-@_api.deprecated("3.4")
-def deprecated(*args, **kwargs):
-    return _api.deprecated(*args, **kwargs)
-
-
-@_api.deprecated("3.4")
-def warn_deprecated(*args, **kwargs):
-    _api.warn_deprecated(*args, **kwargs)
+@_api.caching_module_getattr
+class __getattr__:
+    # module-level deprecations
+    MatplotlibDeprecationWarning = _api.deprecated(
+        "3.6", obj_type="",
+        alternative="matplotlib.MatplotlibDeprecationWarning")(
+        property(lambda self: _api.deprecation.MatplotlibDeprecationWarning))
+    mplDeprecation = _api.deprecated(
+        "3.6", obj_type="",
+        alternative="matplotlib.MatplotlibDeprecationWarning")(
+        property(lambda self: _api.deprecation.MatplotlibDeprecationWarning))
 
 
 def _get_running_interactive_framework():
@@ -132,9 +132,9 @@ class CallbackRegistry:
     for a set of signals and callbacks:
 
         >>> def oneat(x):
-        ...    print('eat', x)
+        ...     print('eat', x)
         >>> def ondrink(x):
-        ...    print('drink', x)
+        ...     print('drink', x)
 
         >>> from matplotlib.cbook import CallbackRegistry
         >>> callbacks = CallbackRegistry()
@@ -146,13 +146,13 @@ class CallbackRegistry:
         drink 123
         >>> callbacks.process('eat', 456)
         eat 456
-        >>> callbacks.process('be merry', 456) # nothing will be called
+        >>> callbacks.process('be merry', 456)   # nothing will be called
 
         >>> callbacks.disconnect(id_eat)
-        >>> callbacks.process('eat', 456)      # nothing will be called
+        >>> callbacks.process('eat', 456)        # nothing will be called
 
         >>> with callbacks.blocked(signal='drink'):
-        ...     callbacks.process('drink', 123) # nothing will be called
+        ...     callbacks.process('drink', 123)  # nothing will be called
         >>> callbacks.process('drink', 123)
         drink 123
 
@@ -175,13 +175,20 @@ class CallbackRegistry:
        The default handler prints the exception (with `traceback.print_exc`) if
        an interactive event loop is running; it re-raises the exception if no
        interactive event loop is running.
+
+    signals : list, optional
+        If not None, *signals* is a list of signals that this registry handles:
+        attempting to `process` or to `connect` to a signal not in the list
+        throws a `ValueError`.  The default, None, does not restrict the
+        handled signals.
     """
 
     # We maintain two mappings:
     #   callbacks: signal -> {cid -> weakref-to-callback}
     #   _func_cid_map: signal -> {weakref-to-callback -> cid}
 
-    def __init__(self, exception_handler=_exception_printer):
+    def __init__(self, exception_handler=_exception_printer, *, signals=None):
+        self._signals = None if signals is None else list(signals)  # Copy it.
         self.exception_handler = exception_handler
         self.callbacks = {}
         self._cid_gen = itertools.count()
@@ -211,12 +218,13 @@ class CallbackRegistry:
             s: {proxy: cid for cid, proxy in d.items()}
             for s, d in self.callbacks.items()}
 
-    @_api.rename_parameter("3.4", "s", "signal")
     def connect(self, signal, func):
         """Register *func* to be called when signal *signal* is generated."""
         if signal == "units finalize":
             _api.warn_deprecated(
                 "3.5", name=signal, obj_type="signal", alternative="units")
+        if self._signals is not None:
+            _api.check_in_list(self._signals, signal=signal)
         self._func_cid_map.setdefault(signal, {})
         proxy = _weak_or_strong_ref(func, self._remove_proxy)
         if proxy in self._func_cid_map[signal]:
@@ -227,6 +235,16 @@ class CallbackRegistry:
         self.callbacks[signal][cid] = proxy
         return cid
 
+    def _connect_picklable(self, signal, func):
+        """
+        Like `.connect`, but the callback is kept when pickling/unpickling.
+
+        Currently internal-use only.
+        """
+        cid = self.connect(signal, func)
+        self._pickled_cids.add(cid)
+        return cid
+
     # Keep a reference to sys.is_finalizing, as sys may have been cleared out
     # at that point.
     def _remove_proxy(self, proxy, *, _is_finalizing=sys.is_finalizing):
@@ -280,6 +298,8 @@ class CallbackRegistry:
         All of the functions registered to receive callbacks on *s* will be
         called with ``*args`` and ``**kwargs``.
         """
+        if self._signals is not None:
+            _api.check_in_list(self._signals, signal=s)
         for cid, ref in list(self.callbacks.get(s, {}).items()):
             func = ref()
             if func is not None:
@@ -354,7 +374,8 @@ class silent_list(list):
 
 
 def _local_over_kwdict(
-        local_var, kwargs, *keys, warning_cls=MatplotlibDeprecationWarning):
+        local_var, kwargs, *keys,
+        warning_cls=_api.MatplotlibDeprecationWarning):
     out = local_var
     for key in keys:
         kwarg_val = kwargs.pop(key, None)
@@ -390,6 +411,26 @@ def strip_math(s):
     return s
 
 
+def _strip_comment(s):
+    """Strip everything from the first unquoted #."""
+    pos = 0
+    while True:
+        quote_pos = s.find('"', pos)
+        hash_pos = s.find('#', pos)
+        if quote_pos < 0:
+            without_comment = s if hash_pos < 0 else s[:hash_pos]
+            return without_comment.strip()
+        elif 0 <= hash_pos < quote_pos:
+            return s[:hash_pos].strip()
+        else:
+            closing_quote_pos = s.find('"', quote_pos + 1)
+            if closing_quote_pos < 0:
+                raise ValueError(
+                    f"Missing closing quote in: {s!r}. If you need a double-"
+                    'quote inside a string, use escaping: e.g. "the \" char"')
+            pos = closing_quote_pos + 1  # behind closing quote
+
+
 def is_writable_file_like(obj):
     """Return whether *obj* looks like a file object with a *write* method."""
     return callable(getattr(obj, 'write', None))
@@ -540,6 +581,7 @@ def flatten(seq, scalarp=is_scalar_or_string):
             yield from flatten(item, scalarp)
 
 
+@_api.deprecated("3.6", alternative="functools.lru_cache")
 class maxdict(dict):
     """
     A dictionary with a maximum size.
@@ -876,6 +918,34 @@ class Grouper:
         return [x() for x in siblings]
 
 
+class GrouperView:
+    """Immutable view over a `.Grouper`."""
+
+    def __init__(self, grouper):
+        self._grouper = grouper
+
+    class _GrouperMethodForwarder:
+        def __init__(self, deprecated_kw=None):
+            self._deprecated_kw = deprecated_kw
+
+        def __set_name__(self, owner, name):
+            wrapped = getattr(Grouper, name)
+            forwarder = functools.wraps(wrapped)(
+                lambda self, *args, **kwargs: wrapped(
+                    self._grouper, *args, **kwargs))
+            if self._deprecated_kw:
+                forwarder = _api.deprecated(**self._deprecated_kw)(forwarder)
+            setattr(owner, name, forwarder)
+
+    __contains__ = _GrouperMethodForwarder()
+    __iter__ = _GrouperMethodForwarder()
+    joined = _GrouperMethodForwarder()
+    get_siblings = _GrouperMethodForwarder()
+    clean = _GrouperMethodForwarder(deprecated_kw=dict(since="3.6"))
+    join = _GrouperMethodForwarder(deprecated_kw=dict(since="3.6"))
+    remove = _GrouperMethodForwarder(deprecated_kw=dict(since="3.6"))
+
+
 def simple_linear_interpolation(a, steps):
     """
     Resample an array with ``steps - 1`` points between original point pairs.
@@ -948,7 +1018,7 @@ def delete_masked_points(*args):
             else:
                 x = np.asarray(x)
         margs.append(x)
-    masks = []    # list of masks that are True where good
+    masks = []  # List of masks that are True where good.
     for i, x in enumerate(margs):
         if seqlist[i]:
             if x.ndim > 1:
@@ -1100,6 +1170,7 @@ def boxplot_stats(X, whis=1.5, bootstrap=None, labels=None,
         med        50th percentile
         q1         first quartile (25th percentile)
         q3         third quartile (75th percentile)
+        iqr        interquartile range
         cilo       lower notch around the median
         cihi       upper notch around the median
         whislo     end of the lower whisker
@@ -1181,11 +1252,11 @@ def boxplot_stats(X, whis=1.5, bootstrap=None, labels=None,
             stats['med'] = np.nan
             stats['q1'] = np.nan
             stats['q3'] = np.nan
+            stats['iqr'] = np.nan
             stats['cilo'] = np.nan
             stats['cihi'] = np.nan
             stats['whislo'] = np.nan
             stats['whishi'] = np.nan
-            stats['med'] = np.nan
             continue
 
         # up-convert to an array, just to be safe
@@ -1300,47 +1371,17 @@ def _to_unmasked_float_array(x):
 
 def _check_1d(x):
     """Convert scalars to 1D arrays; pass-through arrays as is."""
-    if not hasattr(x, 'shape') or len(x.shape) < 1:
+    # Unpack in case of e.g. Pandas or xarray object
+    x = _unpack_to_numpy(x)
+    # plot requires `shape` and `ndim`.  If passed an
+    # object that doesn't provide them, then force to numpy array.
+    # Note this will strip unit information.
+    if (not hasattr(x, 'shape') or
+            not hasattr(x, 'ndim') or
+            len(x.shape) < 1):
         return np.atleast_1d(x)
     else:
-        try:
-            # work around
-            # https://github.com/pandas-dev/pandas/issues/27775 which
-            # means the shape of multi-dimensional slicing is not as
-            # expected.  That this ever worked was an unintentional
-            # quirk of pandas and will raise an exception in the
-            # future.  This slicing warns in pandas >= 1.0rc0 via
-            # https://github.com/pandas-dev/pandas/pull/30588
-            #
-            # < 1.0rc0 : x[:, None].ndim == 1, no warning, custom type
-            # >= 1.0rc1 : x[:, None].ndim == 2, warns, numpy array
-            # future : x[:, None] -> raises
-            #
-            # This code should correctly identify and coerce to a
-            # numpy array all pandas versions.
-            with warnings.catch_warnings(record=True) as w:
-                warnings.filterwarnings(
-                    "always",
-                    category=Warning,
-                    message='Support for multi-dimensional indexing')
-
-                ndim = x[:, None].ndim
-                # we have definitely hit a pandas index or series object
-                # cast to a numpy array.
-                if len(w) > 0:
-                    return np.asanyarray(x)
-            # We have likely hit a pandas object, or at least
-            # something where 2D slicing does not result in a 2D
-            # object.
-            if ndim < 2:
-                return np.atleast_1d(x)
-            return x
-        # In pandas 1.1.0, multidimensional indexing leads to an
-        # AssertionError for some Series objects, but should be
-        # IndexError as described in
-        # https://github.com/pandas-dev/pandas/issues/35527
-        except (AssertionError, IndexError, TypeError):
-            return np.atleast_1d(x)
+        return x
 
 
 def _reshape_2D(X, name):
@@ -1355,15 +1396,8 @@ def _reshape_2D(X, name):
     *name* is used to generate the error message for invalid inputs.
     """
 
-    # unpack if we have a values or to_numpy method.
-    try:
-        X = X.to_numpy()
-    except AttributeError:
-        try:
-            if isinstance(X.values, np.ndarray):
-                X = X.values
-        except AttributeError:
-            pass
+    # Unpack in case of e.g. Pandas or xarray object
+    X = _unpack_to_numpy(X)
 
     # Iterate over columns for ndarrays.
     if isinstance(X, np.ndarray):
@@ -1389,9 +1423,13 @@ def _reshape_2D(X, name):
     for xi in X:
         # check if this is iterable, except for strings which we
         # treat as singletons.
-        if (isinstance(xi, collections.abc.Iterable) and
-                not isinstance(xi, str)):
-            is_1d = False
+        if not isinstance(xi, str):
+            try:
+                iter(xi)
+            except TypeError:
+                pass
+            else:
+                is_1d = False
         xi = np.asanyarray(xi)
         nd = np.ndim(xi)
         if nd > 1:
@@ -1645,7 +1683,7 @@ def index_of(y):
        The x and y values to plot.
     """
     try:
-        return y.index.values, y.values
+        return y.index.to_numpy(), y.to_numpy()
     except AttributeError:
         pass
     try:
@@ -1662,22 +1700,53 @@ def safe_first_element(obj):
     """
     Return the first element in *obj*.
 
-    This is an type-independent way of obtaining the first element, supporting
-    both index access and the iterator protocol.
+    This is an type-independent way of obtaining the first element,
+    supporting both index access and the iterator protocol.
     """
-    if isinstance(obj, collections.abc.Iterator):
-        # needed to accept `array.flat` as input.
-        # np.flatiter reports as an instance of collections.Iterator
-        # but can still be indexed via [].
-        # This has the side effect of re-setting the iterator, but
-        # that is acceptable.
+    return _safe_first_finite(obj, skip_nonfinite=False)
+
+
+def _safe_first_finite(obj, *, skip_nonfinite=True):
+    """
+    Return the first non-None (and optionally finite) element in *obj*.
+
+    This is a method for internal use.
+
+    This is an type-independent way of obtaining the first non-None element,
+    supporting both index access and the iterator protocol.
+    The first non-None element will be obtained when skip_none is True.
+    """
+    def safe_isfinite(val):
+        if val is None:
+            return False
         try:
-            return obj[0]
+            return np.isfinite(val) if np.isscalar(val) else True
         except TypeError:
-            pass
-        raise RuntimeError("matplotlib does not support generators "
-                           "as input")
-    return next(iter(obj))
+            # This is something that numpy can not make heads or tails
+            # of, assume "finite"
+            return True
+    if skip_nonfinite is False:
+        if isinstance(obj, collections.abc.Iterator):
+            # needed to accept `array.flat` as input.
+            # np.flatiter reports as an instance of collections.Iterator
+            # but can still be indexed via [].
+            # This has the side effect of re-setting the iterator, but
+            # that is acceptable.
+            try:
+                return obj[0]
+            except TypeError:
+                pass
+            raise RuntimeError("matplotlib does not support generators "
+                               "as input")
+        return next(iter(obj))
+    elif isinstance(obj, np.flatiter):
+        # TODO do the finite filtering on this
+        return obj[0]
+    elif isinstance(obj, collections.abc.Iterator):
+        raise RuntimeError("matplotlib does not "
+                           "support generators as input")
+    else:
+        return next(val for val in obj if safe_isfinite(val))
 
 
 def sanitize_sequence(data):
@@ -1818,61 +1887,6 @@ def _str_lower_equal(obj, s):
     return isinstance(obj, str) and obj.lower() == s
 
 
-def _define_aliases(alias_d, cls=None):
-    """
-    Class decorator for defining property aliases.
-
-    Use as ::
-
-        @cbook._define_aliases({"property": ["alias", ...], ...})
-        class C: ...
-
-    For each property, if the corresponding ``get_property`` is defined in the
-    class so far, an alias named ``get_alias`` will be defined; the same will
-    be done for setters.  If neither the getter nor the setter exists, an
-    exception will be raised.
-
-    The alias map is stored as the ``_alias_map`` attribute on the class and
-    can be used by `.normalize_kwargs` (which assumes that higher priority
-    aliases come last).
-    """
-    if cls is None:  # Return the actual class decorator.
-        return functools.partial(_define_aliases, alias_d)
-
-    def make_alias(name):  # Enforce a closure over *name*.
-        @functools.wraps(getattr(cls, name))
-        def method(self, *args, **kwargs):
-            return getattr(self, name)(*args, **kwargs)
-        return method
-
-    for prop, aliases in alias_d.items():
-        exists = False
-        for prefix in ["get_", "set_"]:
-            if prefix + prop in vars(cls):
-                exists = True
-                for alias in aliases:
-                    method = make_alias(prefix + prop)
-                    method.__name__ = prefix + alias
-                    method.__doc__ = "Alias for `{}`.".format(prefix + prop)
-                    setattr(cls, prefix + alias, method)
-        if not exists:
-            raise ValueError(
-                "Neither getter nor setter exists for {!r}".format(prop))
-
-    def get_aliased_and_aliases(d):
-        return {*d, *(alias for aliases in d.values() for alias in aliases)}
-
-    preexisting_aliases = getattr(cls, "_alias_map", {})
-    conflicting = (get_aliased_and_aliases(preexisting_aliases)
-                   & get_aliased_and_aliases(alias_d))
-    if conflicting:
-        # Need to decide on conflict resolution policy.
-        raise NotImplementedError(
-            f"Parent class already defines conflicting aliases: {conflicting}")
-    cls._alias_map = {**preexisting_aliases, **alias_d}
-    return cls
-
-
 def _array_perimeter(arr):
     """
     Get the elements on the perimeter of *arr*.
@@ -1891,7 +1905,7 @@ def _array_perimeter(arr):
 
     Examples
     --------
-    >>> i, j = np.ogrid[:3,:4]
+    >>> i, j = np.ogrid[:3, :4]
     >>> a = i*10 + j
     >>> a
     array([[ 0,  1,  2,  3],
@@ -1935,7 +1949,7 @@ def _unfold(arr, axis, size, step):
 
     Examples
     --------
-    >>> i, j = np.ogrid[:3,:7]
+    >>> i, j = np.ogrid[:3, :7]
     >>> a = i*10 + j
     >>> a
     array([[ 0,  1,  2,  3,  4,  5,  6],
@@ -2076,7 +2090,7 @@ class _OrderedSet(collections.abc.MutableSet):
         self._od.pop(key, None)
 
 
-# Agg's buffers are unmultiplied RGBA8888, which neither PyQt5 nor cairo
+# Agg's buffers are unmultiplied RGBA8888, which neither PyQt<=5.1 nor cairo
 # support; however, both do support premultiplied ARGB32.
 
 
@@ -2215,7 +2229,7 @@ def _g_sig_digits(value, delta):
     if delta == 0:
         # delta = 0 may occur when trying to format values over a tiny range;
         # in that case, replace it by the distance to the closest float.
-        delta = np.spacing(value)
+        delta = abs(np.spacing(value))
     # If e.g. value = 45.67 and delta = 0.02, then we want to round to 2 digits
     # after the decimal point (floor(log10(0.02)) = -2); 45.67 contributes 2
     # digits before the decimal point (floor(log10(45.67)) + 1 = 2): the total
@@ -2305,3 +2319,20 @@ def _picklable_class_constructor(mixin_class, fmt, attr_name, base_class):
     factory = _make_class_factory(mixin_class, fmt, attr_name)
     cls = factory(base_class)
     return cls.__new__(cls)
+
+
+def _unpack_to_numpy(x):
+    """Internal helper to extract data from e.g. pandas and xarray objects."""
+    if isinstance(x, np.ndarray):
+        # If numpy, return directly
+        return x
+    if hasattr(x, 'to_numpy'):
+        # Assume that any function to_numpy() do actually return a numpy array
+        return x.to_numpy()
+    if hasattr(x, 'values'):
+        xtmp = x.values
+        # For example a dict has a 'values' attribute, but it is not a property
+        # so in this case we do not want to return a function
+        if isinstance(xtmp, np.ndarray):
+            return xtmp
+    return x
