@@ -48,11 +48,11 @@ class Path:
         Draw a line from the current position to the given vertex.
 
     - ``CURVE3`` :  1 control point, 1 endpoint
-        Draw a quadratic Bezier curve from the current position, with the given
+        Draw a quadratic Bézier curve from the current position, with the given
         control point, to the given end point.
 
     - ``CURVE4`` :  2 control points, 1 endpoint
-        Draw a cubic Bezier curve from the current position, with the given
+        Draw a cubic Bézier curve from the current position, with the given
         control points, to the given end point.
 
     - ``CLOSEPOLY`` : 1 vertex (ignored)
@@ -188,6 +188,17 @@ class Path:
             pth._interpolation_steps = 1
         return pth
 
+    @classmethod
+    def _create_closed(cls, vertices):
+        """
+        Create a closed polygonal path going through *vertices*.
+
+        Unlike ``Path(..., closed=True)``, *vertices* should **not** end with
+        an entry for the CLOSEPATH; this entry is added by `._create_closed`.
+        """
+        v = _to_unmasked_float_array(vertices)
+        return cls(np.concatenate([v, v[:1]]), closed=True)
+
     def _update_values(self):
         self._simplify_threshold = mpl.rcParams['path.simplify_threshold']
         self._should_simplify = (
@@ -218,7 +229,7 @@ class Path:
         code is one of `STOP`, `MOVETO`, `LINETO`, `CURVE3`, `CURVE4`
         or `CLOSEPOLY`.  For codes that correspond to more than one
         vertex (`CURVE3` and `CURVE4`), that code will be repeated so
-        that the length of `self.vertices` and `self.codes` is always
+        that the length of `vertices` and `codes` is always
         the same.
         """
         return self._codes
@@ -272,13 +283,10 @@ class Path:
         Return a deepcopy of the `Path`.  The `Path` will not be
         readonly, even if the source `Path` is.
         """
-        try:
-            codes = self.codes.copy()
-        except AttributeError:
-            codes = None
-        return self.__class__(
-            self.vertices.copy(), codes,
-            _interpolation_steps=self._interpolation_steps)
+        # Deepcopying arrays (vertices, codes) strips the writeable=False flag.
+        p = copy.deepcopy(super(), memo)
+        p._readonly = False
+        return p
 
     deepcopy = __deepcopy__
 
@@ -411,7 +419,7 @@ class Path:
 
     def iter_bezier(self, **kwargs):
         """
-        Iterate over each bezier curve (lines included) in a Path.
+        Iterate over each Bézier curve (lines included) in a Path.
 
         Parameters
         ----------
@@ -421,13 +429,13 @@ class Path:
         Yields
         ------
         B : matplotlib.bezier.BezierSegment
-            The bezier curves that make up the current path. Note in particular
-            that freestanding points are bezier curves of order 0, and lines
-            are bezier curves of order 1 (with two control points).
+            The Bézier curves that make up the current path. Note in particular
+            that freestanding points are Bézier curves of order 0, and lines
+            are Bézier curves of order 1 (with two control points).
         code : Path.code_type
             The code describing what kind of curve is being returned.
             Path.MOVETO, Path.LINETO, Path.CURVE3, Path.CURVE4 correspond to
-            bezier curves with 1, 2, 3, and 4 control points (respectively).
+            Bézier curves with 1, 2, 3, and 4 control points (respectively).
             Path.CLOSEPOLY is a Path.LINETO with the control points correctly
             chosen based on the start/end points of the current stroke.
         """
@@ -505,7 +513,7 @@ class Path:
             by *transform*; i.e. for a correct check, *transform* should
             transform the path into the coordinate system of *point*.
         radius : float, default: 0
-            Add an additional margin on the path in coordinates of *point*.
+            Additional margin on the path in coordinates of *point*.
             The path is extended tangentially by *radius/2*; i.e. if you would
             draw the path with a linewidth of *radius*, all points on the line
             would still be considered to be contained in the area. Conversely,
@@ -555,7 +563,7 @@ class Path:
             by *transform*; i.e. for a correct check, *transform* should
             transform the path into the coordinate system of *points*.
         radius : float, default: 0
-            Add an additional margin on the path in coordinates of *points*.
+            Additional margin on the path in coordinates of *points*.
             The path is extended tangentially by *radius/2*; i.e. if you would
             draw the path with a linewidth of *radius*, all points on the line
             would still be considered to be contained in the area. Conversely,
@@ -680,7 +688,7 @@ class Path:
         polygon/polyline is an Nx2 array of vertices.  In other words,
         each polygon has no ``MOVETO`` instructions or curves.  This
         is useful for displaying in backends that do not support
-        compound paths or Bezier curves.
+        compound paths or Bézier curves.
 
         If *width* and *height* are both non-zero then the lines will
         be simplified so that vertices outside of (0, 0), (width,
@@ -819,7 +827,7 @@ class Path:
 
         Notes
         -----
-        The circle is approximated using 8 cubic Bezier curves, as described in
+        The circle is approximated using 8 cubic Bézier curves, as described in
 
           Lancaster, Don.  `Approximating a Circle or an Ellipse Using Four
           Bezier Cubic Splines <https://www.tinaja.com/glib/ellipse4.pdf>`_.
