@@ -2,17 +2,17 @@ import subprocess
 import os
 import sys
 import pytest
+import matplotlib.backends.backend_webagg_core
 
 
 @pytest.mark.parametrize("backend", ["webagg", "nbagg"])
 def test_webagg_fallback(backend):
+    pytest.importorskip("tornado")
     if backend == "nbagg":
         pytest.importorskip("IPython")
-    env = {}
-    if os.name == "nt":
-        env = dict(os.environ)
-    else:
-        env = {"DISPLAY": ""}
+    env = dict(os.environ)
+    if os.name != "nt":
+        env["DISPLAY"] = ""
 
     env["MPLBACKEND"] = backend
 
@@ -26,3 +26,8 @@ def test_webagg_fallback(backend):
     ret = subprocess.call([sys.executable, "-c", test_code], env=env)
 
     assert ret == 0
+
+
+def test_webagg_core_no_toolbar():
+    fm = matplotlib.backends.backend_webagg_core.FigureManagerWebAgg
+    assert fm._toolbar2_class is None
