@@ -10,12 +10,11 @@ import base64
 
 from numpy.testing import assert_array_equal, assert_array_almost_equal
 
-from matplotlib import cycler
+from matplotlib import cbook, cm, cycler
 import matplotlib
+import matplotlib as mpl
 import matplotlib.colors as mcolors
-import matplotlib.cm as cm
 import matplotlib.colorbar as mcolorbar
-import matplotlib.cbook as cbook
 import matplotlib.pyplot as plt
 import matplotlib.scale as mscale
 from matplotlib.testing.decorators import image_comparison, check_figures_equal
@@ -31,9 +30,9 @@ def test_create_lookup_table(N, result):
     assert_array_almost_equal(mcolors._create_lookup_table(N, data), result)
 
 
-def test_resample():
+def test_resampled():
     """
-    GitHub issue #6025 pointed to incorrect ListedColormap._resample;
+    GitHub issue #6025 pointed to incorrect ListedColormap.resampled;
     here we test the method for LinearSegmentedColormap as well.
     """
     n = 101
@@ -49,8 +48,8 @@ def test_resample():
         cmap.set_under('r')
         cmap.set_over('g')
         cmap.set_bad('b')
-    lsc3 = lsc._resample(3)
-    lc3 = lc._resample(3)
+    lsc3 = lsc.resampled(3)
+    lc3 = lc.resampled(3)
     expected = np.array([[0.0, 0.2, 1.0, 0.7],
                          [0.5, 0.2, 0.5, 0.7],
                          [1.0, 0.2, 0.0, 0.7]], float)
@@ -66,79 +65,91 @@ def test_resample():
 
 
 def test_register_cmap():
-    new_cm = copy.copy(cm.get_cmap("viridis"))
+    new_cm = mpl.colormaps["viridis"]
     target = "viridis2"
-    cm.register_cmap(target, new_cm)
-    assert plt.get_cmap(target) == new_cm
+    with pytest.warns(
+            PendingDeprecationWarning,
+            match=r"matplotlib\.colormaps\.register\(name\)"
+    ):
+        cm.register_cmap(target, new_cm)
+    assert mpl.colormaps[target] == new_cm
 
     with pytest.raises(ValueError,
                        match="Arguments must include a name or a Colormap"):
-        cm.register_cmap()
+        with pytest.warns(
+            PendingDeprecationWarning,
+            match=r"matplotlib\.colormaps\.register\(name\)"
+        ):
+            cm.register_cmap()
 
-    with pytest.warns(UserWarning):
-        cm.register_cmap(target, new_cm)
-
-    cm.unregister_cmap(target)
+    with pytest.warns(
+            PendingDeprecationWarning,
+            match=r"matplotlib\.colormaps\.unregister\(name\)"
+    ):
+        cm.unregister_cmap(target)
     with pytest.raises(ValueError,
                        match=f'{target!r} is not a valid value for name;'):
-        cm.get_cmap(target)
-    # test that second time is error free
-    cm.unregister_cmap(target)
+        with pytest.warns(
+                PendingDeprecationWarning,
+                match=r"matplotlib\.colormaps\[name\]"
+        ):
+            cm.get_cmap(target)
+    with pytest.warns(
+            PendingDeprecationWarning,
+            match=r"matplotlib\.colormaps\.unregister\(name\)"
+    ):
+        # test that second time is error free
+        cm.unregister_cmap(target)
 
-    with pytest.raises(ValueError, match="You must pass a Colormap instance."):
-        cm.register_cmap('nome', cmap='not a cmap')
+    with pytest.raises(TypeError, match="'cmap' must be"):
+        with pytest.warns(
+            PendingDeprecationWarning,
+            match=r"matplotlib\.colormaps\.register\(name\)"
+        ):
+            cm.register_cmap('nome', cmap='not a cmap')
+
+
+def test_colormaps_get_cmap():
+    cr = mpl.colormaps
+
+    # check str, and Colormap pass
+    assert cr.get_cmap('plasma') == cr["plasma"]
+    assert cr.get_cmap(cr["magma"]) == cr["magma"]
+
+    # check default
+    assert cr.get_cmap(None) == cr[mpl.rcParams['image.cmap']]
+
+    # check ValueError on bad name
+    bad_cmap = 'AardvarksAreAwkward'
+    with pytest.raises(ValueError, match=bad_cmap):
+        cr.get_cmap(bad_cmap)
+
+    # check TypeError on bad type
+    with pytest.raises(TypeError, match='object'):
+        cr.get_cmap(object())
 
 
 def test_double_register_builtin_cmap():
     name = "viridis"
-    match = f"Trying to re-register the builtin cmap {name!r}."
+    match = f"Re-registering the builtin cmap {name!r}."
     with pytest.raises(ValueError, match=match):
-        cm.register_cmap(name, cm.get_cmap(name))
+        matplotlib.colormaps.register(
+            mpl.colormaps[name], name=name, force=True
+        )
+    with pytest.raises(ValueError, match='A colormap named "viridis"'):
+        with pytest.warns(PendingDeprecationWarning):
+            cm.register_cmap(name, mpl.colormaps[name])
     with pytest.warns(UserWarning):
-        cm.register_cmap(name, cm.get_cmap(name), override_builtin=True)
+        # TODO is warning more than once!
+        cm.register_cmap(name, mpl.colormaps[name], override_builtin=True)
 
 
 def test_unregister_builtin_cmap():
     name = "viridis"
     match = f'cannot unregister {name!r} which is a builtin colormap.'
     with pytest.raises(ValueError, match=match):
-        cm.unregister_cmap(name)
-
-
-def test_colormap_global_set_warn():
-    new_cm = plt.get_cmap('viridis')
-    # Store the old value so we don't override the state later on.
-    orig_cmap = copy.copy(new_cm)
-    with pytest.warns(cbook.MatplotlibDeprecationWarning,
-                      match="You are modifying the state of a globally"):
-        # This should warn now because we've modified the global state
-        new_cm.set_under('k')
-
-    # This shouldn't warn because it is a copy
-    copy.copy(new_cm).set_under('b')
-
-    # Test that registering and then modifying warns
-    plt.register_cmap(name='test_cm', cmap=copy.copy(orig_cmap))
-    new_cm = plt.get_cmap('test_cm')
-    with pytest.warns(cbook.MatplotlibDeprecationWarning,
-                      match="You are modifying the state of a globally"):
-        # This should warn now because we've modified the global state
-        new_cm.set_under('k')
-
-    # Re-register the original
-    with pytest.warns(UserWarning):
-        plt.register_cmap(cmap=orig_cmap, override_builtin=True)
-
-
-def test_colormap_dict_deprecate():
-    # Make sure we warn on get and set access into cmap_d
-    with pytest.warns(cbook.MatplotlibDeprecationWarning,
-                      match="The global colormaps dictionary is no longer"):
-        cmap = plt.cm.cmap_d['viridis']
-
-    with pytest.warns(cbook.MatplotlibDeprecationWarning,
-                      match="The global colormaps dictionary is no longer"):
-        plt.cm.cmap_d['test'] = cmap
+        with pytest.warns(PendingDeprecationWarning):
+            cm.unregister_cmap(name)
 
 
 def test_colormap_copy():
@@ -164,7 +175,7 @@ def test_colormap_copy():
 
 
 def test_colormap_equals():
-    cmap = plt.get_cmap("plasma")
+    cmap = mpl.colormaps["plasma"]
     cm_copy = cmap.copy()
     # different object id's
     assert cm_copy is not cmap
@@ -192,7 +203,7 @@ def test_colormap_endian():
     mapping of 1.0 when input from a non-native-byteorder
     array.
     """
-    cmap = cm.get_cmap("jet")
+    cmap = mpl.colormaps["jet"]
     # Test under, over, and invalid along with values 0 and 1.
     a = [-0.5, 0, 0.5, 1, 1.5, np.nan]
     for dt in ["f2", "f4", "f8"]:
@@ -207,7 +218,7 @@ def test_colormap_invalid():
     rather than bad. This tests to make sure all invalid values
     (-inf, nan, inf) are mapped respectively to (under, bad, over).
     """
-    cmap = cm.get_cmap("plasma")
+    cmap = mpl.colormaps["plasma"]
     x = np.array([-np.inf, -1, 0, np.nan, .7, 2, np.inf])
 
     expected = np.array([[0.050383, 0.029803, 0.527975, 1.],
@@ -240,7 +251,7 @@ def test_colormap_return_types():
     Make sure that tuples are returned for scalar input and
     that the proper shapes are returned for ndarrays.
     """
-    cmap = cm.get_cmap("plasma")
+    cmap = mpl.colormaps["plasma"]
     # Test return types and shapes
     # scalar input needs to return a tuple of length 4
     assert isinstance(cmap(0.5), tuple)
@@ -355,7 +366,7 @@ def test_BoundaryNorm():
 
     # Testing extend keyword, with interpolation (large cmap)
     bounds = [1, 2, 3]
-    cmap = cm.get_cmap('viridis')
+    cmap = mpl.colormaps['viridis']
     mynorm = mcolors.BoundaryNorm(bounds, cmap.N, extend='both')
     refnorm = mcolors.BoundaryNorm([0] + bounds + [4], cmap.N)
     x = np.random.randn(100) * 10 + 2
@@ -568,14 +579,15 @@ def test_Normalize():
     # Don't lose precision on longdoubles (float128 on Linux):
     # for array inputs...
     vals = np.array([1.2345678901, 9.8765432109], dtype=np.longdouble)
-    norm = mcolors.Normalize(vals.min(), vals.max())
-    assert_array_equal(np.asarray(norm(vals)), [0, 1])
+    norm = mcolors.Normalize(vals[0], vals[1])
+    assert norm(vals).dtype == np.longdouble
+    assert_array_equal(norm(vals), [0, 1])
     # and for scalar ones.
     eps = np.finfo(np.longdouble).resolution
     norm = plt.Normalize(1, 1 + 100 * eps)
     # This returns exactly 0.5 when longdouble is extended precision (80-bit),
     # but only a value close to it when it is quadruple precision (128-bit).
-    assert 0 < norm(1 + 50 * eps) < 1
+    assert_array_almost_equal(norm(1 + 50 * eps), 0.5, decimal=3)
 
 
 def test_FuncNorm():
@@ -745,6 +757,28 @@ def test_SymLogNorm_single_zero():
     plt.close(fig)
 
 
+class TestAsinhNorm:
+    """
+    Tests for `~.colors.AsinhNorm`
+    """
+
+    def test_init(self):
+        norm0 = mcolors.AsinhNorm()
+        assert norm0.linear_width == 1
+
+        norm5 = mcolors.AsinhNorm(linear_width=5)
+        assert norm5.linear_width == 5
+
+    def test_norm(self):
+        norm = mcolors.AsinhNorm(2, vmin=-4, vmax=4)
+        vals = np.arange(-3.5, 3.5, 10)
+        normed_vals = norm(vals)
+        asinh2 = np.arcsinh(2)
+
+        expected = (2 * np.arcsinh(vals / 2) + 2 * asinh2) / (4 * asinh2)
+        assert_array_almost_equal(normed_vals, expected)
+
+
 def _inverse_tester(norm_instance, vals):
     """
     Checks if the inverse of the given normalization is working.
@@ -803,7 +837,7 @@ def test_boundarynorm_and_colorbarbase():
 
     # Set the colormap and bounds
     bounds = [-1, 2, 5, 7, 12, 15]
-    cmap = cm.get_cmap('viridis')
+    cmap = mpl.colormaps['viridis']
 
     # Default behavior
     norm = mcolors.BoundaryNorm(bounds, cmap.N)
@@ -1148,13 +1182,13 @@ def test_pandas_iterable(pd):
     assert_array_equal(cm1.colors, cm2.colors)
 
 
-@pytest.mark.parametrize('name', sorted(plt.colormaps()))
+@pytest.mark.parametrize('name', sorted(mpl.colormaps()))
 def test_colormap_reversing(name):
     """
     Check the generated _lut data of a colormap and corresponding reversed
     colormap if they are almost the same.
     """
-    cmap = plt.get_cmap(name)
+    cmap = mpl.colormaps[name]
     cmap_r = cmap.reversed()
     if not cmap_r._isinit:
         cmap._init()
@@ -1166,6 +1200,15 @@ def test_colormap_reversing(name):
     assert_array_almost_equal(cmap(np.nan), cmap_r(np.nan))
 
 
+def test_has_alpha_channel():
+    assert mcolors._has_alpha_channel((0, 0, 0, 0))
+    assert mcolors._has_alpha_channel([1, 1, 1, 1])
+    assert not mcolors._has_alpha_channel('blue')  # 4-char string!
+    assert not mcolors._has_alpha_channel('0.25')
+    assert not mcolors._has_alpha_channel('r')
+    assert not mcolors._has_alpha_channel((1, 0, 0))
+
+
 def test_cn():
     matplotlib.rcParams['axes.prop_cycle'] = cycler('color',
                                                     ['blue', 'r'])
@@ -1223,8 +1266,7 @@ def test_to_rgba_array_single_str():
 
     # single char color sequence is invalid
     with pytest.raises(ValueError,
-                       match="Using a string of single character colors as "
-                             "a color sequence is not supported."):
+                       match="'rgb' is not a valid color value."):
         array = mcolors.to_rgba_array("rgb")
 
 
@@ -1313,7 +1355,7 @@ def test_hex_shorthand_notation():
 
 
 def test_repr_png():
-    cmap = plt.get_cmap('viridis')
+    cmap = mpl.colormaps['viridis']
     png = cmap._repr_png_()
     assert len(png) > 0
     img = Image.open(BytesIO(png))
@@ -1326,7 +1368,7 @@ def test_repr_png():
 
 
 def test_repr_html():
-    cmap = plt.get_cmap('viridis')
+    cmap = mpl.colormaps['viridis']
     html = cmap._repr_html_()
     assert len(html) > 0
     png = cmap._repr_png_()
@@ -1337,7 +1379,7 @@ def test_repr_html():
 
 
 def test_get_under_over_bad():
-    cmap = plt.get_cmap('viridis')
+    cmap = mpl.colormaps['viridis']
     assert_array_equal(cmap.get_under(), cmap(-np.inf))
     assert_array_equal(cmap.get_over(), cmap(np.inf))
     assert_array_equal(cmap.get_bad(), cmap(np.nan))
@@ -1345,7 +1387,7 @@ def test_get_under_over_bad():
 
 @pytest.mark.parametrize('kind', ('over', 'under', 'bad'))
 def test_non_mutable_get_values(kind):
-    cmap = copy.copy(plt.get_cmap('viridis'))
+    cmap = copy.copy(mpl.colormaps['viridis'])
     init_value = getattr(cmap, f'get_{kind}')()
     getattr(cmap, f'set_{kind}')('k')
     black_value = getattr(cmap, f'get_{kind}')()
@@ -1354,7 +1396,7 @@ def test_non_mutable_get_values(kind):
 
 
 def test_colormap_alpha_array():
-    cmap = plt.get_cmap('viridis')
+    cmap = mpl.colormaps['viridis']
     vals = [-1, 0.5, 2]  # under, valid, over
     with pytest.raises(ValueError, match="alpha is array-like but"):
         cmap(vals, alpha=[1, 1, 1, 1])
@@ -1366,7 +1408,7 @@ def test_colormap_alpha_array():
 
 
 def test_colormap_bad_data_with_alpha():
-    cmap = plt.get_cmap('viridis')
+    cmap = mpl.colormaps['viridis']
     c = cmap(np.nan, alpha=0.5)
     assert c == (0, 0, 0, 0)
     c = cmap([0.5, np.nan], alpha=0.5)
@@ -1480,4 +1522,52 @@ def test_norm_update_figs(fig_test, fig_ref):
 def test_make_norm_from_scale_name():
     logitnorm = mcolors.make_norm_from_scale(
         mscale.LogitScale, mcolors.Normalize)
-    assert logitnorm.__name__ == "LogitScaleNorm"
+    assert logitnorm.__name__ == logitnorm.__qualname__ == "LogitScaleNorm"
+
+
+def test_color_sequences():
+    # basic access
+    assert plt.color_sequences is matplotlib.color_sequences  # same registry
+    assert list(plt.color_sequences) == [
+        'tab10', 'tab20', 'tab20b', 'tab20c', 'Pastel1', 'Pastel2', 'Paired',
+        'Accent', 'Dark2', 'Set1', 'Set2', 'Set3']
+    assert len(plt.color_sequences['tab10']) == 10
+    assert len(plt.color_sequences['tab20']) == 20
+
+    tab_colors = [
+        'tab:blue', 'tab:orange', 'tab:green', 'tab:red', 'tab:purple',
+        'tab:brown', 'tab:pink', 'tab:gray', 'tab:olive', 'tab:cyan']
+    for seq_color, tab_color in zip(plt.color_sequences['tab10'], tab_colors):
+        assert mcolors.same_color(seq_color, tab_color)
+
+    # registering
+    with pytest.raises(ValueError, match="reserved name"):
+        plt.color_sequences.register('tab10', ['r', 'g', 'b'])
+    with pytest.raises(ValueError, match="not a valid color specification"):
+        plt.color_sequences.register('invalid', ['not a color'])
+
+    rgb_colors = ['r', 'g', 'b']
+    plt.color_sequences.register('rgb', rgb_colors)
+    assert plt.color_sequences['rgb'] == ['r', 'g', 'b']
+    # should not affect the registered sequence because input is copied
+    rgb_colors.append('c')
+    assert plt.color_sequences['rgb'] == ['r', 'g', 'b']
+    # should not affect the registered sequence because returned list is a copy
+    plt.color_sequences['rgb'].append('c')
+    assert plt.color_sequences['rgb'] == ['r', 'g', 'b']
+
+    # unregister
+    plt.color_sequences.unregister('rgb')
+    with pytest.raises(KeyError):
+        plt.color_sequences['rgb']  # rgb is gone
+    plt.color_sequences.unregister('rgb')  # multiple unregisters are ok
+    with pytest.raises(ValueError, match="Cannot unregister builtin"):
+        plt.color_sequences.unregister('tab10')
+
+
+def test_cm_set_cmap_error():
+    sm = cm.ScalarMappable()
+    # Pick a name we are pretty sure will never be a colormap name
+    bad_cmap = 'AardvarksAreAwkward'
+    with pytest.raises(ValueError, match=bad_cmap):
+        sm.set_cmap(bad_cmap)
