@@ -6,12 +6,11 @@ import functools
 import numpy as np
 import pytest
 
-from matplotlib import rc_context, style
+from matplotlib import _api, rc_context, style
 import matplotlib.dates as mdates
 import matplotlib.pyplot as plt
 from matplotlib.testing.decorators import image_comparison
 import matplotlib.ticker as mticker
-import matplotlib._api as _api
 
 
 def test_date_numpyx():
@@ -78,8 +77,8 @@ def test_date_empty():
     ax.xaxis_date()
     fig.draw_without_rendering()
     np.testing.assert_allclose(ax.get_xlim(),
-                               [mdates.date2num(np.datetime64('2000-01-01')),
-                                mdates.date2num(np.datetime64('2010-01-01'))])
+                               [mdates.date2num(np.datetime64('1970-01-01')),
+                                mdates.date2num(np.datetime64('1970-01-02'))])
 
     mdates._reset_epoch_test_example()
     mdates.set_epoch('0000-12-31')
@@ -87,8 +86,8 @@ def test_date_empty():
     ax.xaxis_date()
     fig.draw_without_rendering()
     np.testing.assert_allclose(ax.get_xlim(),
-                               [mdates.date2num(np.datetime64('2000-01-01')),
-                                mdates.date2num(np.datetime64('2010-01-01'))])
+                               [mdates.date2num(np.datetime64('1970-01-01')),
+                                mdates.date2num(np.datetime64('1970-01-02'))])
     mdates._reset_epoch_test_example()
 
 
@@ -182,8 +181,8 @@ def test_too_many_date_ticks(caplog):
     with pytest.warns(UserWarning) as rec:
         ax.set_xlim((t0, tf), auto=True)
         assert len(rec) == 1
-        assert \
-            'Attempting to set identical left == right' in str(rec[0].message)
+        assert ('Attempting to set identical low and high xlims'
+                in str(rec[0].message))
     ax.plot([], [])
     ax.xaxis.set_major_locator(mdates.DayLocator())
     v = ax.xaxis.get_major_locator()()
@@ -357,9 +356,13 @@ def test_drange():
     # dates from an half open interval [start, end)
     assert len(mdates.drange(start, end, delta)) == 24
 
+    # Same if interval ends slightly earlier
+    end = end - datetime.timedelta(microseconds=1)
+    assert len(mdates.drange(start, end, delta)) == 24
+
     # if end is a little bit later, we expect the range to contain one element
     # more
-    end = end + datetime.timedelta(microseconds=1)
+    end = end + datetime.timedelta(microseconds=2)
     assert len(mdates.drange(start, end, delta)) == 25
 
     # reset end
@@ -443,6 +446,15 @@ def test_auto_date_locator():
         locator = _create_auto_date_locator(d1, d2)
         assert list(map(str, mdates.num2date(locator()))) == expected
 
+    locator = mdates.AutoDateLocator(interval_multiples=False)
+    assert locator.maxticks == {0: 11, 1: 12, 3: 11, 4: 12, 5: 11, 6: 11, 7: 8}
+
+    locator = mdates.AutoDateLocator(maxticks={dateutil.rrule.MONTHLY: 5})
+    assert locator.maxticks == {0: 11, 1: 5, 3: 11, 4: 12, 5: 11, 6: 11, 7: 8}
+
+    locator = mdates.AutoDateLocator(maxticks=5)
+    assert locator.maxticks == {0: 5, 1: 5, 3: 5, 4: 5, 5: 5, 6: 5, 7: 5}
+
 
 @_new_epoch_decorator
 def test_auto_date_locator_intmult():
@@ -621,6 +633,10 @@ def test_offset_changes():
     ax.set_xlim(d1, d1 + datetime.timedelta(weeks=3))
     fig.draw_without_rendering()
     assert formatter.get_offset() == '1997-Jan'
+    ax.set_xlim(d1 + datetime.timedelta(weeks=7),
+                d1 + datetime.timedelta(weeks=30))
+    fig.draw_without_rendering()
+    assert formatter.get_offset() == '1997'
     ax.set_xlim(d1, d1 + datetime.timedelta(weeks=520))
     fig.draw_without_rendering()
     assert formatter.get_offset() == ''
@@ -900,7 +916,7 @@ def _test_date2num_dst(date_range, tz_convert):
     # Interval is 0b0.0000011 days, to prevent float rounding issues
     dtstart = datetime.datetime(2014, 3, 30, 0, 0, tzinfo=UTC)
     interval = datetime.timedelta(minutes=33, seconds=45)
-    interval_days = 0.0234375   # 2025 / 86400 seconds
+    interval_days = interval.seconds / 86400
     N = 8
 
     dt_utc = date_range(start=dtstart, freq=interval, periods=N)
@@ -970,7 +986,7 @@ def test_date2num_dst():
 
         return [dtstart + (i * freq) for i in range(periods)]
 
-    # Define a tz_convert function that converts a list to a new time zone.
+    # Define a tz_convert function that converts a list to a new timezone.
     def tz_convert(dt_list, tzinfo):
         return [d.astimezone(tzinfo) for d in dt_list]
 
@@ -1008,6 +1024,20 @@ def test_rrulewrapper():
 
     _test_rrulewrapper(attach_tz, dateutil.tz.gettz)
 
+    SYD = dateutil.tz.gettz('Australia/Sydney')
+    dtstart = datetime.datetime(2017, 4, 1, 0)
+    dtend = datetime.datetime(2017, 4, 4, 0)
+    rule = mdates.rrulewrapper(freq=dateutil.rrule.DAILY, dtstart=dtstart,
+                               tzinfo=SYD, until=dtend)
+    assert rule.after(dtstart) == datetime.datetime(2017, 4, 2, 0, 0,
+                                                    tzinfo=SYD)
+    assert rule.before(dtend) == datetime.datetime(2017, 4, 3, 0, 0,
+                                                   tzinfo=SYD)
+
+    # Test parts of __getattr__
+    assert rule._base_tzinfo == SYD
+    assert rule._interval == 1
+
 
 @pytest.mark.pytz
 def test_rrulewrapper_pytz():
@@ -1042,6 +1072,15 @@ def test_yearlocator_pytz():
                 '2014-01-01 00:00:00-05:00', '2015-01-01 00:00:00-05:00']
     st = list(map(str, mdates.num2date(locator(), tz=tz)))
     assert st == expected
+    assert np.allclose(locator.tick_values(x[0], x[1]), np.array(
+        [14610.20833333, 14610.33333333, 14610.45833333, 14610.58333333,
+         14610.70833333, 14610.83333333, 14610.95833333, 14611.08333333,
+         14611.20833333]))
+    assert np.allclose(locator.get_locator(x[1], x[0]).tick_values(x[0], x[1]),
+                       np.array(
+        [14610.20833333, 14610.33333333, 14610.45833333, 14610.58333333,
+         14610.70833333, 14610.83333333, 14610.95833333, 14611.08333333,
+         14611.20833333]))
 
 
 def test_YearLocator():
@@ -1097,7 +1136,7 @@ def test_DayLocator():
 
 def test_tz_utc():
     dt = datetime.datetime(1970, 1, 1, tzinfo=mdates.UTC)
-    dt.tzname()
+    assert dt.tzname() == 'UTC'
 
 
 @pytest.mark.parametrize("x, tdelta",
@@ -1157,7 +1196,7 @@ def test_warn_notintervals():
     locator.create_dummy_axis()
     locator.axis.set_view_interval(mdates.date2num(dates[0]),
                                    mdates.date2num(dates[-1]))
-    with pytest.warns(UserWarning, match="AutoDateLocator was unable") as rec:
+    with pytest.warns(UserWarning, match="AutoDateLocator was unable"):
         locs = locator()
 
 
@@ -1226,3 +1265,129 @@ def test_julian2num():
     mdates.set_epoch('1970-01-01T00:00:00')
     assert mdates.julian2num(2440588.5) == 1.0
     assert mdates.num2julian(2.0) == 2440589.5
+
+
+def test_DateLocator():
+    locator = mdates.DateLocator()
+    # Test nonsingular
+    assert locator.nonsingular(0, np.inf) == (0, 1)
+    assert locator.nonsingular(0, 1) == (0, 1)
+    assert locator.nonsingular(1, 0) == (0, 1)
+    assert locator.nonsingular(0, 0) == (-2, 2)
+    locator.create_dummy_axis()
+    # default values
+    assert locator.datalim_to_dt() == (
+        datetime.datetime(1970, 1, 1, 0, 0, tzinfo=datetime.timezone.utc),
+        datetime.datetime(1970, 1, 2, 0, 0, tzinfo=datetime.timezone.utc))
+
+    # Check default is UTC
+    assert locator.tz == mdates.UTC
+    tz_str = 'Iceland'
+    iceland_tz = dateutil.tz.gettz(tz_str)
+    # Check not Iceland
+    assert locator.tz != iceland_tz
+    # Set it to to Iceland
+    locator.set_tzinfo('Iceland')
+    # Check now it is Iceland
+    assert locator.tz == iceland_tz
+    locator.create_dummy_axis()
+    locator.axis.set_data_interval(*mdates.date2num(["2022-01-10",
+                                                     "2022-01-08"]))
+    assert locator.datalim_to_dt() == (
+        datetime.datetime(2022, 1, 8, 0, 0, tzinfo=iceland_tz),
+        datetime.datetime(2022, 1, 10, 0, 0, tzinfo=iceland_tz))
+
+    # Set rcParam
+    plt.rcParams['timezone'] = tz_str
+
+    # Create a new one in a similar way
+    locator = mdates.DateLocator()
+    # Check now it is Iceland
+    assert locator.tz == iceland_tz
+
+    # Test invalid tz values
+    with pytest.raises(ValueError, match="Aiceland is not a valid timezone"):
+        mdates.DateLocator(tz="Aiceland")
+    with pytest.raises(TypeError,
+                       match="tz must be string or tzinfo subclass."):
+        mdates.DateLocator(tz=1)
+
+
+def test_datestr2num():
+    assert mdates.datestr2num('2022-01-10') == 19002.0
+    dt = datetime.date(year=2022, month=1, day=10)
+    assert mdates.datestr2num('2022-01', default=dt) == 19002.0
+    assert np.all(mdates.datestr2num(
+        ['2022-01', '2022-02'], default=dt
+        ) == np.array([19002., 19033.]))
+    assert mdates.datestr2num([]).size == 0
+    assert mdates.datestr2num([], datetime.date(year=2022,
+                                                month=1, day=10)).size == 0
+
+
+@pytest.mark.parametrize('kwarg',
+                         ('formats', 'zero_formats', 'offset_formats'))
+def test_concise_formatter_exceptions(kwarg):
+    locator = mdates.AutoDateLocator()
+    kwargs = {kwarg: ['', '%Y']}
+    match = f"{kwarg} argument must be a list"
+    with pytest.raises(ValueError, match=match):
+        mdates.ConciseDateFormatter(locator, **kwargs)
+
+
+def test_concise_formatter_call():
+    locator = mdates.AutoDateLocator()
+    formatter = mdates.ConciseDateFormatter(locator)
+    assert formatter(19002.0) == '2022'
+    assert formatter.format_data_short(19002.0) == '2022-01-10 00:00:00'
+
+
+@pytest.mark.parametrize('span, expected_locator',
+                         ((0.02, mdates.MinuteLocator),
+                          (1, mdates.HourLocator),
+                          (19, mdates.DayLocator),
+                          (40, mdates.WeekdayLocator),
+                          (200, mdates.MonthLocator),
+                          (2000, mdates.YearLocator)))
+def test_date_ticker_factory(span, expected_locator):
+    with pytest.warns(_api.MatplotlibDeprecationWarning):
+        locator, _ = mdates.date_ticker_factory(span)
+        assert isinstance(locator, expected_locator)
+
+
+def test_datetime_masked():
+    # make sure that all-masked data falls back to the viewlim
+    # set in convert.axisinfo....
+    x = np.array([datetime.datetime(2017, 1, n) for n in range(1, 6)])
+    y = np.array([1, 2, 3, 4, 5])
+    m = np.ma.masked_greater(y, 0)
+
+    fig, ax = plt.subplots()
+    ax.plot(x, m)
+    assert ax.get_xlim() == (0, 1)
+
+
+@pytest.mark.parametrize('val', (-1000000, 10000000))
+def test_num2date_error(val):
+    with pytest.raises(ValueError, match=f"Date ordinal {val} converts"):
+        mdates.num2date(val)
+
+
+def test_num2date_roundoff():
+    assert mdates.num2date(100000.0000578702) == datetime.datetime(
+        2243, 10, 17, 0, 0, 4, 999980, tzinfo=datetime.timezone.utc)
+    # Slightly larger, steps of 20 microseconds
+    assert mdates.num2date(100000.0000578703) == datetime.datetime(
+        2243, 10, 17, 0, 0, 5, tzinfo=datetime.timezone.utc)
+
+
+def test_DateFormatter_settz():
+    time = mdates.date2num(datetime.datetime(2011, 1, 1, 0, 0,
+                                             tzinfo=mdates.UTC))
+    formatter = mdates.DateFormatter('%Y-%b-%d %H:%M')
+    # Default UTC
+    assert formatter(time) == '2011-Jan-01 00:00'
+
+    # Set tzinfo
+    formatter.set_tzinfo('Pacific/Kiritimati')
+    assert formatter(time) == '2011-Jan-01 14:00'
