@@ -2,6 +2,7 @@ from io import BytesIO, StringIO
 import multiprocessing
 import os
 from pathlib import Path
+from PIL import Image
 import shutil
 import subprocess
 import sys
@@ -11,9 +12,10 @@ import numpy as np
 import pytest
 
 from matplotlib.font_manager import (
-    findfont, findSystemFonts, FontProperties, fontManager, json_dump,
-    json_load, get_font, is_opentype_cff_font, MSUserFontDirectories,
-    _get_fontconfig_fonts)
+    findfont, findSystemFonts, FontEntry, FontProperties, fontManager,
+    json_dump, json_load, get_font, is_opentype_cff_font,
+    MSUserFontDirectories, _get_fontconfig_fonts, ft2font,
+    ttfFontProperty, cbook)
 from matplotlib import pyplot as plt, rc_context
 
 has_fclist = shutil.which('fc-list') is not None
@@ -71,7 +73,8 @@ def test_otf():
             assert res == is_opentype_cff_font(f.fname)
 
 
-@pytest.mark.skipif(not has_fclist, reason='no fontconfig installed')
+@pytest.mark.skipif(sys.platform == "win32" or not has_fclist,
+                    reason='no fontconfig installed')
 def test_get_fontconfig_fonts():
     assert len(_get_fontconfig_fonts()) > 1
 
@@ -101,7 +104,7 @@ def test_utf16m_sfnt():
         entry = next(entry for entry in fontManager.ttflist
                      if Path(entry.fname).name == "seguisbi.ttf")
     except StopIteration:
-        pytest.skip("Couldn't find font to test against.")
+        pytest.skip("Couldn't find seguisbi.ttf font to test against.")
     else:
         # Check that we successfully read "semibold" from the font's sfnt table
         # and set its weight accordingly.
@@ -111,14 +114,25 @@ def test_utf16m_sfnt():
 def test_find_ttc():
     fp = FontProperties(family=["WenQuanYi Zen Hei"])
     if Path(findfont(fp)).name != "wqy-zenhei.ttc":
-        pytest.skip("Font may be missing")
-
+        pytest.skip("Font wqy-zenhei.ttc may be missing")
     fig, ax = plt.subplots()
     ax.text(.5, .5, "\N{KANGXI RADICAL DRAGON}", fontproperties=fp)
     for fmt in ["raw", "svg", "pdf", "ps"]:
         fig.savefig(BytesIO(), format=fmt)
 
 
+def test_find_noto():
+    fp = FontProperties(family=["Noto Sans CJK SC", "Noto Sans CJK JP"])
+    name = Path(findfont(fp)).name
+    if name not in ("NotoSansCJKsc-Regular.otf", "NotoSansCJK-Regular.ttc"):
+        pytest.skip(f"Noto Sans CJK SC font may be missing (found {name})")
+
+    fig, ax = plt.subplots()
+    ax.text(0.5, 0.5, 'Hello, 你好', fontproperties=fp)
+    for fmt in ["raw", "svg", "pdf", "ps"]:
+        fig.savefig(BytesIO(), format=fmt)
+
+
 def test_find_invalid(tmpdir):
     tmp_path = Path(tmpdir)
 
@@ -137,7 +151,8 @@ def test_find_invalid(tmpdir):
         FT2Font(StringIO())
 
 
-@pytest.mark.skipif(sys.platform != 'linux', reason='Linux only')
+@pytest.mark.skipif(sys.platform != 'linux' or not has_fclist,
+                    reason='only Linux with fontconfig installed')
 def test_user_fonts_linux(tmpdir, monkeypatch):
     font_test_file = 'mpltest.ttf'
 
@@ -163,6 +178,22 @@ def test_user_fonts_linux(tmpdir, monkeypatch):
     _get_fontconfig_fonts.cache_clear()
 
 
+def test_addfont_as_path():
+    """Smoke test that addfont() accepts pathlib.Path."""
+    font_test_file = 'mpltest.ttf'
+    path = Path(__file__).parent / font_test_file
+    try:
+        fontManager.addfont(path)
+        added, = [font for font in fontManager.ttflist
+                  if font.fname.endswith(font_test_file)]
+        fontManager.ttflist.remove(added)
+    finally:
+        to_remove = [font for font in fontManager.ttflist
+                     if font.fname.endswith(font_test_file)]
+        for font in to_remove:
+            fontManager.ttflist.remove(font)
+
+
 @pytest.mark.skipif(sys.platform != 'win32', reason='Windows only')
 def test_user_fonts_win32():
     if not (os.environ.get('APPVEYOR') or os.environ.get('TF_BUILD')):
@@ -255,3 +286,41 @@ def test_fontcache_thread_safe():
     if proc.returncode:
         pytest.fail("The subprocess returned with non-zero exit status "
                     f"{proc.returncode}.")
+
+
+def test_fontentry_dataclass():
+    fontent = FontEntry(name='font-name')
+
+    png = fontent._repr_png_()
+    img = Image.open(BytesIO(png))
+    assert img.width > 0
+    assert img.height > 0
+
+    html = fontent._repr_html_()
+    assert html.startswith("<img src=\"data:image/png;base64")
+
+
+def test_fontentry_dataclass_invalid_path():
+    with pytest.raises(FileNotFoundError):
+        fontent = FontEntry(fname='/random', name='font-name')
+        fontent._repr_html_()
+
+
+@pytest.mark.skipif(sys.platform == 'win32', reason='Linux or OS only')
+def test_get_font_names():
+    paths_mpl = [cbook._get_data_path('fonts', subdir) for subdir in ['ttf']]
+    fonts_mpl = findSystemFonts(paths_mpl, fontext='ttf')
+    fonts_system = findSystemFonts(fontext='ttf')
+    ttf_fonts = []
+    for path in fonts_mpl + fonts_system:
+        try:
+            font = ft2font.FT2Font(path)
+            prop = ttfFontProperty(font)
+            ttf_fonts.append(prop.name)
+        except:
+            pass
+    available_fonts = sorted(list(set(ttf_fonts)))
+    mpl_font_names = sorted(fontManager.get_font_names())
+    assert set(available_fonts) == set(mpl_font_names)
+    assert len(available_fonts) == len(mpl_font_names)
+    assert available_fonts == mpl_font_names
