@@ -3,7 +3,7 @@ from numpy.testing import (assert_allclose, assert_almost_equal,
 import numpy as np
 import pytest
 
-import matplotlib.mlab as mlab
+from matplotlib import mlab, _api
 
 
 class TestStride:
@@ -13,6 +13,11 @@ class TestStride:
             y = y.base
         return y
 
+    @pytest.fixture(autouse=True)
+    def stride_is_deprecated(self):
+        with _api.suppress_matplotlib_deprecation_warning():
+            yield
+
     def calc_window_target(self, x, NFFT, noverlap=0, axis=0):
         """
         This is an adaptation of the original window extraction algorithm.
@@ -92,7 +97,7 @@ def test_window():
 
 
 class TestDetrend:
-    def setup(self):
+    def setup_method(self):
         np.random.seed(0)
         n = 1000
         x = np.linspace(0., 100, n)
