@@ -126,11 +126,12 @@ def test_auto_column():
     # iterable list input
     ax1 = fig.add_subplot(4, 1, 1)
     ax1.axis('off')
-    tb1 = ax1.table(cellText=[['Fit Text', 2],
-          ['very long long text, Longer text than default', 1]],
-          rowLabels=["A", "B"],
-          colLabels=["Col1", "Col2"],
-          loc="center")
+    tb1 = ax1.table(
+        cellText=[['Fit Text', 2],
+                  ['very long long text, Longer text than default', 1]],
+        rowLabels=["A", "B"],
+        colLabels=["Col1", "Col2"],
+        loc="center")
     tb1.auto_set_font_size(False)
     tb1.set_fontsize(12)
     tb1.auto_set_column_width([-1, 0, 1])
@@ -138,37 +139,40 @@ def test_auto_column():
     # iterable tuple input
     ax2 = fig.add_subplot(4, 1, 2)
     ax2.axis('off')
-    tb2 = ax2.table(cellText=[['Fit Text', 2],
-          ['very long long text, Longer text than default', 1]],
-          rowLabels=["A", "B"],
-          colLabels=["Col1", "Col2"],
-          loc="center")
+    tb2 = ax2.table(
+        cellText=[['Fit Text', 2],
+                  ['very long long text, Longer text than default', 1]],
+        rowLabels=["A", "B"],
+        colLabels=["Col1", "Col2"],
+        loc="center")
     tb2.auto_set_font_size(False)
     tb2.set_fontsize(12)
     tb2.auto_set_column_width((-1, 0, 1))
 
-    #3 single inputs
+    # 3 single inputs
     ax3 = fig.add_subplot(4, 1, 3)
     ax3.axis('off')
-    tb3 = ax3.table(cellText=[['Fit Text', 2],
-          ['very long long text, Longer text than default', 1]],
-          rowLabels=["A", "B"],
-          colLabels=["Col1", "Col2"],
-          loc="center")
+    tb3 = ax3.table(
+        cellText=[['Fit Text', 2],
+                  ['very long long text, Longer text than default', 1]],
+        rowLabels=["A", "B"],
+        colLabels=["Col1", "Col2"],
+        loc="center")
     tb3.auto_set_font_size(False)
     tb3.set_fontsize(12)
     tb3.auto_set_column_width(-1)
     tb3.auto_set_column_width(0)
     tb3.auto_set_column_width(1)
 
-    #4 non integer iterable input
+    # 4 non integer iterable input
     ax4 = fig.add_subplot(4, 1, 4)
     ax4.axis('off')
-    tb4 = ax4.table(cellText=[['Fit Text', 2],
-          ['very long long text, Longer text than default', 1]],
-          rowLabels=["A", "B"],
-          colLabels=["Col1", "Col2"],
-          loc="center")
+    tb4 = ax4.table(
+        cellText=[['Fit Text', 2],
+                  ['very long long text, Longer text than default', 1]],
+        rowLabels=["A", "B"],
+        colLabels=["Col1", "Col2"],
+        loc="center")
     tb4.auto_set_font_size(False)
     tb4.set_fontsize(12)
     tb4.auto_set_column_width("-101")
@@ -186,7 +190,7 @@ def test_table_cells():
     table[2, 1] = cell2
     assert table[2, 1] is cell2
 
-    # make sure gettitem support has not broken
+    # make sure getitem support has not broken
     # properties and setp
     table.properties()
     plt.setp(table)
