@@ -1,39 +1,24 @@
 """
-axis_artist.py module provides axis-related artists. They are
+The :mod:`.axis_artist` module implements custom artists to draw axis elements
+(axis lines and labels, tick lines and labels, grid lines).
 
-* axis line
-* tick lines
-* tick labels
-* axis label
-* grid lines
+Axis lines and labels and tick lines and labels are managed by the `AxisArtist`
+class; grid lines are managed by the `GridlinesCollection` class.
 
-The main artist classes are `AxisArtist` and `GridlinesCollection`. While
-`GridlinesCollection` is responsible for drawing grid lines, `AxisArtist`
-is responsible for all other artists. `AxisArtist` has attributes that are
-associated with each type of artists:
+There is one `AxisArtist` per Axis; it can be accessed through
+the ``axis`` dictionary of the parent Axes (which should be a
+`mpl_toolkits.axislines.Axes`), e.g. ``ax.axis["bottom"]``.
 
-* line: axis line
-* major_ticks: major tick lines
-* major_ticklabels: major tick labels
-* minor_ticks: minor tick lines
-* minor_ticklabels: minor tick labels
-* label: axis label
+Children of the AxisArtist are accessed as attributes: ``.line`` and ``.label``
+for the axis line and label, ``.major_ticks``, ``.major_ticklabels``,
+``.minor_ticks``, ``.minor_ticklabels`` for the tick lines and labels (e.g.
+``ax.axis["bottom"].line``).
 
-Typically, the `AxisArtist` associated with an axes will be accessed with the
-*axis* dictionary of the axes, i.e., the `AxisArtist` for the bottom axis is ::
+Children properties (colors, fonts, line widths, etc.) can be set using
+setters, e.g. ::
 
-  ax.axis["bottom"]
-
-where *ax* is an instance of `mpl_toolkits.axislines.Axes`.  Thus,
-``ax.axis["bottom"].line`` is an artist associated with the axis line, and
-``ax.axis["bottom"].major_ticks`` is an artist associated with the major tick
-lines.
-
-You can change the colors, fonts, line widths, etc. of these artists
-by calling suitable set method. For example, to change the color of the major
-ticks of the bottom axis to red, use ::
-
-  ax.axis["bottom"].major_ticks.set_color("r")
+  # Make the major ticks of the bottom axis red.
+  ax.axis["bottom"].major_ticks.set_color("red")
 
 However, things like the locations of ticks, and their ticklabels need to be
 changed from the side of the grid_helper.
@@ -73,7 +58,7 @@ axislabel ha        right  center   right  center
 Ticks are by default direct opposite side of the ticklabels. To make ticks to
 the same side of the ticklabels, ::
 
-  ax.axis["bottom"].major_ticks.set_ticks_out(True)
+  ax.axis["bottom"].major_ticks.set_tick_out(True)
 
 The following attributes can be customized (use the ``set_xxx`` methods):
 
@@ -90,90 +75,22 @@ from operator import methodcaller
 
 import numpy as np
 
-from matplotlib import cbook, rcParams
+import matplotlib as mpl
+from matplotlib import _api, cbook
 import matplotlib.artist as martist
+import matplotlib.colors as mcolors
 import matplotlib.text as mtext
-
 from matplotlib.collections import LineCollection
 from matplotlib.lines import Line2D
 from matplotlib.patches import PathPatch
 from matplotlib.path import Path
 from matplotlib.transforms import (
-    Affine2D, Bbox, IdentityTransform, ScaledTranslation, TransformedPath)
+    Affine2D, Bbox, IdentityTransform, ScaledTranslation)
 
 from .axisline_style import AxislineStyle
 
 
-@cbook.deprecated("3.2", alternative="matplotlib.patches.PathPatch")
-class BezierPath(Line2D):
-
-    def __init__(self, path, *args, **kwargs):
-        """
-        Parameters
-        ----------
-        path : `~.path.Path`
-            The path to draw.
-        **kwargs
-            All remaining keyword arguments are passed to `.Line2D`.
-        """
-        Line2D.__init__(self, [], [], *args, **kwargs)
-        self._path = path
-        self._invalid = False
-
-    def recache(self):
-        self._transformed_path = TransformedPath(
-            self._path, self.get_transform())
-        self._invalid = False
-
-    def set_path(self, path):
-        self._path = path
-        self._invalid = True
-
-    def draw(self, renderer):
-        if self._invalid:
-            self.recache()
-
-        if not self._visible:
-            return
-        renderer.open_group('line2d', gid=self.get_gid())
-
-        gc = renderer.new_gc()
-        self._set_gc_clip(gc)
-
-        gc.set_foreground(self._color)
-        gc.set_antialiased(self._antialiased)
-        gc.set_linewidth(self._linewidth)
-        gc.set_alpha(self._alpha)
-        if self.is_dashed():
-            cap = self._dashcapstyle
-            join = self._dashjoinstyle
-        else:
-            cap = self._solidcapstyle
-            join = self._solidjoinstyle
-        gc.set_joinstyle(join)
-        gc.set_capstyle(cap)
-        gc.set_dashes(self._dashOffset, self._dashSeq)
-
-        if self._lineStyles[self._linestyle] != '_draw_nothing':
-            tpath, affine = (
-                self._transformed_path.get_transformed_path_and_affine())
-            renderer.draw_path(gc, tpath, affine.frozen())
-
-        gc.restore()
-        renderer.close_group('line2d')
-
-
 class AttributeCopier:
-    @cbook.deprecated("3.2")
-    def __init__(self, ref_artist, klass=martist.Artist):
-        self._klass = klass
-        self._ref_artist = ref_artist
-        super().__init__()
-
-    @cbook.deprecated("3.2")
-    def set_ref_artist(self, artist):
-        self._ref_artist = artist
-
     def get_ref_artist(self):
         """
         Return the underlying artist that actually defines some properties
@@ -181,8 +98,7 @@ class AttributeCopier:
         """
         raise RuntimeError("get_ref_artist must overridden")
 
-    @cbook._delete_parameter("3.2", "default_value")
-    def get_attribute_from_ref_artist(self, attr_name, default_value=None):
+    def get_attribute_from_ref_artist(self, attr_name):
         getter = methodcaller("get_" + attr_name)
         prop = getter(super())
         return getter(self.get_ref_artist()) if prop == "auto" else prop
@@ -219,6 +135,14 @@ class Ticks(AttributeCopier, Line2D):
         # docstring inherited
         return self._axis.majorTicks[0].tick1line
 
+    def set_color(self, color):
+        # docstring inherited
+        # Unlike the base Line2D.set_color, this also supports "auto".
+        if not cbook._str_equal(color, "auto"):
+            mcolors._check_color_like(color=color)
+        self._color = color
+        self.stale = True
+
     def get_color(self):
         return self.get_attribute_from_ref_artist("color")
 
@@ -293,26 +217,16 @@ class LabelBase(mtext.Text):
         self.set_rotation_mode("anchor")
         self._text_follow_ref_angle = True
 
-    def _set_ref_angle(self, a):
-        self._ref_angle = a
-
-    def _get_ref_angle(self):
-        return self._ref_angle
-
-    def _get_text_ref_angle(self):
+    @property
+    def _text_ref_angle(self):
         if self._text_follow_ref_angle:
-            return self._get_ref_angle()+90
+            return self._ref_angle + 90
         else:
-            return 0  # self.get_ref_angle()
+            return 0
 
-    def _get_offset_ref_angle(self):
-        return self._get_ref_angle()
-
-    def _set_offset_radius(self, offset_radius):
-        self._offset_radius = offset_radius
-
-    def _get_offset_radius(self):
-        return self._offset_radius
+    @property
+    def _offset_ref_angle(self):
+        return self._ref_angle
 
     _get_opposite_direction = {"left": "right",
                                "right": "left",
@@ -326,31 +240,30 @@ class LabelBase(mtext.Text):
         # save original and adjust some properties
         tr = self.get_transform()
         angle_orig = self.get_rotation()
-        text_ref_angle = self._get_text_ref_angle()
-        offset_ref_angle = self._get_offset_ref_angle()
-        theta = np.deg2rad(offset_ref_angle)
-        dd = self._get_offset_radius()
+        theta = np.deg2rad(self._offset_ref_angle)
+        dd = self._offset_radius
         dx, dy = dd * np.cos(theta), dd * np.sin(theta)
 
         self.set_transform(tr + Affine2D().translate(dx, dy))
-        self.set_rotation(text_ref_angle+angle_orig)
+        self.set_rotation(self._text_ref_angle + angle_orig)
         super().draw(renderer)
         # restore original properties
         self.set_transform(tr)
         self.set_rotation(angle_orig)
 
-    def get_window_extent(self, renderer):
+    def get_window_extent(self, renderer=None):
+        if renderer is None:
+            renderer = self.figure._get_renderer()
+
         # save original and adjust some properties
         tr = self.get_transform()
         angle_orig = self.get_rotation()
-        text_ref_angle = self._get_text_ref_angle()
-        offset_ref_angle = self._get_offset_ref_angle()
-        theta = np.deg2rad(offset_ref_angle)
-        dd = self._get_offset_radius()
+        theta = np.deg2rad(self._offset_ref_angle)
+        dd = self._offset_radius
         dx, dy = dd * np.cos(theta), dd * np.sin(theta)
 
         self.set_transform(tr + Affine2D().translate(dx, dy))
-        self.set_rotation(text_ref_angle+angle_orig)
+        self.set_rotation(self._text_ref_angle + angle_orig)
         bbox = super().get_window_extent(renderer).frozen()
         # restore original properties
         self.set_transform(tr)
@@ -371,7 +284,7 @@ class AxisLabel(AttributeCopier, LabelBase):
     def __init__(self, *args, axis_direction="bottom", axis=None, **kwargs):
         self._axis = axis
         self._pad = 5
-        self._extra_pad = 0
+        self._external_pad = 0  # in pixels
         LabelBase.__init__(self, *args, **kwargs)
         self.set_axis_direction(axis_direction)
 
@@ -392,14 +305,6 @@ class AxisLabel(AttributeCopier, LabelBase):
         """
         return self._pad
 
-    def _set_external_pad(self, p):
-        """Set external pad in pixels."""
-        self._extra_pad = p
-
-    def _get_external_pad(self):
-        """Return external pad in pixels."""
-        return self._extra_pad
-
     def get_ref_artist(self):
         # docstring inherited
         return self._axis.get_label()
@@ -416,7 +321,7 @@ class AxisLabel(AttributeCopier, LabelBase):
                                top=("bottom", "center"))
 
     def set_default_alignment(self, d):
-        va, ha = cbook._check_getitem(self._default_alignments, d=d)
+        va, ha = _api.check_getitem(self._default_alignments, d=d)
         self.set_va(va)
         self.set_ha(ha)
 
@@ -426,7 +331,7 @@ class AxisLabel(AttributeCopier, LabelBase):
                            top=180)
 
     def set_default_angle(self, d):
-        self.set_rotation(cbook._check_getitem(self._default_angles, d=d))
+        self.set_rotation(_api.check_getitem(self._default_angles, d=d))
 
     def set_axis_direction(self, d):
         """
@@ -455,19 +360,19 @@ class AxisLabel(AttributeCopier, LabelBase):
         if not self.get_visible():
             return
 
-        pad = renderer.points_to_pixels(self.get_pad())
-        r = self._get_external_pad() + pad
-        self._set_offset_radius(r)
+        self._offset_radius = \
+            self._external_pad + renderer.points_to_pixels(self.get_pad())
 
         super().draw(renderer)
 
-    def get_window_extent(self, renderer):
+    def get_window_extent(self, renderer=None):
+        if renderer is None:
+            renderer = self.figure._get_renderer()
         if not self.get_visible():
             return
 
-        pad = renderer.points_to_pixels(self.get_pad())
-        r = self._get_external_pad() + pad
-        self._set_offset_radius(r)
+        r = self._external_pad + renderer.points_to_pixels(self.get_pad())
+        self._offset_radius = r
 
         bb = super().get_window_extent(renderer)
 
@@ -487,7 +392,7 @@ class TickLabels(AxisLabel):  # mtext.Text
     """
 
     def __init__(self, *, axis_direction="bottom", **kwargs):
-        AxisLabel.__init__(self, **kwargs)
+        super().__init__(**kwargs)
         self.set_axis_direction(axis_direction)
         self._axislabel_pad = 0
 
@@ -590,20 +495,19 @@ class TickLabels(AxisLabel):  # mtext.Text
 
     def draw(self, renderer):
         if not self.get_visible():
-            self._axislabel_pad = self._get_external_pad()
+            self._axislabel_pad = self._external_pad
             return
 
         r, total_width = self._get_ticklabels_offsets(renderer,
                                                       self._axis_direction)
 
-        pad = (self._get_external_pad()
-               + renderer.points_to_pixels(self.get_pad()))
-        self._set_offset_radius(r+pad)
+        pad = self._external_pad + renderer.points_to_pixels(self.get_pad())
+        self._offset_radius = r + pad
 
         for (x, y), a, l in self._locs_angles_labels:
             if not l.strip():
                 continue
-            self._set_ref_angle(a)  # + add_angle
+            self._ref_angle = a
             self.set_x(x)
             self.set_y(y)
             self.set_text(l)
@@ -615,10 +519,12 @@ class TickLabels(AxisLabel):  # mtext.Text
     def set_locs_angles_labels(self, locs_angles_labels):
         self._locs_angles_labels = locs_angles_labels
 
-    def get_window_extents(self, renderer):
+    def get_window_extents(self, renderer=None):
+        if renderer is None:
+            renderer = self.figure._get_renderer()
 
         if not self.get_visible():
-            self._axislabel_pad = self._get_external_pad()
+            self._axislabel_pad = self._external_pad
             return []
 
         bboxes = []
@@ -626,12 +532,11 @@ class TickLabels(AxisLabel):  # mtext.Text
         r, total_width = self._get_ticklabels_offsets(renderer,
                                                       self._axis_direction)
 
-        pad = self._get_external_pad() + \
-            renderer.points_to_pixels(self.get_pad())
-        self._set_offset_radius(r+pad)
+        pad = self._external_pad + renderer.points_to_pixels(self.get_pad())
+        self._offset_radius = r + pad
 
         for (x, y), a, l in self._locs_angles_labels:
-            self._set_ref_angle(a)  # + add_angle
+            self._ref_angle = a
             self.set_x(x)
             self.set_y(y)
             self.set_text(l)
@@ -686,10 +591,7 @@ class GridlinesCollection(LineCollection):
         if self._grid_helper is not None:
             self._grid_helper.update_lim(self.axes)
             gl = self._grid_helper.get_gridlines(self._which, self._axis)
-            if gl:
-                self.set_segments([np.transpose(l) for l in gl])
-            else:
-                self.set_segments([])
+            self.set_segments([np.transpose(l) for l in gl])
         super().draw(renderer)
 
 
@@ -699,7 +601,7 @@ class AxisArtist(martist.Artist):
     is constant) line, ticks, ticklabels, and axis label.
     """
 
-    zorder = ZORDER = 2.5  # ZORDER is a backcompat alias.
+    zorder = 2.5
 
     @property
     def LABELPAD(self):
@@ -720,7 +622,7 @@ class AxisArtist(martist.Artist):
         axes : `mpl_toolkits.axisartist.axislines.Axes`
         helper : `~mpl_toolkits.axisartist.axislines.AxisArtistHelper`
         """
-        #axes is also used to follow the axis attribute (tick color, etc).
+        # axes is also used to follow the axis attribute (tick color, etc).
 
         super().__init__(**kwargs)
 
@@ -753,11 +655,6 @@ class AxisArtist(martist.Artist):
         self._axislabel_add_angle = 0.
         self.set_axis_direction(axis_direction)
 
-    @cbook.deprecated("3.3")
-    @property
-    def dpi_transform(self):
-        return Affine2D().scale(1 / 72) + self.axes.figure.dpi_scale_trans
-
     # axis direction
 
     def set_axis_direction(self, axis_direction):
@@ -807,7 +704,7 @@ class AxisArtist(martist.Artist):
         ----------
         tick_direction : {"+", "-"}
         """
-        self._ticklabel_add_angle = cbook._check_getitem(
+        self._ticklabel_add_angle = _api.check_getitem(
             {"+": 0, "-": 180}, tick_direction=tick_direction)
 
     def invert_ticklabel_direction(self):
@@ -824,9 +721,9 @@ class AxisArtist(martist.Artist):
 
         Parameters
         ----------
-        tick_direction : {"+", "-"}
+        label_direction : {"+", "-"}
         """
-        self._axislabel_add_angle = cbook._check_getitem(
+        self._axislabel_add_angle = _api.check_getitem(
             {"+": 0, "-": 180}, label_direction=label_direction)
 
     def get_transform(self):
@@ -885,11 +782,11 @@ class AxisArtist(martist.Artist):
         if axisline_style is None:
             self.line = PathPatch(
                 self._axis_artist_helper.get_line(self.axes),
-                color=rcParams['axes.edgecolor'],
+                color=mpl.rcParams['axes.edgecolor'],
                 fill=False,
-                linewidth=rcParams['axes.linewidth'],
-                capstyle=rcParams['lines.solid_capstyle'],
-                joinstyle=rcParams['lines.solid_joinstyle'],
+                linewidth=mpl.rcParams['axes.linewidth'],
+                capstyle=mpl.rcParams['lines.solid_capstyle'],
+                joinstyle=mpl.rcParams['lines.solid_joinstyle'],
                 transform=tran)
         else:
             self.line = axisline_style(self, transform=tran)
@@ -908,14 +805,16 @@ class AxisArtist(martist.Artist):
 
         self.major_ticks = Ticks(
             kwargs.get(
-                "major_tick_size", rcParams[f"{axis_name}tick.major.size"]),
+                "major_tick_size",
+                mpl.rcParams[f"{axis_name}tick.major.size"]),
             axis=self.axis, transform=trans)
         self.minor_ticks = Ticks(
             kwargs.get(
-                "minor_tick_size", rcParams[f"{axis_name}tick.minor.size"]),
+                "minor_tick_size",
+                mpl.rcParams[f"{axis_name}tick.minor.size"]),
             axis=self.axis, transform=trans)
 
-        size = rcParams[f"{axis_name}tick.labelsize"]
+        size = mpl.rcParams[f"{axis_name}tick.labelsize"]
         self.major_ticklabels = TickLabels(
             axis=self.axis,
             axis_direction=self._axis_direction,
@@ -923,7 +822,7 @@ class AxisArtist(martist.Artist):
             transform=trans,
             fontsize=size,
             pad=kwargs.get(
-                "major_tick_pad", rcParams[f"{axis_name}tick.major.pad"]),
+                "major_tick_pad", mpl.rcParams[f"{axis_name}tick.major.pad"]),
         )
         self.minor_ticklabels = TickLabels(
             axis=self.axis,
@@ -932,7 +831,7 @@ class AxisArtist(martist.Artist):
             transform=trans,
             fontsize=size,
             pad=kwargs.get(
-                "minor_tick_pad", rcParams[f"{axis_name}tick.minor.pad"]),
+                "minor_tick_pad", mpl.rcParams[f"{axis_name}tick.minor.pad"]),
         )
 
     def _get_tick_info(self, tick_iter):
@@ -957,96 +856,45 @@ class AxisArtist(martist.Artist):
 
         return ticks_loc_angle, ticklabels_loc_angle_label
 
-    def _update_ticks(self, renderer):
+    def _update_ticks(self, renderer=None):
         # set extra pad for major and minor ticklabels: use ticksize of
         # majorticks even for minor ticks. not clear what is best.
 
+        if renderer is None:
+            renderer = self.figure._get_renderer()
+
         dpi_cor = renderer.points_to_pixels(1.)
         if self.major_ticks.get_visible() and self.major_ticks.get_tick_out():
-            self.major_ticklabels._set_external_pad(
-                self.major_ticks._ticksize * dpi_cor)
-            self.minor_ticklabels._set_external_pad(
-                self.major_ticks._ticksize * dpi_cor)
+            ticklabel_pad = self.major_ticks._ticksize * dpi_cor
+            self.major_ticklabels._external_pad = ticklabel_pad
+            self.minor_ticklabels._external_pad = ticklabel_pad
         else:
-            self.major_ticklabels._set_external_pad(0)
-            self.minor_ticklabels._set_external_pad(0)
+            self.major_ticklabels._external_pad = 0
+            self.minor_ticklabels._external_pad = 0
 
         majortick_iter, minortick_iter = \
             self._axis_artist_helper.get_tick_iterators(self.axes)
 
         tick_loc_angle, ticklabel_loc_angle_label = \
             self._get_tick_info(majortick_iter)
-
         self.major_ticks.set_locs_angles(tick_loc_angle)
         self.major_ticklabels.set_locs_angles_labels(ticklabel_loc_angle_label)
 
-        # minor ticks
         tick_loc_angle, ticklabel_loc_angle_label = \
             self._get_tick_info(minortick_iter)
-
         self.minor_ticks.set_locs_angles(tick_loc_angle)
         self.minor_ticklabels.set_locs_angles_labels(ticklabel_loc_angle_label)
 
-        return self.major_ticklabels.get_window_extents(renderer)
-
     def _draw_ticks(self, renderer):
-
-        extents = self._update_ticks(renderer)
-
+        self._update_ticks(renderer)
         self.major_ticks.draw(renderer)
         self.major_ticklabels.draw(renderer)
-
         self.minor_ticks.draw(renderer)
         self.minor_ticklabels.draw(renderer)
-
         if (self.major_ticklabels.get_visible()
                 or self.minor_ticklabels.get_visible()):
             self._draw_offsetText(renderer)
 
-        return extents
-
-    def _draw_ticks2(self, renderer):
-        # set extra pad for major and minor ticklabels: use ticksize of
-        # majorticks even for minor ticks. not clear what is best.
-
-        dpi_cor = renderer.points_to_pixels(1.)
-        if self.major_ticks.get_visible() and self.major_ticks.get_tick_out():
-            self.major_ticklabels._set_external_pad(
-                self.major_ticks._ticksize * dpi_cor)
-            self.minor_ticklabels._set_external_pad(
-                self.major_ticks._ticksize * dpi_cor)
-        else:
-            self.major_ticklabels._set_external_pad(0)
-            self.minor_ticklabels._set_external_pad(0)
-
-        majortick_iter, minortick_iter = \
-            self._axis_artist_helper.get_tick_iterators(self.axes)
-
-        tick_loc_angle, ticklabel_loc_angle_label = \
-            self._get_tick_info(majortick_iter)
-
-        self.major_ticks.set_locs_angles(tick_loc_angle)
-        self.major_ticklabels.set_locs_angles_labels(ticklabel_loc_angle_label)
-
-        self.major_ticks.draw(renderer)
-        self.major_ticklabels.draw(renderer)
-
-        # minor ticks
-        tick_loc_angle, ticklabel_loc_angle_label = \
-            self._get_tick_info(minortick_iter)
-
-        self.minor_ticks.set_locs_angles(tick_loc_angle)
-        self.minor_ticklabels.set_locs_angles_labels(ticklabel_loc_angle_label)
-
-        self.minor_ticks.draw(renderer)
-        self.minor_ticklabels.draw(renderer)
-
-        if (self.major_ticklabels.get_visible()
-                or self.minor_ticklabels.get_visible()):
-            self._draw_offsetText(renderer)
-
-        return self.major_ticklabels.get_window_extents(renderer)
-
     _offsetText_pos = dict(left=(0, 1, "bottom", "right"),
                            right=(1, 1, "bottom", "left"),
                            bottom=(1, 0, "top", "right"),
@@ -1058,7 +906,7 @@ class AxisArtist(martist.Artist):
             "",
             xy=(x, y), xycoords="axes fraction",
             xytext=(0, 0), textcoords="offset points",
-            color=rcParams['xtick.color'],
+            color=mpl.rcParams['xtick.color'],
             horizontalalignment=ha, verticalalignment=va,
         )
         self.offsetText.set_transform(IdentityTransform())
@@ -1082,8 +930,8 @@ class AxisArtist(martist.Artist):
         self.label = AxisLabel(
             0, 0, "__from_axes__",
             color="auto",
-            fontsize=kwargs.get("labelsize", rcParams['axes.labelsize']),
-            fontweight=rcParams['axes.labelweight'],
+            fontsize=kwargs.get("labelsize", mpl.rcParams['axes.labelsize']),
+            fontweight=mpl.rcParams['axes.labelweight'],
             axis=self.axis,
             transform=tr,
             axis_direction=self._axis_direction,
@@ -1108,7 +956,7 @@ class AxisArtist(martist.Artist):
             axislabel_pad = max(self.major_ticklabels._axislabel_pad,
                                 self.minor_ticklabels._axislabel_pad)
 
-        self.label._set_external_pad(axislabel_pad)
+        self.label._external_pad = axislabel_pad
 
         xy, angle_tangent = \
             self._axis_artist_helper.get_axislabel_pos_angle(self.axes)
@@ -1118,47 +966,17 @@ class AxisArtist(martist.Artist):
         angle_label = angle_tangent - 90
 
         x, y = xy
-        self.label._set_ref_angle(angle_label+self._axislabel_add_angle)
+        self.label._ref_angle = angle_label + self._axislabel_add_angle
         self.label.set(x=x, y=y)
 
     def _draw_label(self, renderer):
         self._update_label(renderer)
         self.label.draw(renderer)
 
-    def _draw_label2(self, renderer):
-        if not self.label.get_visible():
-            return
-
-        if self._ticklabel_add_angle != self._axislabel_add_angle:
-            if ((self.major_ticks.get_visible()
-                 and not self.major_ticks.get_tick_out())
-                or (self.minor_ticks.get_visible()
-                    and not self.major_ticks.get_tick_out())):
-                axislabel_pad = self.major_ticks._ticksize
-            else:
-                axislabel_pad = 0
-        else:
-            axislabel_pad = max(self.major_ticklabels._axislabel_pad,
-                                self.minor_ticklabels._axislabel_pad)
-
-        self.label._set_external_pad(axislabel_pad)
-
-        xy, angle_tangent = \
-            self._axis_artist_helper.get_axislabel_pos_angle(self.axes)
-        if xy is None:
-            return
-
-        angle_label = angle_tangent - 90
-
-        x, y = xy
-        self.label._set_ref_angle(angle_label+self._axislabel_add_angle)
-        self.label.set(x=x, y=y)
-        self.label.draw(renderer)
-
     def set_label(self, s):
         self.label.set_text(s)
 
-    def get_tightbbox(self, renderer):
+    def get_tightbbox(self, renderer=None):
         if not self.get_visible():
             return
         self._axis_artist_helper.update_lim(self.axes)
