@@ -7,6 +7,9 @@
 // From Python
 #include <structmember.h>
 
+#include <set>
+#include <algorithm>
+
 #define STRINGIFY(s) XSTRINGIFY(s)
 #define XSTRINGIFY(s) #s
 
@@ -33,6 +36,8 @@ typedef struct
     Py_ssize_t suboffsets[2];
 } PyFT2Image;
 
+static PyTypeObject PyFT2ImageType;
+
 static PyObject *PyFT2Image_new(PyTypeObject *type, PyObject *args, PyObject *kwds)
 {
     PyFT2Image *self;
@@ -62,7 +67,7 @@ static void PyFT2Image_dealloc(PyFT2Image *self)
 }
 
 const char *PyFT2Image_draw_rect__doc__ =
-    "draw_rect(x0, y0, x1, y1)\n"
+    "draw_rect(self, x0, y0, x1, y1)\n"
     "--\n\n"
     "Draw an empty rectangle to the image.\n";
 
@@ -80,7 +85,7 @@ static PyObject *PyFT2Image_draw_rect(PyFT2Image *self, PyObject *args)
 }
 
 const char *PyFT2Image_draw_rect_filled__doc__ =
-    "draw_rect_filled(x0, y0, x1, y1)\n"
+    "draw_rect_filled(self, x0, y0, x1, y1)\n"
     "--\n\n"
     "Draw a filled rectangle to the image.\n";
 
@@ -121,9 +126,7 @@ static int PyFT2Image_get_buffer(PyFT2Image *self, Py_buffer *buf, int flags)
     return 1;
 }
 
-static PyTypeObject PyFT2ImageType;
-
-static PyTypeObject *PyFT2Image_init_type(PyObject *m, PyTypeObject *type)
+static PyTypeObject* PyFT2Image_init_type()
 {
     static PyMethodDef methods[] = {
         {"draw_rect", (PyCFunction)PyFT2Image_draw_rect, METH_VARARGS, PyFT2Image_draw_rect__doc__},
@@ -132,28 +135,18 @@ static PyTypeObject *PyFT2Image_init_type(PyObject *m, PyTypeObject *type)
     };
 
     static PyBufferProcs buffer_procs;
-    memset(&buffer_procs, 0, sizeof(PyBufferProcs));
     buffer_procs.bf_getbuffer = (getbufferproc)PyFT2Image_get_buffer;
 
-    memset(type, 0, sizeof(PyTypeObject));
-    type->tp_name = "matplotlib.ft2font.FT2Image";
-    type->tp_basicsize = sizeof(PyFT2Image);
-    type->tp_dealloc = (destructor)PyFT2Image_dealloc;
-    type->tp_flags = Py_TPFLAGS_DEFAULT | Py_TPFLAGS_BASETYPE;
-    type->tp_methods = methods;
-    type->tp_new = PyFT2Image_new;
-    type->tp_init = (initproc)PyFT2Image_init;
-    type->tp_as_buffer = &buffer_procs;
+    PyFT2ImageType.tp_name = "matplotlib.ft2font.FT2Image";
+    PyFT2ImageType.tp_basicsize = sizeof(PyFT2Image);
+    PyFT2ImageType.tp_dealloc = (destructor)PyFT2Image_dealloc;
+    PyFT2ImageType.tp_flags = Py_TPFLAGS_DEFAULT | Py_TPFLAGS_BASETYPE;
+    PyFT2ImageType.tp_methods = methods;
+    PyFT2ImageType.tp_new = PyFT2Image_new;
+    PyFT2ImageType.tp_init = (initproc)PyFT2Image_init;
+    PyFT2ImageType.tp_as_buffer = &buffer_procs;
 
-    if (PyType_Ready(type) < 0) {
-        return NULL;
-    }
-
-    if (PyModule_AddObject(m, "FT2Image", (PyObject *)type)) {
-        return NULL;
-    }
-
-    return type;
+    return &PyFT2ImageType;
 }
 
 /**********************************************************************
@@ -178,14 +171,16 @@ typedef struct
 
 static PyTypeObject PyGlyphType;
 
-static PyObject *
-PyGlyph_new(const FT_Face &face, const FT_Glyph &glyph, size_t ind, long hinting_factor)
+static PyObject *PyGlyph_from_FT2Font(const FT2Font *font)
 {
+    const FT_Face &face = font->get_face();
+    const long hinting_factor = font->get_hinting_factor();
+    const FT_Glyph &glyph = font->get_last_glyph();
+
     PyGlyph *self;
     self = (PyGlyph *)PyGlyphType.tp_alloc(&PyGlyphType, 0);
 
-    self->glyphInd = ind;
-
+    self->glyphInd = font->get_last_glyph_index();
     FT_Glyph_Get_CBox(glyph, ft_glyph_bbox_subpixels, &self->bbox);
 
     self->width = face->glyph->metrics.width / hinting_factor;
@@ -212,7 +207,7 @@ static PyObject *PyGlyph_get_bbox(PyGlyph *self, void *closure)
         "llll", self->bbox.xMin, self->bbox.yMin, self->bbox.xMax, self->bbox.yMax);
 }
 
-static PyTypeObject *PyGlyph_init_type(PyObject *m, PyTypeObject *type)
+static PyTypeObject *PyGlyph_init_type()
 {
     static PyMemberDef members[] = {
         {(char *)"width", T_LONG, offsetof(PyGlyph, width), READONLY, (char *)""},
@@ -232,39 +227,33 @@ static PyTypeObject *PyGlyph_init_type(PyObject *m, PyTypeObject *type)
         {NULL}
     };
 
-    memset(type, 0, sizeof(PyTypeObject));
-    type->tp_name = "matplotlib.ft2font.Glyph";
-    type->tp_basicsize = sizeof(PyGlyph);
-    type->tp_dealloc = (destructor)PyGlyph_dealloc;
-    type->tp_flags = Py_TPFLAGS_DEFAULT | Py_TPFLAGS_BASETYPE;
-    type->tp_members = members;
-    type->tp_getset = getset;
+    PyGlyphType.tp_name = "matplotlib.ft2font.Glyph";
+    PyGlyphType.tp_basicsize = sizeof(PyGlyph);
+    PyGlyphType.tp_dealloc = (destructor)PyGlyph_dealloc;
+    PyGlyphType.tp_flags = Py_TPFLAGS_DEFAULT | Py_TPFLAGS_BASETYPE;
+    PyGlyphType.tp_members = members;
+    PyGlyphType.tp_getset = getset;
 
-    if (PyType_Ready(type) < 0) {
-        return NULL;
-    }
-
-    /* Don't need to add to module, since you can't create glyphs
-       directly from Python */
-
-    return type;
+    return &PyGlyphType;
 }
 
 /**********************************************************************
  * FT2Font
  * */
 
-typedef struct
+struct PyFT2Font
 {
     PyObject_HEAD
     FT2Font *x;
-    PyObject *fname;
     PyObject *py_file;
     FT_StreamRec stream;
     Py_ssize_t shape[2];
     Py_ssize_t strides[2];
     Py_ssize_t suboffsets[2];
-} PyFT2Font;
+    std::vector<PyObject *> fallbacks;
+};
+
+static PyTypeObject PyFT2FontType;
 
 static unsigned long read_from_file_callback(FT_Stream stream,
                                              unsigned long offset,
@@ -292,11 +281,13 @@ exit:
             return 1;  // Non-zero signals error, when count == 0.
         }
     }
-    return n_read;
+    return (unsigned long)n_read;
 }
 
 static void close_file_callback(FT_Stream stream)
 {
+    PyObject *type, *value, *traceback;
+    PyErr_Fetch(&type, &value, &traceback);
     PyFT2Font *self = (PyFT2Font *)stream->descriptor.pointer;
     PyObject *close_result = NULL;
     if (!(close_result = PyObject_CallMethod(self->py_file, "close", ""))) {
@@ -308,26 +299,38 @@ exit:
     if (PyErr_Occurred()) {
         PyErr_WriteUnraisable((PyObject*)self);
     }
+    PyErr_Restore(type, value, traceback);
 }
 
-static PyTypeObject PyFT2FontType;
-
 static PyObject *PyFT2Font_new(PyTypeObject *type, PyObject *args, PyObject *kwds)
 {
     PyFT2Font *self;
     self = (PyFT2Font *)type->tp_alloc(type, 0);
     self->x = NULL;
-    self->fname = NULL;
     self->py_file = NULL;
     memset(&self->stream, 0, sizeof(FT_StreamRec));
     return (PyObject *)self;
 }
 
 const char *PyFT2Font_init__doc__ =
-    "FT2Font(ttffile)\n"
+    "FT2Font(filename, hinting_factor=8, *, _fallback_list=None, _kerning_factor=0)\n"
     "--\n\n"
     "Create a new FT2Font object.\n"
     "\n"
+    "Parameters\n"
+    "----------\n"
+    "filename : str or file-like\n"
+    "    The source of the font data in a format (ttf or ttc) that FreeType can read\n\n"
+    "hinting_factor : int, optional\n"
+    "    Must be positive. Used to scale the hinting in the x-direction\n"
+    "_fallback_list : list of FT2Font, optional\n"
+    "    A list of FT2Font objects used to find missing glyphs.\n\n"
+    "    .. warning::\n"
+    "        This API is both private and provisional: do not use it directly\n\n"
+    "_kerning_factor : int, optional\n"
+    "    Used to adjust the degree of kerning.\n\n"
+    "    .. warning::\n"
+    "        This API is private: do not use it directly\n\n"
     "Attributes\n"
     "----------\n"
     "num_faces\n"
@@ -361,17 +364,24 @@ const char *PyFT2Font_init__doc__ =
 
 static int PyFT2Font_init(PyFT2Font *self, PyObject *args, PyObject *kwds)
 {
-    PyObject *filename = NULL, *open = NULL, *data = NULL;
+    PyObject *filename = NULL, *open = NULL, *data = NULL, *fallback_list = NULL;
     FT_Open_Args open_args;
     long hinting_factor = 8;
     int kerning_factor = 0;
-    const char *names[] = { "filename", "hinting_factor", "_kerning_factor", NULL };
-
+    const char *names[] = {
+        "filename", "hinting_factor", "_fallback_list", "_kerning_factor", NULL
+    };
+    std::vector<FT2Font *> fallback_fonts;
     if (!PyArg_ParseTupleAndKeywords(
-             args, kwds, "O|l$i:FT2Font", (char **)names, &filename,
-             &hinting_factor, &kerning_factor)) {
+             args, kwds, "O|l$Oi:FT2Font", (char **)names, &filename,
+             &hinting_factor, &fallback_list, &kerning_factor)) {
         return -1;
     }
+    if (hinting_factor <= 0) {
+      PyErr_SetString(PyExc_ValueError,
+                      "hinting_factor must be greater than 0");
+      goto exit;
+    }
 
     self->stream.base = NULL;
     self->stream.size = 0x7fffffff;  // Unknown size.
@@ -382,6 +392,37 @@ static int PyFT2Font_init(PyFT2Font *self, PyObject *args, PyObject *kwds)
     open_args.flags = FT_OPEN_STREAM;
     open_args.stream = &self->stream;
 
+    if (fallback_list) {
+        if (!PyList_Check(fallback_list)) {
+            PyErr_SetString(PyExc_TypeError, "Fallback list must be a list");
+            goto exit;
+        }
+        Py_ssize_t size = PyList_Size(fallback_list);
+
+        // go through fallbacks once to make sure the types are right
+        for (Py_ssize_t i = 0; i < size; ++i) {
+            // this returns a borrowed reference
+            PyObject* item = PyList_GetItem(fallback_list, i);
+            if (!PyObject_IsInstance(item, PyObject_Type(reinterpret_cast<PyObject *>(self)))) {
+                PyErr_SetString(PyExc_TypeError, "Fallback fonts must be FT2Font objects.");
+                goto exit;
+            }
+        }
+        // go through a second time to add them to our lists
+        for (Py_ssize_t i = 0; i < size; ++i) {
+            // this returns a borrowed reference
+            PyObject* item = PyList_GetItem(fallback_list, i);
+            // Increase the ref count, we will undo this in dealloc this makes
+            // sure things do not get gc'd under us!
+            Py_INCREF(item);
+            self->fallbacks.push_back(item);
+            // Also (locally) cache the underlying FT2Font objects. As long as
+            // the Python objects are kept alive, these pointer are good.
+            FT2Font *fback = reinterpret_cast<PyFT2Font *>(item)->x;
+            fallback_fonts.push_back(fback);
+        }
+    }
+
     if (PyBytes_Check(filename) || PyUnicode_Check(filename)) {
         if (!(open = PyDict_GetItemString(PyEval_GetBuiltins(), "open"))  // Borrowed reference.
             || !(self->py_file = PyObject_CallFunction(open, "Os", filename, "rb"))) {
@@ -403,14 +444,11 @@ static int PyFT2Font_init(PyFT2Font *self, PyObject *args, PyObject *kwds)
     Py_CLEAR(data);
 
     CALL_CPP_FULL(
-        "FT2Font", (self->x = new FT2Font(open_args, hinting_factor)),
+        "FT2Font", (self->x = new FT2Font(open_args, hinting_factor, fallback_fonts)),
         Py_CLEAR(self->py_file), -1);
 
     CALL_CPP_INIT("FT2Font->set_kerning_factor", (self->x->set_kerning_factor(kerning_factor)));
 
-    Py_INCREF(filename);
-    self->fname = filename;
-
 exit:
     return PyErr_Occurred() ? -1 : 0;
 }
@@ -418,13 +456,16 @@ exit:
 static void PyFT2Font_dealloc(PyFT2Font *self)
 {
     delete self->x;
+    for (size_t i = 0; i < self->fallbacks.size(); i++) {
+        Py_DECREF(self->fallbacks[i]);
+    }
+
     Py_XDECREF(self->py_file);
-    Py_XDECREF(self->fname);
     Py_TYPE(self)->tp_free((PyObject *)self);
 }
 
 const char *PyFT2Font_clear__doc__ =
-    "clear()\n"
+    "clear(self)\n"
     "--\n\n"
     "Clear all the glyphs, reset for a new call to `.set_text`.\n";
 
@@ -436,7 +477,7 @@ static PyObject *PyFT2Font_clear(PyFT2Font *self, PyObject *args)
 }
 
 const char *PyFT2Font_set_size__doc__ =
-    "set_size(ptsize, dpi)\n"
+    "set_size(self, ptsize, dpi)\n"
     "--\n\n"
     "Set the point size and dpi of the text.\n";
 
@@ -455,7 +496,7 @@ static PyObject *PyFT2Font_set_size(PyFT2Font *self, PyObject *args)
 }
 
 const char *PyFT2Font_set_charmap__doc__ =
-    "set_charmap(i)\n"
+    "set_charmap(self, i)\n"
     "--\n\n"
     "Make the i-th charmap current.\n";
 
@@ -473,7 +514,7 @@ static PyObject *PyFT2Font_set_charmap(PyFT2Font *self, PyObject *args)
 }
 
 const char *PyFT2Font_select_charmap__doc__ =
-    "select_charmap(i)\n"
+    "select_charmap(self, i)\n"
     "--\n\n"
     "Select a charmap by its FT_Encoding number.\n";
 
@@ -491,30 +532,101 @@ static PyObject *PyFT2Font_select_charmap(PyFT2Font *self, PyObject *args)
 }
 
 const char *PyFT2Font_get_kerning__doc__ =
-    "get_kerning(left, right, mode)\n"
+    "get_kerning(self, left, right, mode)\n"
     "--\n\n"
     "Get the kerning between *left* and *right* glyph indices.\n"
-    "*mode* is a kerning mode constant:\n"
-    "  KERNING_DEFAULT  - Return scaled and grid-fitted kerning distances\n"
-    "  KERNING_UNFITTED - Return scaled but un-grid-fitted kerning distances\n"
-    "  KERNING_UNSCALED - Return the kerning vector in original font units\n";
+    "*mode* is a kerning mode constant:\n\n"
+    "    - KERNING_DEFAULT  - Return scaled and grid-fitted kerning distances\n"
+    "    - KERNING_UNFITTED - Return scaled but un-grid-fitted kerning distances\n"
+    "    - KERNING_UNSCALED - Return the kerning vector in original font units\n";
 
 static PyObject *PyFT2Font_get_kerning(PyFT2Font *self, PyObject *args)
 {
     FT_UInt left, right, mode;
     int result;
+    int fallback = 1;
 
     if (!PyArg_ParseTuple(args, "III:get_kerning", &left, &right, &mode)) {
         return NULL;
     }
 
-    CALL_CPP("get_kerning", (result = self->x->get_kerning(left, right, mode)));
+    CALL_CPP("get_kerning", (result = self->x->get_kerning(left, right, mode, (bool)fallback)));
 
     return PyLong_FromLong(result);
 }
 
+const char *PyFT2Font_get_fontmap__doc__ =
+    "_get_fontmap(self, string)\n"
+    "--\n\n"
+    "Get a mapping between characters and the font that includes them.\n"
+    "A dictionary mapping unicode characters to PyFT2Font objects.";
+static PyObject *PyFT2Font_get_fontmap(PyFT2Font *self, PyObject *args, PyObject *kwds)
+{
+    PyObject *textobj;
+    const char *names[] = { "string", NULL };
+
+    if (!PyArg_ParseTupleAndKeywords(
+            args, kwds, "O:_get_fontmap", (char **)names, &textobj)) {
+        return NULL;
+    }
+
+    std::set<FT_ULong> codepoints;
+    size_t size;
+
+    if (PyUnicode_Check(textobj)) {
+        size = PyUnicode_GET_LENGTH(textobj);
+#if defined(PYPY_VERSION) && (PYPY_VERSION_NUM < 0x07040000)
+        // PyUnicode_ReadChar is available from PyPy 7.3.2, but wheels do not
+        // specify the micro-release version, so put the version bound at 7.4
+        // to prevent generating wheels unusable on PyPy 7.3.{0,1}.
+        Py_UNICODE *unistr = PyUnicode_AsUnicode(textobj);
+        for (size_t i = 0; i < size; ++i) {
+            codepoints.insert(unistr[i]);
+        }
+#else
+        for (size_t i = 0; i < size; ++i) {
+            codepoints.insert(PyUnicode_ReadChar(textobj, i));
+        }
+#endif
+    } else {
+        PyErr_SetString(PyExc_TypeError, "string must be str");
+        return NULL;
+    }
+    PyObject *char_to_font;
+    if (!(char_to_font = PyDict_New())) {
+        return NULL;
+    }
+    for (auto it = codepoints.begin(); it != codepoints.end(); ++it) {
+        auto x = *it;
+        PyObject* target_font;
+        int index;
+        if (self->x->get_char_fallback_index(x, index)) {
+            if (index >= 0) {
+                target_font = self->fallbacks[index];
+            } else {
+                target_font = (PyObject *)self;
+            }
+        } else {
+            // TODO Handle recursion!
+            target_font = (PyObject *)self;
+        }
+
+        PyObject *key = NULL;
+        bool error = (!(key = PyUnicode_FromFormat("%c", x))
+                      || (PyDict_SetItem(char_to_font, key, target_font) == -1));
+        Py_XDECREF(key);
+        if (error) {
+            Py_DECREF(char_to_font);
+            PyErr_SetString(PyExc_ValueError, "Something went very wrong");
+            return NULL;
+        }
+    }
+    return char_to_font;
+}
+
+
 const char *PyFT2Font_set_text__doc__ =
-    "set_text(string, angle, flags=32)\n"
+    "set_text(self, string, angle, flags=32)\n"
     "--\n\n"
     "Set the text *string* and *angle*.\n"
     "*flags* can be a bitwise-or of the LOAD_XXX constants;\n"
@@ -557,22 +669,8 @@ static PyObject *PyFT2Font_set_text(PyFT2Font *self, PyObject *args, PyObject *k
             codepoints[i] = PyUnicode_ReadChar(textobj, i);
         }
 #endif
-    } else if (PyBytes_Check(textobj)) {
-        if (PyErr_WarnEx(
-            PyExc_FutureWarning,
-            "Passing bytes to FTFont.set_text is deprecated since Matplotlib "
-            "3.4 and support will be removed in Matplotlib 3.6; pass str instead",
-            1)) {
-            return NULL;
-        }
-        size = PyBytes_Size(textobj);
-        codepoints.resize(size);
-        char *bytestr = PyBytes_AsString(textobj);
-        for (size_t i = 0; i < size; ++i) {
-            codepoints[i] = bytestr[i];
-        }
     } else {
-        PyErr_SetString(PyExc_TypeError, "String must be str or bytes");
+        PyErr_SetString(PyExc_TypeError, "set_text requires str-input.");
         return NULL;
     }
 
@@ -586,95 +684,93 @@ static PyObject *PyFT2Font_set_text(PyFT2Font *self, PyObject *args, PyObject *k
 }
 
 const char *PyFT2Font_get_num_glyphs__doc__ =
-    "get_num_glyphs()\n"
+    "get_num_glyphs(self)\n"
     "--\n\n"
     "Return the number of loaded glyphs.\n";
 
 static PyObject *PyFT2Font_get_num_glyphs(PyFT2Font *self, PyObject *args)
 {
-    return PyLong_FromLong(self->x->get_num_glyphs());
+    return PyLong_FromSize_t(self->x->get_num_glyphs());
 }
 
 const char *PyFT2Font_load_char__doc__ =
-    "load_char(charcode, flags=32)\n"
+    "load_char(self, charcode, flags=32)\n"
     "--\n\n"
     "Load character with *charcode* in current fontfile and set glyph.\n"
     "*flags* can be a bitwise-or of the LOAD_XXX constants;\n"
     "the default value is LOAD_FORCE_AUTOHINT.\n"
-    "Return value is a Glyph object, with attributes\n"
-    "  width          # glyph width\n"
-    "  height         # glyph height\n"
-    "  bbox           # the glyph bbox (xmin, ymin, xmax, ymax)\n"
-    "  horiBearingX   # left side bearing in horizontal layouts\n"
-    "  horiBearingY   # top side bearing in horizontal layouts\n"
-    "  horiAdvance    # advance width for horizontal layout\n"
-    "  vertBearingX   # left side bearing in vertical layouts\n"
-    "  vertBearingY   # top side bearing in vertical layouts\n"
-    "  vertAdvance    # advance height for vertical layout\n";
+    "Return value is a Glyph object, with attributes\n\n"
+    "- width: glyph width\n"
+    "- height: glyph height\n"
+    "- bbox: the glyph bbox (xmin, ymin, xmax, ymax)\n"
+    "- horiBearingX: left side bearing in horizontal layouts\n"
+    "- horiBearingY: top side bearing in horizontal layouts\n"
+    "- horiAdvance: advance width for horizontal layout\n"
+    "- vertBearingX: left side bearing in vertical layouts\n"
+    "- vertBearingY: top side bearing in vertical layouts\n"
+    "- vertAdvance: advance height for vertical layout\n";
 
 static PyObject *PyFT2Font_load_char(PyFT2Font *self, PyObject *args, PyObject *kwds)
 {
     long charcode;
+    int fallback = 1;
     FT_Int32 flags = FT_LOAD_FORCE_AUTOHINT;
     const char *names[] = { "charcode", "flags", NULL };
 
     /* This makes a technically incorrect assumption that FT_Int32 is
        int. In theory it can also be long, if the size of int is less
        than 32 bits. This is very unlikely on modern platforms. */
-    if (!PyArg_ParseTupleAndKeywords(
-             args, kwds, "l|i:load_char", (char **)names, &charcode, &flags)) {
+    if (!PyArg_ParseTupleAndKeywords(args, kwds, "l|i:load_char", (char **)names, &charcode,
+                                     &flags)) {
         return NULL;
     }
 
-    CALL_CPP("load_char", (self->x->load_char(charcode, flags)));
+    FT2Font *ft_object = NULL;
+    CALL_CPP("load_char", (self->x->load_char(charcode, flags, ft_object, (bool)fallback)));
 
-    return PyGlyph_new(self->x->get_face(),
-                       self->x->get_last_glyph(),
-                       self->x->get_last_glyph_index(),
-                       self->x->get_hinting_factor());
+    return PyGlyph_from_FT2Font(ft_object);
 }
 
 const char *PyFT2Font_load_glyph__doc__ =
-    "load_glyph(glyphindex, flags=32)\n"
+    "load_glyph(self, glyphindex, flags=32)\n"
     "--\n\n"
     "Load character with *glyphindex* in current fontfile and set glyph.\n"
     "*flags* can be a bitwise-or of the LOAD_XXX constants;\n"
     "the default value is LOAD_FORCE_AUTOHINT.\n"
-    "Return value is a Glyph object, with attributes\n"
-    "  width          # glyph width\n"
-    "  height         # glyph height\n"
-    "  bbox           # the glyph bbox (xmin, ymin, xmax, ymax)\n"
-    "  horiBearingX   # left side bearing in horizontal layouts\n"
-    "  horiBearingY   # top side bearing in horizontal layouts\n"
-    "  horiAdvance    # advance width for horizontal layout\n"
-    "  vertBearingX   # left side bearing in vertical layouts\n"
-    "  vertBearingY   # top side bearing in vertical layouts\n"
-    "  vertAdvance    # advance height for vertical layout\n";
+    "Return value is a Glyph object, with attributes\n\n"
+    "- width: glyph width\n"
+    "- height: glyph height\n"
+    "- bbox: the glyph bbox (xmin, ymin, xmax, ymax)\n"
+    "- horiBearingX: left side bearing in horizontal layouts\n"
+    "- horiBearingY: top side bearing in horizontal layouts\n"
+    "- horiAdvance: advance width for horizontal layout\n"
+    "- vertBearingX: left side bearing in vertical layouts\n"
+    "- vertBearingY: top side bearing in vertical layouts\n"
+    "- vertAdvance: advance height for vertical layout\n";
 
 static PyObject *PyFT2Font_load_glyph(PyFT2Font *self, PyObject *args, PyObject *kwds)
 {
     FT_UInt glyph_index;
     FT_Int32 flags = FT_LOAD_FORCE_AUTOHINT;
+    int fallback = 1;
     const char *names[] = { "glyph_index", "flags", NULL };
 
     /* This makes a technically incorrect assumption that FT_Int32 is
        int. In theory it can also be long, if the size of int is less
        than 32 bits. This is very unlikely on modern platforms. */
-    if (!PyArg_ParseTupleAndKeywords(
-             args, kwds, "I|i:load_glyph", (char **)names, &glyph_index, &flags)) {
+    if (!PyArg_ParseTupleAndKeywords(args, kwds, "I|i:load_glyph", (char **)names, &glyph_index,
+                                     &flags)) {
         return NULL;
     }
 
-    CALL_CPP("load_glyph", (self->x->load_glyph(glyph_index, flags)));
+    FT2Font *ft_object = NULL;
+    CALL_CPP("load_glyph", (self->x->load_glyph(glyph_index, flags, ft_object, (bool)fallback)));
 
-    return PyGlyph_new(self->x->get_face(),
-                       self->x->get_last_glyph(),
-                       self->x->get_last_glyph_index(),
-                       self->x->get_hinting_factor());
+    return PyGlyph_from_FT2Font(ft_object);
 }
 
 const char *PyFT2Font_get_width_height__doc__ =
-    "get_width_height()\n"
+    "get_width_height(self)\n"
     "--\n\n"
     "Get the width and height in 26.6 subpixels of the current string set by `.set_text`.\n"
     "The rotation of the string is accounted for.  To get width and height\n"
@@ -690,7 +786,7 @@ static PyObject *PyFT2Font_get_width_height(PyFT2Font *self, PyObject *args)
 }
 
 const char *PyFT2Font_get_bitmap_offset__doc__ =
-    "get_bitmap_offset()\n"
+    "get_bitmap_offset(self)\n"
     "--\n\n"
     "Get the (x, y) offset in 26.6 subpixels for the bitmap if ink hangs left or below (0, 0).\n"
     "Since Matplotlib only supports left-to-right text, y is always 0.\n";
@@ -705,7 +801,7 @@ static PyObject *PyFT2Font_get_bitmap_offset(PyFT2Font *self, PyObject *args)
 }
 
 const char *PyFT2Font_get_descent__doc__ =
-    "get_descent()\n"
+    "get_descent(self)\n"
     "--\n\n"
     "Get the descent in 26.6 subpixels of the current string set by `.set_text`.\n"
     "The rotation of the string is accounted for.  To get the descent\n"
@@ -721,7 +817,7 @@ static PyObject *PyFT2Font_get_descent(PyFT2Font *self, PyObject *args)
 }
 
 const char *PyFT2Font_draw_glyphs_to_bitmap__doc__ =
-    "draw_glyphs_to_bitmap()\n"
+    "draw_glyphs_to_bitmap(self, antialiased=True)\n"
     "--\n\n"
     "Draw the glyphs that were loaded by `.set_text` to the bitmap.\n"
     "The bitmap size will be automatically set to include the glyphs.\n";
@@ -742,7 +838,7 @@ static PyObject *PyFT2Font_draw_glyphs_to_bitmap(PyFT2Font *self, PyObject *args
 }
 
 const char *PyFT2Font_get_xys__doc__ =
-    "get_xys()\n"
+    "get_xys(self, antialiased=True)\n"
     "--\n\n"
     "Get the xy locations of the current glyphs.\n";
 
@@ -763,7 +859,7 @@ static PyObject *PyFT2Font_get_xys(PyFT2Font *self, PyObject *args, PyObject *kw
 }
 
 const char *PyFT2Font_draw_glyph_to_bitmap__doc__ =
-    "draw_glyph_to_bitmap(bitmap, x, y, glyph)\n"
+    "draw_glyph_to_bitmap(self, image, x, y, glyph, antialiased=True)\n"
     "--\n\n"
     "Draw a single glyph to the bitmap at pixel locations x, y\n"
     "Note it is your responsibility to set up the bitmap manually\n"
@@ -804,7 +900,7 @@ static PyObject *PyFT2Font_draw_glyph_to_bitmap(PyFT2Font *self, PyObject *args,
 }
 
 const char *PyFT2Font_get_glyph_name__doc__ =
-    "get_glyph_name(index)\n"
+    "get_glyph_name(self, index)\n"
     "--\n\n"
     "Retrieve the ASCII name of a given glyph *index* in a face.\n"
     "\n"
@@ -816,15 +912,17 @@ static PyObject *PyFT2Font_get_glyph_name(PyFT2Font *self, PyObject *args)
 {
     unsigned int glyph_number;
     char buffer[128];
+    int fallback = 1;
+
     if (!PyArg_ParseTuple(args, "I:get_glyph_name", &glyph_number)) {
         return NULL;
     }
-    CALL_CPP("get_glyph_name", (self->x->get_glyph_name(glyph_number, buffer)));
+    CALL_CPP("get_glyph_name", (self->x->get_glyph_name(glyph_number, buffer, (bool)fallback)));
     return PyUnicode_FromString(buffer);
 }
 
 const char *PyFT2Font_get_charmap__doc__ =
-    "get_charmap()\n"
+    "get_charmap(self)\n"
     "--\n\n"
     "Return a dict that maps the character codes of the selected charmap\n"
     "(Unicode by default) to their corresponding glyph indices.\n";
@@ -855,7 +953,7 @@ static PyObject *PyFT2Font_get_charmap(PyFT2Font *self, PyObject *args)
 
 
 const char *PyFT2Font_get_char_index__doc__ =
-    "get_char_index(codepoint)\n"
+    "get_char_index(self, codepoint)\n"
     "--\n\n"
     "Return the glyph index corresponding to a character *codepoint*.\n";
 
@@ -863,19 +961,20 @@ static PyObject *PyFT2Font_get_char_index(PyFT2Font *self, PyObject *args)
 {
     FT_UInt index;
     FT_ULong ccode;
+    int fallback = 1;
 
     if (!PyArg_ParseTuple(args, "k:get_char_index", &ccode)) {
         return NULL;
     }
 
-    index = FT_Get_Char_Index(self->x->get_face(), ccode);
+    CALL_CPP("get_char_index", index = self->x->get_char_index(ccode, (bool)fallback));
 
     return PyLong_FromLong(index);
 }
 
 
 const char *PyFT2Font_get_sfnt__doc__ =
-    "get_sfnt()\n"
+    "get_sfnt(self)\n"
     "--\n\n"
     "Load the entire SFNT names table, as a dict whose keys are\n"
     "(platform-ID, ISO-encoding-scheme, language-code, and description)\n"
@@ -936,7 +1035,7 @@ static PyObject *PyFT2Font_get_sfnt(PyFT2Font *self, PyObject *args)
 }
 
 const char *PyFT2Font_get_name_index__doc__ =
-    "get_name_index(name)\n"
+    "get_name_index(self, name)\n"
     "--\n\n"
     "Return the glyph index of a given glyph *name*.\n"
     "The glyph index 0 means 'undefined character code'.\n";
@@ -953,7 +1052,7 @@ static PyObject *PyFT2Font_get_name_index(PyFT2Font *self, PyObject *args)
 }
 
 const char *PyFT2Font_get_ps_font_info__doc__ =
-    "get_ps_font_info()\n"
+    "get_ps_font_info(self)\n"
     "--\n\n"
     "Return the information in the PS Font Info structure.\n";
 
@@ -980,7 +1079,7 @@ static PyObject *PyFT2Font_get_ps_font_info(PyFT2Font *self, PyObject *args)
 }
 
 const char *PyFT2Font_get_sfnt_table__doc__ =
-    "get_sfnt_table(name)\n"
+    "get_sfnt_table(self, name)\n"
     "--\n\n"
     "Return one of the following SFNT tables: head, maxp, OS/2, hhea, "
     "vhea, post, or pclt.\n";
@@ -1282,7 +1381,7 @@ static PyObject *PyFT2Font_get_sfnt_table(PyFT2Font *self, PyObject *args)
 }
 
 const char *PyFT2Font_get_path__doc__ =
-    "get_path()\n"
+    "get_path(self)\n"
     "--\n\n"
     "Get the path data from the currently loaded glyph as a tuple of vertices, "
     "codes.\n";
@@ -1293,7 +1392,7 @@ static PyObject *PyFT2Font_get_path(PyFT2Font *self, PyObject *args)
 }
 
 const char *PyFT2Font_get_image__doc__ =
-    "get_image()\n"
+    "get_image(self)\n"
     "--\n\n"
     "Return the underlying image buffer for this font object.\n";
 
@@ -1420,12 +1519,12 @@ static PyObject *PyFT2Font_underline_thickness(PyFT2Font *self, void *closure)
 
 static PyObject *PyFT2Font_fname(PyFT2Font *self, void *closure)
 {
-    if (self->fname) {
-        Py_INCREF(self->fname);
-        return self->fname;
+    if (self->stream.close) {  // Called passed a filename to the constructor.
+        return PyObject_GetAttrString(self->py_file, "name");
+    } else {
+        Py_INCREF(self->py_file);
+        return self->py_file;
     }
-
-    Py_RETURN_NONE;
 }
 
 static int PyFT2Font_get_buffer(PyFT2Font *self, Py_buffer *buf, int flags)
@@ -1452,7 +1551,7 @@ static int PyFT2Font_get_buffer(PyFT2Font *self, Py_buffer *buf, int flags)
     return 1;
 }
 
-static PyTypeObject *PyFT2Font_init_type(PyObject *m, PyTypeObject *type)
+static PyTypeObject *PyFT2Font_init_type()
 {
     static PyGetSetDef getset[] = {
         {(char *)"postscript_name", (getter)PyFT2Font_postscript_name, NULL, NULL, NULL},
@@ -1485,6 +1584,7 @@ static PyTypeObject *PyFT2Font_init_type(PyObject *m, PyTypeObject *type)
         {"select_charmap", (PyCFunction)PyFT2Font_select_charmap, METH_VARARGS, PyFT2Font_select_charmap__doc__},
         {"get_kerning", (PyCFunction)PyFT2Font_get_kerning, METH_VARARGS, PyFT2Font_get_kerning__doc__},
         {"set_text", (PyCFunction)PyFT2Font_set_text, METH_VARARGS|METH_KEYWORDS, PyFT2Font_set_text__doc__},
+        {"_get_fontmap", (PyCFunction)PyFT2Font_get_fontmap, METH_VARARGS|METH_KEYWORDS, PyFT2Font_get_fontmap__doc__},
         {"get_num_glyphs", (PyCFunction)PyFT2Font_get_num_glyphs, METH_NOARGS, PyFT2Font_get_num_glyphs__doc__},
         {"load_char", (PyCFunction)PyFT2Font_load_char, METH_VARARGS|METH_KEYWORDS, PyFT2Font_load_char__doc__},
         {"load_glyph", (PyCFunction)PyFT2Font_load_glyph, METH_VARARGS|METH_KEYWORDS, PyFT2Font_load_glyph__doc__},
@@ -1507,30 +1607,20 @@ static PyTypeObject *PyFT2Font_init_type(PyObject *m, PyTypeObject *type)
     };
 
     static PyBufferProcs buffer_procs;
-    memset(&buffer_procs, 0, sizeof(PyBufferProcs));
     buffer_procs.bf_getbuffer = (getbufferproc)PyFT2Font_get_buffer;
 
-    memset(type, 0, sizeof(PyTypeObject));
-    type->tp_name = "matplotlib.ft2font.FT2Font";
-    type->tp_doc = PyFT2Font_init__doc__;
-    type->tp_basicsize = sizeof(PyFT2Font);
-    type->tp_dealloc = (destructor)PyFT2Font_dealloc;
-    type->tp_flags = Py_TPFLAGS_DEFAULT | Py_TPFLAGS_BASETYPE;
-    type->tp_methods = methods;
-    type->tp_getset = getset;
-    type->tp_new = PyFT2Font_new;
-    type->tp_init = (initproc)PyFT2Font_init;
-    type->tp_as_buffer = &buffer_procs;
+    PyFT2FontType.tp_name = "matplotlib.ft2font.FT2Font";
+    PyFT2FontType.tp_doc = PyFT2Font_init__doc__;
+    PyFT2FontType.tp_basicsize = sizeof(PyFT2Font);
+    PyFT2FontType.tp_dealloc = (destructor)PyFT2Font_dealloc;
+    PyFT2FontType.tp_flags = Py_TPFLAGS_DEFAULT | Py_TPFLAGS_BASETYPE;
+    PyFT2FontType.tp_methods = methods;
+    PyFT2FontType.tp_getset = getset;
+    PyFT2FontType.tp_new = PyFT2Font_new;
+    PyFT2FontType.tp_init = (initproc)PyFT2Font_init;
+    PyFT2FontType.tp_as_buffer = &buffer_procs;
 
-    if (PyType_Ready(type) < 0) {
-        return NULL;
-    }
-
-    if (PyModule_AddObject(m, "FT2Font", (PyObject *)type)) {
-        return NULL;
-    }
-
-    return type;
+    return &PyFT2FontType;
 }
 
 static struct PyModuleDef moduledef = { PyModuleDef_HEAD_INIT, "ft2font" };
@@ -1539,32 +1629,26 @@ static struct PyModuleDef moduledef = { PyModuleDef_HEAD_INIT, "ft2font" };
 
 PyMODINIT_FUNC PyInit_ft2font(void)
 {
-    PyObject *m;
-
     import_array();
 
-    m = PyModule_Create(&moduledef);
-
-    if (m == NULL) {
-        return NULL;
+    if (FT_Init_FreeType(&_ft2Library)) {  // initialize library
+        return PyErr_Format(
+            PyExc_RuntimeError, "Could not initialize the freetype2 library");
     }
+    FT_Int major, minor, patch;
+    char version_string[64];
+    FT_Library_Version(_ft2Library, &major, &minor, &patch);
+    snprintf(version_string, sizeof(version_string), "%d.%d.%d", major, minor, patch);
 
-    if (!PyFT2Image_init_type(m, &PyFT2ImageType)) {
-        Py_DECREF(m);
-        return NULL;
-    }
-
-    if (!PyGlyph_init_type(m, &PyGlyphType)) {
-        Py_DECREF(m);
-        return NULL;
-    }
-
-    if (!PyFT2Font_init_type(m, &PyFT2FontType)) {
-        Py_DECREF(m);
-        return NULL;
-    }
-
-    if (PyModule_AddIntConstant(m, "SCALABLE", FT_FACE_FLAG_SCALABLE) ||
+    PyObject *m;
+    if (!(m = PyModule_Create(&moduledef)) ||
+        prepare_and_add_type(PyFT2Image_init_type(), m) ||
+        prepare_and_add_type(PyFT2Font_init_type(), m) ||
+        // Glyph is not constructible from Python, thus not added to the module.
+        PyType_Ready(PyGlyph_init_type()) ||
+        PyModule_AddStringConstant(m, "__freetype_version__", version_string) ||
+        PyModule_AddStringConstant(m, "__freetype_build_type__", STRINGIFY(FREETYPE_BUILD_TYPE)) ||
+        PyModule_AddIntConstant(m, "SCALABLE", FT_FACE_FLAG_SCALABLE) ||
         PyModule_AddIntConstant(m, "FIXED_SIZES", FT_FACE_FLAG_FIXED_SIZES) ||
         PyModule_AddIntConstant(m, "FIXED_WIDTH", FT_FACE_FLAG_FIXED_WIDTH) ||
         PyModule_AddIntConstant(m, "SFNT", FT_FACE_FLAG_SFNT) ||
@@ -1600,33 +1684,8 @@ PyMODINIT_FUNC PyInit_ft2font(void)
         PyModule_AddIntConstant(m, "LOAD_TARGET_MONO", (unsigned long)FT_LOAD_TARGET_MONO) ||
         PyModule_AddIntConstant(m, "LOAD_TARGET_LCD", (unsigned long)FT_LOAD_TARGET_LCD) ||
         PyModule_AddIntConstant(m, "LOAD_TARGET_LCD_V", (unsigned long)FT_LOAD_TARGET_LCD_V)) {
-        Py_DECREF(m);
-        return NULL;
-    }
-
-    // initialize library
-    int error = FT_Init_FreeType(&_ft2Library);
-
-    if (error) {
-        PyErr_SetString(PyExc_RuntimeError, "Could not initialize the freetype2 library");
-        Py_DECREF(m);
-        return NULL;
-    }
-
-    {
-        FT_Int major, minor, patch;
-        char version_string[64];
-
-        FT_Library_Version(_ft2Library, &major, &minor, &patch);
-        sprintf(version_string, "%d.%d.%d", major, minor, patch);
-        if (PyModule_AddStringConstant(m, "__freetype_version__", version_string)) {
-            Py_DECREF(m);
-            return NULL;
-        }
-    }
-
-    if (PyModule_AddStringConstant(m, "__freetype_build_type__", STRINGIFY(FREETYPE_BUILD_TYPE))) {
-        Py_DECREF(m);
+        FT_Done_FreeType(_ft2Library);
+        Py_XDECREF(m);
         return NULL;
     }
 
