@@ -7,15 +7,12 @@
  */
 #define NO_IMPORT_ARRAY
 
+#include "../mplutils.h"
 #include "_tri.h"
 
 #include <algorithm>
 #include <set>
 
-#define MOVETO 1
-#define LINETO 2
-
-
 
 TriEdge::TriEdge()
     : tri(-1), edge(-1)
@@ -600,31 +597,88 @@ void TriContourGenerator::clear_visited_flags(bool include_boundaries)
     }
 }
 
-PyObject* TriContourGenerator::contour_to_segs(const Contour& contour)
+PyObject* TriContourGenerator::contour_line_to_segs_and_kinds(const Contour& contour)
 {
-    PyObject* segs = PyList_New(contour.size());
-    for (Contour::size_type i = 0; i < contour.size(); ++i) {
-        const ContourLine& line = contour[i];
-        npy_intp dims[2] = {static_cast<npy_intp>(line.size()),2};
-        PyArrayObject* py_line = (PyArrayObject*)PyArray_SimpleNew(
-                                                     2, dims, NPY_DOUBLE);
-        double* p = (double*)PyArray_DATA(py_line);
-        for (ContourLine::const_iterator it = line.begin(); it != line.end(); ++it) {
-            *p++ = it->x;
-            *p++ = it->y;
-        }
-        if (PyList_SetItem(segs, i, (PyObject*)py_line)) {
-            Py_XDECREF(segs);
-            PyErr_SetString(PyExc_RuntimeError,
-                            "Unable to set contour segments");
-            return NULL;
-        }
+    // Convert all of the lines generated by a call to create_contour() into
+    // their Python equivalents for return to the calling function.
+    // A line is either a closed line loop (in which case the last point is
+    // identical to the first) or an open line strip.  Two NumPy arrays are
+    // created for each line:
+    //   vertices is a double array of shape (npoints, 2) containing the (x, y)
+    //     coordinates of the points in the line
+    //   codes is a uint8 array of shape (npoints,) containing the 'kind codes'
+    //     which are defined in the Path class
+    // and they are appended to the Python lists vertices_list and codes_list
+    // respectively for return to the Python calling function.
+
+    PyObject* vertices_list = PyList_New(contour.size());
+    if (vertices_list == 0)
+        throw std::runtime_error("Failed to create Python list");
+
+    PyObject* codes_list = PyList_New(contour.size());
+    if (codes_list == 0) {
+        Py_XDECREF(vertices_list);
+        throw std::runtime_error("Failed to create Python list");
     }
-    return segs;
+
+    for (Contour::size_type i = 0; i < contour.size(); ++i) {
+        const ContourLine& contour_line = contour[i];
+        npy_intp npoints = static_cast<npy_intp>(contour_line.size());
+
+        npy_intp segs_dims[2] = {npoints, 2};
+        numpy::array_view<double, 2> segs(segs_dims);
+        double* segs_ptr = segs.data();
+
+        npy_intp codes_dims[1] = {npoints};
+        numpy::array_view<unsigned char, 1> codes(codes_dims);
+        unsigned char* codes_ptr = codes.data();
+
+        for (ContourLine::const_iterator it = contour_line.begin();
+             it != contour_line.end(); ++it) {
+            *segs_ptr++ = it->x;
+            *segs_ptr++ = it->y;
+            *codes_ptr++ = (it == contour_line.begin() ? MOVETO : LINETO);
+        }
+
+        // Closed line loop has identical first and last (x, y) points.
+        if (contour_line.size() > 1 &&
+            contour_line.front() == contour_line.back())
+            *(codes_ptr-1) = CLOSEPOLY;
+
+        PyList_SET_ITEM(vertices_list, i, segs.pyobj());
+        PyList_SET_ITEM(codes_list, i, codes.pyobj());
+    }
+
+    PyObject* result = PyTuple_New(2);
+    if (result == 0) {
+        Py_XDECREF(vertices_list);
+        Py_XDECREF(codes_list);
+        throw std::runtime_error("Failed to create Python tuple");
+    }
+
+    // No error checking here as filling in a brand new pre-allocated result.
+    PyTuple_SET_ITEM(result, 0, vertices_list);
+    PyTuple_SET_ITEM(result, 1, codes_list);
+
+    return result;
 }
 
 PyObject* TriContourGenerator::contour_to_segs_and_kinds(const Contour& contour)
 {
+    // Convert all of the polygons generated by a call to
+    // create_filled_contour() into their Python equivalents for return to the
+    // calling function.  All of the polygons' points and kinds codes are
+    // combined into single NumPy arrays for each; this avoids having
+    // to determine which polygons are holes as this will be determined by the
+    // renderer.  If there are ntotal points in all of the polygons, the two
+    // NumPy arrays created are:
+    //   vertices is a double array of shape (ntotal, 2) containing the (x, y)
+    //     coordinates of the points in the polygons
+    //   codes is a uint8 array of shape (ntotal,) containing the 'kind codes'
+    //     which are defined in the Path class
+    // and they are returned in the Python lists vertices_list and codes_list
+    // respectively.
+
     Contour::const_iterator line;
     ContourLine::const_iterator point;
 
@@ -635,32 +689,50 @@ PyObject* TriContourGenerator::contour_to_segs_and_kinds(const Contour& contour)
 
     // Create segs array for point coordinates.
     npy_intp segs_dims[2] = {n_points, 2};
-    PyArrayObject* segs = (PyArrayObject*)PyArray_SimpleNew(
-                                                2, segs_dims, NPY_DOUBLE);
-    double* segs_ptr = (double*)PyArray_DATA(segs);
+    numpy::array_view<double, 2> segs(segs_dims);
+    double* segs_ptr = segs.data();
 
     // Create kinds array for code types.
-    npy_intp kinds_dims[1] = {n_points};
-    PyArrayObject* kinds = (PyArrayObject*)PyArray_SimpleNew(
-                                                1, kinds_dims, NPY_UBYTE);
-    unsigned char* kinds_ptr = (unsigned char*)PyArray_DATA(kinds);
+    npy_intp codes_dims[1] = {n_points};
+    numpy::array_view<unsigned char, 1> codes(codes_dims);
+    unsigned char* codes_ptr = codes.data();
 
     for (line = contour.begin(); line != contour.end(); ++line) {
         for (point = line->begin(); point != line->end(); point++) {
             *segs_ptr++ = point->x;
             *segs_ptr++ = point->y;
-            *kinds_ptr++ = (point == line->begin() ? MOVETO : LINETO);
+            *codes_ptr++ = (point == line->begin() ? MOVETO : LINETO);
         }
     }
 
-    PyObject* result = PyTuple_New(2);
-    if (PyTuple_SetItem(result, 0, (PyObject*)segs) ||
-        PyTuple_SetItem(result, 1, (PyObject*)kinds)) {
-        Py_XDECREF(result);
-        PyErr_SetString(PyExc_RuntimeError,
-                        "Unable to set contour segments and kinds");
-        return NULL;
+    PyObject* vertices_list = PyList_New(0);
+    if (vertices_list == 0)
+        throw std::runtime_error("Failed to create Python list");
+
+    PyObject* codes_list = PyList_New(0);
+    if (codes_list == 0) {
+        Py_XDECREF(vertices_list);
+        throw std::runtime_error("Failed to create Python list");
     }
+
+    if (PyList_Append(vertices_list, segs.pyobj_steal()) ||
+        PyList_Append(codes_list, codes.pyobj_steal())) {
+        Py_XDECREF(vertices_list);
+        Py_XDECREF(codes_list);
+        throw std::runtime_error("Unable to add contour to vertices and codes lists");
+    }
+
+    PyObject* result = PyTuple_New(2);
+    if (result == 0) {
+        Py_XDECREF(vertices_list);
+        Py_XDECREF(codes_list);
+        throw std::runtime_error("Failed to create Python tuple");
+    }
+
+    // No error checking here as filling in a brand new pre-allocated tuple.
+    PyTuple_SET_ITEM(result, 0, vertices_list);
+    PyTuple_SET_ITEM(result, 1, codes_list);
+
     return result;
 }
 
@@ -672,7 +744,7 @@ PyObject* TriContourGenerator::create_contour(const double& level)
     find_boundary_lines(contour, level);
     find_interior_lines(contour, level, false, false);
 
-    return contour_to_segs(contour);
+    return contour_line_to_segs_and_kinds(contour);
 }
 
 PyObject* TriContourGenerator::create_filled_contour(const double& lower_level,
