@@ -52,11 +52,10 @@ fig.subplots_adjust(bottom=0.5)
 cmap = mpl.cm.viridis
 bounds = [-1, 2, 5, 7, 12, 15]
 norm = mpl.colors.BoundaryNorm(bounds, cmap.N, extend='both')
-cb2 = mpl.colorbar.ColorbarBase(ax, cmap=cmap,
-                                norm=norm,
-                                orientation='horizontal')
-cb2.set_label("Discrete intervals with extend='both' keyword")
-fig.show()
+
+fig.colorbar(mpl.cm.ScalarMappable(norm=norm, cmap=cmap),
+             cax=ax, orientation='horizontal',
+             label="Discrete intervals with extend='both' keyword")
 
 ###############################################################################
 # Discrete intervals colorbar
@@ -78,8 +77,7 @@ fig.show()
 # `~.Figure.colorbar`. For the out-of-range values to display on the colorbar
 # without using the *extend* keyword with
 # `.colors.BoundaryNorm`, we have to use the *extend* keyword argument directly
-# in the colorbar call, and supply an additional boundary on each end of the
-# range.  Here we also
+# in the colorbar call.  Here we also
 # use the spacing argument to make
 # the length of each colorbar segment proportional to its corresponding
 # interval.
@@ -87,16 +85,14 @@ fig.show()
 fig, ax = plt.subplots(figsize=(6, 1))
 fig.subplots_adjust(bottom=0.5)
 
-cmap = mpl.colors.ListedColormap(['red', 'green', 'blue', 'cyan'])
-cmap.set_over('0.25')
-cmap.set_under('0.75')
+cmap = (mpl.colors.ListedColormap(['red', 'green', 'blue', 'cyan'])
+        .with_extremes(over='0.25', under='0.75'))
 
 bounds = [1, 2, 4, 7, 8]
 norm = mpl.colors.BoundaryNorm(bounds, cmap.N)
 fig.colorbar(
     mpl.cm.ScalarMappable(cmap=cmap, norm=norm),
     cax=ax,
-    boundaries=[0] + bounds + [13],  # Adding values for extensions.
     extend='both',
     ticks=bounds,
     spacing='proportional',
@@ -115,17 +111,14 @@ fig.colorbar(
 fig, ax = plt.subplots(figsize=(6, 1))
 fig.subplots_adjust(bottom=0.5)
 
-cmap = mpl.colors.ListedColormap(['royalblue', 'cyan',
-                                  'yellow', 'orange'])
-cmap.set_over('red')
-cmap.set_under('blue')
+cmap = (mpl.colors.ListedColormap(['royalblue', 'cyan', 'yellow', 'orange'])
+        .with_extremes(over='red', under='blue'))
 
 bounds = [-1.0, -0.5, 0.0, 0.5, 1.0]
 norm = mpl.colors.BoundaryNorm(bounds, cmap.N)
 fig.colorbar(
     mpl.cm.ScalarMappable(cmap=cmap, norm=norm),
     cax=ax,
-    boundaries=[-10] + bounds + [10],
     extend='both',
     extendfrac='auto',
     ticks=bounds,
