@@ -115,6 +115,7 @@ drawing of the ticks, tick labels and axis labels.
 
 Try creating the figure below.
 """
+# sphinx_gallery_capture_repr = ('__repr__',)
 
 import numpy as np
 import matplotlib.pyplot as plt
@@ -122,8 +123,8 @@ import matplotlib.pyplot as plt
 fig = plt.figure()
 fig.subplots_adjust(top=0.8)
 ax1 = fig.add_subplot(211)
-ax1.set_ylabel('volts')
-ax1.set_title('a sine wave')
+ax1.set_ylabel('Voltage [V]')
+ax1.set_title('A sine wave')
 
 t = np.arange(0.0, 1.0, 0.01)
 s = np.sin(2*np.pi*t)
@@ -135,7 +136,7 @@ np.random.seed(19680801)
 ax2 = fig.add_axes([0.15, 0.1, 0.7, 0.3])
 n, bins, patches = ax2.hist(np.random.randn(1000), 50,
                             facecolor='yellow', edgecolor='yellow')
-ax2.set_xlabel('time (s)')
+ax2.set_xlabel('Time [s]')
 
 plt.show()
 
@@ -353,7 +354,7 @@ plt.show()
 # images           A list of `.FigureImage` patches -
 #                  useful for raw pixel display
 # legends          A list of Figure `.Legend` instances
-#                  (different from ``Axes.legends``)
+#                  (different from ``Axes.get_legend()``)
 # lines            A list of Figure `.Line2D` instances
 #                  (rarely used, see ``Axes.lines``)
 # patches          A list of Figure `.Patch`\s
@@ -543,7 +544,7 @@ plt.show()
 # `~.axes.Axes.fill` - shared area           `.Polygon`         ax.patches
 # `~.axes.Axes.hist` - histograms            `.Rectangle`       ax.patches
 # `~.axes.Axes.imshow` - image data          `.AxesImage`       ax.images
-# `~.axes.Axes.legend` - Axes legends        `.Legend`          ax.legends
+# `~.axes.Axes.legend` - Axes legend         `.Legend`          ax.get_legend()
 # `~.axes.Axes.plot` - xy plots              `.Line2D`          ax.lines
 # `~.axes.Axes.scatter` - scatter charts     `.PolyCollection`  ax.collections
 # `~.axes.Axes.text` - text                  `.Text`            ax.texts
@@ -563,26 +564,26 @@ plt.show()
 # the font color of the ``XAxis`` ticklabels using the ``Axes`` helper
 # method::
 #
-#     for label in ax.get_xticklabels():
-#         label.set_color('orange')
+#     ax.tick_params(axis='x', labelcolor='orange')
 #
-# Below is a summary of the Artists that the Axes contains
+# Below is a summary of the Artists that the `~.axes.Axes` contains
 #
 # ==============    =========================================
 # Axes attribute    Description
 # ==============    =========================================
-# artists           A list of `.Artist` instances
+# artists           An `.ArtistList` of `.Artist` instances
 # patch             `.Rectangle` instance for Axes background
-# collections       A list of `.Collection` instances
-# images            A list of `.AxesImage`
-# legends           A list of `.Legend` instances
-# lines             A list of `.Line2D` instances
-# patches           A list of `.Patch` instances
-# texts             A list of `.Text` instances
+# collections       An `.ArtistList` of `.Collection` instances
+# images            An `.ArtistList` of `.AxesImage`
+# lines             An `.ArtistList` of `.Line2D` instances
+# patches           An `.ArtistList` of `.Patch` instances
+# texts             An `.ArtistList` of `.Text` instances
 # xaxis             A `matplotlib.axis.XAxis` instance
 # yaxis             A `matplotlib.axis.YAxis` instance
 # ==============    =========================================
 #
+# The legend can be accessed by `~.axes.Axes.get_legend`,
+#
 # .. _axis-container:
 #
 # Axis containers
@@ -718,6 +719,6 @@ plt.show()
 # dollar signs and colors them green on the right side of the yaxis.
 #
 #
-# .. include:: ../../gallery/pyplots/dollar_ticks.rst
+# .. include:: ../../gallery/ticks/dollar_ticks.rst
 #    :start-after: y axis labels.
 #    :end-before: .. admonition:: References
