@@ -37,15 +37,15 @@ However, for other backends, such as Qt, that open a separate window,
 cells below those that create the plot will change the plot - it is a
 live object in memory.
 
-This tutorial will use Matplotlib's imperative-style plotting
-interface, pyplot.  This interface maintains global state, and is very
-useful for quickly and easily experimenting with various plot
-settings.  The alternative is the object-oriented interface, which is also
-very powerful, and generally more suitable for large application
-development.  If you'd like to learn about the object-oriented
-interface, a great place to start is our :doc:`Usage guide
-</tutorials/introductory/usage>`.  For now, let's get on
-with the imperative-style approach:
+This tutorial will use Matplotlib's implicit plotting interface, pyplot.  This
+interface maintains global state, and is very useful for quickly and easily
+experimenting with various plot settings.  The alternative is the explicit,
+which is more suitable for large application development.  For an explanation
+of the tradeoffs between the implicit and explicit interfaces see
+:ref:`api_interfaces` and the :doc:`Quick start guide
+</tutorials/introductory/quick_start>` to start using the explicit interface.
+For now, let's get on with the implicit approach:
+
 """
 
 import matplotlib.pyplot as plt
@@ -69,7 +69,7 @@ import matplotlib.image as mpimg
 # on where you get your data, the other kinds of image that you'll most
 # likely encounter are RGBA images, which allow for transparency, or
 # single-channel grayscale (luminosity) images.  Download `stinkbug.png
-# <https://raw.githubusercontent.com/matplotlib/matplotlib/master/doc/_static/stinkbug.png>`_
+# <https://raw.githubusercontent.com/matplotlib/matplotlib/main/doc/_static/stinkbug.png>`_
 # to your computer for the rest of this tutorial.
 #
 # And here we go...
@@ -91,7 +91,7 @@ print(img)
 #
 # Each inner list represents a pixel.  Here, with an RGB image, there
 # are 3 values.  Since it's a black and white image, R, G, and B are all
-# similar.  An RGBA (where A is alpha, or transparency), has 4 values
+# similar.  An RGBA (where A is alpha, or transparency) has 4 values
 # per inner list, and a simple luminance image just has one value (and
 # is thus only a 2-D array, not a 3-D array).  For RGB and RGBA images,
 # Matplotlib supports float32 and uint8 data types.  For grayscale,
@@ -127,13 +127,11 @@ imgplot = plt.imshow(img)
 # Pseudocolor is only relevant to single-channel, grayscale, luminosity
 # images.  We currently have an RGB image.  Since R, G, and B are all
 # similar (see for yourself above or in your data), we can just pick one
-# channel of our data:
+# channel of our data using array slicing (you can read more in the
+# `Numpy tutorial <https://numpy.org/doc/stable/user/quickstart.html
+# #indexing-slicing-and-iterating>`_):
 
 lum_img = img[:, :, 0]
-
-# This is array slicing.  You can read more in the `Numpy tutorial
-# <https://numpy.org/doc/stable/user/quickstart.html>`_.
-
 plt.imshow(lum_img)
 
 ###############################################################################
@@ -245,7 +243,7 @@ plt.colorbar(ticks=[0.1, 0.3, 0.5, 0.7], orientation='horizontal')
 from PIL import Image
 
 img = Image.open('../../doc/_static/stinkbug.png')
-img.thumbnail((64, 64), Image.ANTIALIAS)  # resizes image in-place
+img.thumbnail((64, 64))  # resizes image in-place
 imgplot = plt.imshow(img)
 
 ###############################################################################
