@@ -3,19 +3,21 @@
 Pyplot tutorial
 ===============
 
-An introduction to the pyplot interface.
+An introduction to the pyplot interface.  Please also see
+:doc:`/tutorials/introductory/quick_start` for an overview of how Matplotlib
+works and :ref:`api_interfaces` for an explanation of the trade-offs between the
+supported user APIs.
+
 """
 
 ###############################################################################
 # Intro to pyplot
 # ===============
 #
-# :mod:`matplotlib.pyplot` is a collection of functions
-# that make matplotlib work like MATLAB.
-# Each ``pyplot`` function makes
-# some change to a figure: e.g., creates a figure, creates a plotting area
-# in a figure, plots some lines in a plotting area, decorates the plot
-# with labels, etc.
+# :mod:`matplotlib.pyplot` is a collection of functions that make matplotlib
+# work like MATLAB.  Each ``pyplot`` function makes some change to a figure:
+# e.g., creates a figure, creates a plotting area in a figure, plots some lines
+# in a plotting area, decorates the plot with labels, etc.
 #
 # In :mod:`matplotlib.pyplot` various states are preserved
 # across function calls, so that it keeps track of things like
@@ -27,10 +29,11 @@ An introduction to the pyplot interface.
 #
 # .. note::
 #
-#    the pyplot API is generally less-flexible than the object-oriented API.
-#    Most of the function calls you see here can also be called as methods
-#    from an ``Axes`` object. We recommend browsing the tutorials and
-#    examples to see how this works.
+#    the implicit pyplot API is generally less verbose but also not as flexible as the
+#    explicit API.  Most of the function calls you see here can also be called
+#    as methods from an ``Axes`` object. We recommend browsing the tutorials
+#    and examples to see how this works. See :ref:`api_interfaces` for an
+#    explanation of the trade off of the supported user APIs.
 #
 # Generating visualizations with pyplot is very quick:
 
@@ -77,7 +80,7 @@ plt.show()
 #
 # If matplotlib were limited to working with lists, it would be fairly
 # useless for numeric processing.  Generally, you will use `numpy
-# <http://www.numpy.org>`_ arrays.  In fact, all sequences are
+# <https://numpy.org/>`_ arrays.  In fact, all sequences are
 # converted to numpy arrays internally.  The example below illustrates
 # plotting several lines with different format styles in one function call
 # using arrays.
@@ -150,7 +153,7 @@ plt.show()
 # antialiased, etc; see `matplotlib.lines.Line2D`.  There are
 # several ways to set line properties
 #
-# * Use keyword args::
+# * Use keyword arguments::
 #
 #       plt.plot(x, y, linewidth=2.0)
 #
@@ -171,7 +174,7 @@ plt.show()
 #   MATLAB-style string/value pairs::
 #
 #       lines = plt.plot(x1, y1, x2, y2)
-#       # use keyword args
+#       # use keyword arguments
 #       plt.setp(lines, color='r', linewidth=2.0)
 #       # or MATLAB style string value pairs
 #       plt.setp(lines, 'color', 'r', 'linewidth', 2.0)
@@ -258,25 +261,24 @@ plt.plot(t2, np.cos(2*np.pi*t2), 'r--')
 plt.show()
 
 ###############################################################################
-# The `~.pyplot.figure` call here is optional because
-# ``figure(1)`` will be created by default, just as a ``subplot(111)``
-# will be created by default if you don't manually specify any axes.  The
-# `~.pyplot.subplot` call specifies ``numrows,
+# The `~.pyplot.figure` call here is optional because a figure will be created
+# if none exists, just as an Axes will be created (equivalent to an explicit
+# ``subplot()`` call) if none exists.
+# The `~.pyplot.subplot` call specifies ``numrows,
 # numcols, plot_number`` where ``plot_number`` ranges from 1 to
 # ``numrows*numcols``.  The commas in the ``subplot`` call are
 # optional if ``numrows*numcols<10``.  So ``subplot(211)`` is identical
 # to ``subplot(2, 1, 1)``.
 #
 # You can create an arbitrary number of subplots
-# and axes.  If you want to place an axes manually, i.e., not on a
+# and axes.  If you want to place an Axes manually, i.e., not on a
 # rectangular grid, use `~.pyplot.axes`,
 # which allows you to specify the location as ``axes([left, bottom,
 # width, height])`` where all values are in fractional (0 to 1)
 # coordinates.  See :doc:`/gallery/subplots_axes_and_figures/axes_demo` for an example of
-# placing axes manually and :doc:`/gallery/subplots_axes_and_figures/subplot_demo` for an
+# placing axes manually and :doc:`/gallery/subplots_axes_and_figures/subplot` for an
 # example with lots of subplots.
 #
-#
 # You can create multiple figures by using multiple
 # `~.pyplot.figure` calls with an increasing figure
 # number.  Of course, each figure can contain as many axes and subplots
@@ -291,17 +293,19 @@ plt.show()
 #
 #
 #     plt.figure(2)                # a second figure
-#     plt.plot([4, 5, 6])          # creates a subplot(111) by default
+#     plt.plot([4, 5, 6])          # creates a subplot() by default
 #
-#     plt.figure(1)                # figure 1 current; subplot(212) still current
-#     plt.subplot(211)             # make subplot(211) in figure1 current
+#     plt.figure(1)                # first figure current;
+#                                  # subplot(212) still current
+#     plt.subplot(211)             # make subplot(211) in the first figure
+#                                  # current
 #     plt.title('Easy as 1, 2, 3') # subplot 211 title
 #
 # You can clear the current figure with `~.pyplot.clf`
 # and the current axes with `~.pyplot.cla`.  If you find
 # it annoying that states (specifically the current image, figure and axes)
 # are being maintained for you behind the scenes, don't despair: this is just a thin
-# stateful wrapper around an object oriented API, which you can use
+# stateful wrapper around an object-oriented API, which you can use
 # instead (see :doc:`/tutorials/intermediate/artists`)
 #
 # If you are making lots of figures, you need to be aware of one
@@ -327,7 +331,7 @@ mu, sigma = 100, 15
 x = mu + sigma * np.random.randn(10000)
 
 # the histogram of the data
-n, bins, patches = plt.hist(x, 50, density=1, facecolor='g', alpha=0.75)
+n, bins, patches = plt.hist(x, 50, density=True, facecolor='g', alpha=0.75)
 
 
 plt.xlabel('Smarts')
@@ -340,7 +344,7 @@ plt.show()
 
 ###############################################################################
 # All of the `~.pyplot.text` functions return a `matplotlib.text.Text`
-# instance.  Just as with with lines above, you can customize the properties by
+# instance.  Just as with lines above, you can customize the properties by
 # passing keyword arguments into the text functions or using `~.pyplot.setp`::
 #
 #   t = plt.xlabel('my data', fontsize=14, color='red')
@@ -380,7 +384,7 @@ plt.show()
 # the argument ``xy`` and the location of the text ``xytext``.  Both of
 # these arguments are ``(x, y)`` tuples.
 
-ax = plt.subplot(111)
+ax = plt.subplot()
 
 t = np.arange(0.0, 5.0, 0.01)
 s = np.cos(2*np.pi*t)
@@ -461,5 +465,5 @@ plt.subplots_adjust(top=0.92, bottom=0.08, left=0.10, right=0.95, hspace=0.25,
 plt.show()
 
 ###############################################################################
-# It is also possible to add your own scale, see :ref:`adding-new-scales` for
+# It is also possible to add your own scale, see `matplotlib.scale` for
 # details.
