@@ -1,9 +1,7 @@
 r"""
-==============================
-Overview of axisartist toolkit
-==============================
-
-The axisartist toolkit tutorial.
+======================
+The axisartist toolkit
+======================
 
 .. warning::
    *axisartist* uses a custom Axes class
@@ -20,9 +18,6 @@ curved coordinate systems.
 .. figure:: ../../gallery/axisartist/images/sphx_glr_demo_floating_axis_001.png
    :target: ../../gallery/axisartist/demo_floating_axis.html
    :align: center
-   :scale: 50
-
-   Demo Floating Axis
 
 Since it uses special artists, some Matplotlib commands that work on
 Axes.xaxis and Axes.yaxis may not work.
@@ -48,17 +43,17 @@ dictionary that contains artists (note that ax.axis is still a
 callable method and it behaves as an original Axes.axis method in
 Matplotlib).
 
-To create an axes, ::
+To create an Axes, ::
 
   import mpl_toolkits.axisartist as AA
   fig = plt.figure()
-  ax = AA.Axes(fig, [0.1, 0.1, 0.8, 0.8])
-  fig.add_axes(ax)
+  fig.add_axes([0.1, 0.1, 0.8, 0.8], axes_class=AA.Axes)
 
 or to create a subplot ::
 
-  ax = AA.Subplot(fig, 111)
-  fig.add_subplot(ax)
+  fig.add_subplot(111, axes_class=AA.Axes)
+  # Given that 111 is the default, one can also do
+  fig.add_subplot(axes_class=AA.Axes)
 
 For example, you can hide the right and top spines using::
 
@@ -68,9 +63,6 @@ For example, you can hide the right and top spines using::
 .. figure:: ../../gallery/axisartist/images/sphx_glr_simple_axisline3_001.png
    :target: ../../gallery/axisartist/simple_axisline3.html
    :align: center
-   :scale: 50
-
-   Simple Axisline3
 
 It is also possible to add a horizontal axis. For example, you may have an
 horizontal axis at y=0 (in data coordinate). ::
@@ -80,9 +72,6 @@ horizontal axis at y=0 (in data coordinate). ::
 .. figure:: ../../gallery/axisartist/images/sphx_glr_simple_axisartist1_001.png
    :target: ../../gallery/axisartist/simple_axisartist1.html
    :align: center
-   :scale: 50
-
-   Simple Axisartist1
 
 Or a fixed axis with some offset ::
 
@@ -93,7 +82,7 @@ axisartist with ParasiteAxes
 ----------------------------
 
 Most commands in the axes_grid1 toolkit can take an axes_class keyword
-argument, and the commands create an axes of the given class. For example,
+argument, and the commands create an Axes of the given class. For example,
 to create a host subplot with axisartist.Axes, ::
 
   import mpl_toolkits.axisartist as AA
@@ -106,9 +95,6 @@ Here is an example that uses ParasiteAxes.
 .. figure:: ../../gallery/axisartist/images/sphx_glr_demo_parasite_axes2_001.png
    :target: ../../gallery/axisartist/demo_parasite_axes2.html
    :align: center
-   :scale: 50
-
-   Demo Parasite Axes2
 
 Curvilinear Grid
 ----------------
@@ -119,9 +105,6 @@ and ticks.
 .. figure:: ../../gallery/axisartist/images/sphx_glr_demo_curvelinear_grid_001.png
    :target: ../../gallery/axisartist/demo_curvelinear_grid.html
    :align: center
-   :scale: 50
-
-   Demo Curvelinear Grid
 
 Floating Axes
 -------------
@@ -132,9 +115,6 @@ floating axis.
 .. figure:: ../../gallery/axisartist/images/sphx_glr_demo_floating_axes_001.png
    :target: ../../gallery/axisartist/demo_floating_axes.html
    :align: center
-   :scale: 50
-
-   Demo Floating Axes
 
 axisartist namespace
 ====================
@@ -167,9 +147,6 @@ In summary, all these changes was to support
 .. figure:: ../../gallery/axisartist/images/sphx_glr_demo_floating_axis_001.png
    :target: ../../gallery/axisartist/demo_floating_axis.html
    :align: center
-   :scale: 50
-
-   Demo Floating Axis
 
 *mpl_toolkits.axisartist.Axes* class defines a *axis* attribute, which
 is a dictionary of AxisArtist instances. By default, the dictionary
@@ -288,14 +265,14 @@ HowTo
 
 1. Changing tick locations and label.
 
-  Same as the original Matplotlib's axes::
+   Same as the original Matplotlib's axes::
 
-   ax.set_xticks([1, 2, 3])
+    ax.set_xticks([1, 2, 3])
 
 2. Changing axis properties like color, etc.
 
-  Change the properties of appropriate artists. For example, to change
-  the color of the ticklabels::
+   Change the properties of appropriate artists. For example, to change
+   the color of the ticklabels::
 
     ax.axis["left"].major_ticklabels.set_color("r")
 
@@ -331,77 +308,48 @@ using "set_axis_direction" method. ::
 .. figure:: ../../gallery/axisartist/images/sphx_glr_simple_axis_direction01_001.png
    :target: ../../gallery/axisartist/simple_axis_direction01.html
    :align: center
-   :scale: 50
-
-   Simple Axis Direction01
 
 The parameter for set_axis_direction is one of ["left", "right",
 "bottom", "top"].
 
 You must understand some underlying concept of directions.
 
- 1. There is a reference direction which is defined as the direction
-    of the axis line with increasing coordinate.  For example, the
-    reference direction of the left x-axis is from bottom to top.
+- There is a reference direction which is defined as the direction
+  of the axis line with increasing coordinate.  For example, the
+  reference direction of the left x-axis is from bottom to top.
 
-    .. figure:: ../../gallery/axisartist/images/sphx_glr_axis_direction_demo_step01_001.png
-       :target: ../../gallery/axisartist/axis_direction_demo_step01.html
-       :align: center
-       :scale: 50
+  The direction, text angle, and alignments of the ticks, ticklabels and
+  axis-label is determined with respect to the reference direction
 
-       Axis Direction Demo - Step 01
+- *label_direction* and *ticklabel_direction* are either the right-hand side
+  (+) of the reference direction or the left-hand side (-).
 
-   The direction, text angle, and alignments of the ticks, ticklabels and
-   axis-label is determined with respect to the reference direction
+- ticks are by default drawn toward the opposite direction of the ticklabels.
 
- 2. *ticklabel_direction* is either the right-hand side (+) of the
-    reference direction or the left-hand side (-).
+- text rotation of ticklabels and label is determined in reference
+  to the *ticklabel_direction* or *label_direction*,
+  respectively. The rotation of ticklabels and label is anchored.
 
-    .. figure:: ../../gallery/axisartist/images/sphx_glr_axis_direction_demo_step02_001.png
-       :target: ../../gallery/axisartist/axis_direction_demo_step02.html
-       :align: center
-       :scale: 50
-
-       Axis Direction Demo - Step 02
-
- 3. same for the *label_direction*
-
-    .. figure:: ../../gallery/axisartist/images/sphx_glr_axis_direction_demo_step03_001.png
-       :target: ../../gallery/axisartist/axis_direction_demo_step03.html
-       :align: center
-       :scale: 50
-
-       Axis Direction Demo - Step 03
-
- 4. ticks are by default drawn toward the opposite direction of the ticklabels.
-
- 5. text rotation of ticklabels and label is determined in reference
-    to the *ticklabel_direction* or *label_direction*,
-    respectively. The rotation of ticklabels and label is anchored.
-
-    .. figure:: ../../gallery/axisartist/images/sphx_glr_axis_direction_demo_step04_001.png
-       :target: ../../gallery/axisartist/axis_direction_demo_step04.html
-       :align: center
-       :scale: 50
-
-       Axis Direction Demo - Step 04
+.. figure:: ../../gallery/axisartist/images/sphx_glr_axis_direction_001.png
+   :target: ../../gallery/axisartist/axis_direction.html
+   :align: center
 
 On the other hand, there is a concept of "axis_direction". This is a
 default setting of above properties for each, "bottom", "left", "top",
 and "right" axis.
 
- ========== =========== ========= ========== ========= ==========
-    ?           ?        left      bottom      right      top
- ---------- ----------- --------- ---------- --------- ----------
- axislabel   direction      '-'       '+'        '+'      '-'
- axislabel   rotation      180         0          0       180
- axislabel   va           center    top       center     bottom
- axislabel   ha           right    center      right     center
- ticklabel   direction      '-'       '+'        '+'      '-'
- ticklabels  rotation       90         0        -90       180
- ticklabel   ha           right    center      right     center
- ticklabel   va           center   baseline    center   baseline
- ========== =========== ========= ========== ========= ==========
+========== =========== ========= ========== ========= ==========
+   ?           ?        left      bottom      right      top
+---------- ----------- --------- ---------- --------- ----------
+axislabel   direction      '-'       '+'        '+'      '-'
+axislabel   rotation      180         0          0       180
+axislabel   va           center    top       center     bottom
+axislabel   ha           right    center      right     center
+ticklabel   direction      '-'       '+'        '+'      '-'
+ticklabels  rotation       90         0        -90       180
+ticklabel   ha           right    center      right     center
+ticklabel   va           center   baseline    center   baseline
+========== =========== ========= ========== ========= ==========
 
 And, 'set_axis_direction("top")' means to adjust the text rotation
 etc, for settings suitable for "top" axis. The concept of axis
@@ -410,9 +358,6 @@ direction can be more clear with curved axis.
 .. figure:: ../../gallery/axisartist/images/sphx_glr_demo_axis_direction_001.png
    :target: ../../gallery/axisartist/demo_axis_direction.html
    :align: center
-   :scale: 50
-
-   Demo Axis Direction
 
 The axis_direction can be adjusted in the AxisArtist level, or in the
 level of its child artists, i.e., ticks, ticklabels, and axis-label. ::
@@ -444,9 +389,6 @@ default direction). ::
 .. figure:: ../../gallery/axisartist/images/sphx_glr_simple_axis_direction03_001.png
    :target: ../../gallery/axisartist/simple_axis_direction03.html
    :align: center
-   :scale: 50
-
-   Simple Axis Direction03
 
 So, in summary,
 
@@ -482,9 +424,6 @@ Alignment of TickLabels are treated specially. See below
 .. figure:: ../../gallery/axisartist/images/sphx_glr_demo_ticklabel_alignment_001.png
    :target: ../../gallery/axisartist/demo_ticklabel_alignment.html
    :align: center
-   :scale: 50
-
-   Demo Ticklabel Alignment
 
 Adjusting pad
 -------------
@@ -500,9 +439,6 @@ Or ticklabels and axis-label ::
 .. figure:: ../../gallery/axisartist/images/sphx_glr_simple_axis_pad_001.png
    :target: ../../gallery/axisartist/simple_axis_pad.html
    :align: center
-   :scale: 50
-
-   Simple Axis Pad
 
 GridHelper
 ==========
@@ -518,7 +454,7 @@ transform of the axes itself (ax.transData) is still rectilinear
 
     from mpl_toolkits.axisartist.grid_helper_curvelinear \
          import GridHelperCurveLinear
-    from mpl_toolkits.axisartist import Subplot
+    from mpl_toolkits.axisartist import Axes
 
     # from curved coordinate to rectlinear coordinate.
     def tr(x, y):
@@ -532,9 +468,7 @@ transform of the axes itself (ax.transData) is still rectilinear
 
     grid_helper = GridHelperCurveLinear((tr, inv_tr))
 
-    ax1 = Subplot(fig, 1, 1, 1, grid_helper=grid_helper)
-
-    fig.add_subplot(ax1)
+    fig.add_subplot(axes_class=Axes, grid_helper=grid_helper)
 
 You may use Matplotlib's Transform instance instead (but a
 inverse transformation must be defined). Often, coordinate range in a
@@ -554,10 +488,10 @@ required. ::
     #   has a cycle of 360 degree.
     # The second coordinate (latitude, but radius in polar)  has a minimum of 0
     extreme_finder = angle_helper.ExtremeFinderCycle(20, 20,
-                                                     lon_cycle = 360,
-                                                     lat_cycle = None,
-                                                     lon_minmax = None,
-                                                     lat_minmax = (0, np.inf),
+                                                     lon_cycle=360,
+                                                     lat_cycle=None,
+                                                     lon_minmax=None,
+                                                     lat_minmax=(0, np.inf),
                                                      )
 
     # Find a grid values appropriate for the coordinate (degree,
@@ -591,9 +525,6 @@ coordinates, or you may use Parasite Axes for convenience.::
 .. figure:: ../../gallery/axisartist/images/sphx_glr_demo_curvelinear_grid_001.png
    :target: ../../gallery/axisartist/demo_curvelinear_grid.html
    :align: center
-   :scale: 50
-
-   Demo Curvelinear Grid
 
 FloatingAxis
 ============
